@@ -22,9 +22,15 @@ int main(int argc UNUSED, char **argv UNUSED)
 {
 	GSM_Debug_Info *debug_info;
 
+	/*
+	 * We don't need gettext, but need to set locales so that
+	 * charset conversion works.
+	 */
+	GSM_InitLocales(NULL);
+
 	/* Enable global debugging to stderr */
 	debug_info = GSM_GetGlobalDebug();
-	GSM_SetDebugFileDescriptor(stderr, false, debug_info);
+	GSM_SetDebugFileDescriptor(stderr, FALSE, debug_info);
 	GSM_SetDebugLevel("textall", debug_info);
 
 	/* Allocates state machine */
@@ -37,8 +43,8 @@ int main(int argc UNUSED, char **argv UNUSED)
 	 * Same could be achieved by just using global debug config.
 	 */
 	debug_info = GSM_GetDebug(s);
-	GSM_SetDebugGlobal(false, debug_info);
-	GSM_SetDebugFileDescriptor(stderr, false, debug_info);
+	GSM_SetDebugGlobal(FALSE, debug_info);
+	GSM_SetDebugFileDescriptor(stderr, FALSE, debug_info);
 	GSM_SetDebugLevel("textall", debug_info);
 
 	/*
