@@ -15,170 +15,271 @@
 #include "../helper/memory-display.h"
 #include "../helper/printing.h"
 #include "../helper/string.h"
+#include "../helper/cmdline.h"
 
 void SaveFile(int argc, char *argv[])
 {
 	GSM_Error error;
 	GSM_Backup		Backup;
 	int			i;
-	size_t j;
+	size_t data_size = 0;
 	FILE			*file;
 	unsigned char		Buffer[100000];
 	GSM_MemoryEntry		*pbk;
+	long int location;
 
 	if (strcasecmp(argv[2],"CALENDAR") == 0) {
-		if (argc<5) {
+		if (argc < 5) {
 			printf("%s\n", _("Where is backup filename and location?"));
-			Terminate(3);
+			Terminate(2);
+		}
+		location = GetInt(argv[5]) - 1;
+		error = GSM_ReadBackupFile(argv[4], &Backup,GSM_GuessBackupFormat(argv[4], FALSE));
+		if (error != ERR_NOTIMPLEMENTED) {
+			Print_Error(error);
 		}
-		error=GSM_ReadBackupFile(argv[4],&Backup,GSM_GuessBackupFormat(argv[4], FALSE));
-		if (error!=ERR_NOTIMPLEMENTED) Print_Error(error);
 		i = 0;
-		while (Backup.Calendar[i]!=NULL) {
-			if (i == atoi(argv[5])-1) break;
+		while (Backup.Calendar[i] != NULL) {
+			if (i == location) break;
 			i++;
 		}
-		if (i != atoi(argv[5])-1 || Backup.Calendar[i] == NULL) {
+		if (i != location || Backup.Calendar[i] == NULL) {
 			printf("%s\n", _("Calendar note not found in file"));
 			GSM_FreeBackup(&Backup);
-			Terminate(3);
+			Terminate(2);
 		}
-		j = 0;
-		error = GSM_EncodeVCALENDAR(Buffer, sizeof(Buffer), &j, Backup.Calendar[i],TRUE,Nokia_VCalendar);
+		error = GSM_EncodeVCALENDAR(Buffer, sizeof(Buffer), &data_size, Backup.Calendar[i],TRUE,Nokia_VCalendar);
 		GSM_FreeBackup(&Backup);
 		Print_Error(error);
 	} else if (strcasecmp(argv[2],"BOOKMARK") == 0) {
-		if (argc<5) {
+		if (argc < 5) {
 			printf("%s\n", _("Where is backup filename and location?"));
-			Terminate(3);
+			Terminate(2);
+		}
+		location = GetInt(argv[5]) - 1;
+		error = GSM_ReadBackupFile(argv[4],&Backup,GSM_GuessBackupFormat(argv[4], FALSE));
+		if (error != ERR_NOTIMPLEMENTED) {
+			Print_Error(error);
 		}
-		error=GSM_ReadBackupFile(argv[4],&Backup,GSM_GuessBackupFormat(argv[4], FALSE));
-		if (error!=ERR_NOTIMPLEMENTED) Print_Error(error);
 		i = 0;
 		while (Backup.WAPBookmark[i]!=NULL) {
-			if (i == atoi(argv[5])-1) break;
+			if (i == location) break;
 			i++;
 		}
-		if (i != atoi(argv[5])-1 || Backup.WAPBookmark[i] == NULL) {
+		if (i != location || Backup.WAPBookmark[i] == NULL) {
 			printf("%s\n", _("WAP bookmark not found in file"));
 			GSM_FreeBackup(&Backup);
-			Terminate(3);
+			Terminate(2);
 		}
-		j = 0;
-		error = GSM_EncodeURLFile(Buffer, &j, Backup.WAPBookmark[i]);
+		error = GSM_EncodeURLFile(Buffer, &data_size, Backup.WAPBookmark[i]);
 		GSM_FreeBackup(&Backup);
 		Print_Error(error);
 	} else if (strcasecmp(argv[2],"NOTE") == 0) {
 		if (argc<5) {
 			printf("%s\n", _("Where is backup filename and location?"));
-			Terminate(3);
+			Terminate(2);
 		}
+		location = GetInt(argv[5]) - 1;
 		error=GSM_ReadBackupFile(argv[4],&Backup,GSM_GuessBackupFormat(argv[4], FALSE));
 		if (error!=ERR_NOTIMPLEMENTED) Print_Error(error);
 		i = 0;
 		while (Backup.Note[i]!=NULL) {
-			if (i == atoi(argv[5])-1) break;
+			if (i == location) break;
 			i++;
 		}
-		if (i != atoi(argv[5])-1 || Backup.Note[i] == NULL) {
+		if (i != location || Backup.Note[i] == NULL) {
 			printf("%s\n", _("Note not found in file"));
 			GSM_FreeBackup(&Backup);
-			Terminate(3);
+			Terminate(2);
 		}
-		j = 0;
-		error = GSM_EncodeVNTFile(Buffer, sizeof(Buffer), &j, Backup.Note[i]);
+		error = GSM_EncodeVNTFile(Buffer, sizeof(Buffer), &data_size, Backup.Note[i]);
 		GSM_FreeBackup(&Backup);
 		Print_Error(error);
 	} else if (strcasecmp(argv[2],"TODO") == 0) {
 		if (argc<5) {
 			printf("%s\n", _("Where is backup filename and location?"));
-			Terminate(3);
+			Terminate(2);
 		}
+		location = GetInt(argv[5]) - 1;
 		error=GSM_ReadBackupFile(argv[4],&Backup,GSM_GuessBackupFormat(argv[4], FALSE));
 		if (error!=ERR_NOTIMPLEMENTED) Print_Error(error);
 		i = 0;
 		while (Backup.ToDo[i]!=NULL) {
-			if (i == atoi(argv[5])-1) break;
+			if (i == location) break;
 			i++;
 		}
-		if (i != atoi(argv[5])-1 || Backup.ToDo[i] == NULL) {
+		if (i != location || Backup.ToDo[i] == NULL) {
 			printf("%s\n", _("Todo note not found in file"));
 			GSM_FreeBackup(&Backup);
-			Terminate(3);
+			Terminate(2);
 		}
-		j = 0;
-		error = GSM_EncodeVTODO(Buffer, sizeof(Buffer), &j, Backup.ToDo[i], TRUE, Nokia_VToDo);
+		error = GSM_EncodeVTODO(Buffer, sizeof(Buffer), &data_size, Backup.ToDo[i], TRUE, Nokia_VToDo);
 		GSM_FreeBackup(&Backup);
 		Print_Error(error);
 	} else if (strcasecmp(argv[2],"VCARD10") == 0 || strcasecmp(argv[2],"VCARD21") == 0) {
 		if (argc<6) {
 			printf("%s\n", _("Where is backup filename and location and memory type?"));
-			Terminate(3);
+			Terminate(2);
 		}
+		location = GetInt(argv[6]) - 1;
 		error=GSM_ReadBackupFile(argv[4],&Backup,GSM_GuessBackupFormat(argv[4], FALSE));
 		if (error!=ERR_NOTIMPLEMENTED) Print_Error(error);
 		i = 0;
 		if (strcasecmp(argv[5],"SM") == 0) {
 			while (Backup.SIMPhonebook[i]!=NULL) {
-				if (i == atoi(argv[6])-1) break;
+				if (i == location) break;
 				i++;
 			}
-			if (i != atoi(argv[6])-1 || Backup.SIMPhonebook[i] == NULL) {
+			if (i != location || Backup.SIMPhonebook[i] == NULL) {
 				printf("%s\n", _("Phonebook entry not found in file"));
 				GSM_FreeBackup(&Backup);
-				Terminate(3);
+				Terminate(2);
 			}
 			pbk = Backup.SIMPhonebook[i];
 		} else if (strcasecmp(argv[5],"ME") == 0) {
 			while (Backup.PhonePhonebook[i]!=NULL) {
-				if (i == atoi(argv[6])-1) break;
+				if (i == location) break;
 				i++;
 			}
-			if (i != atoi(argv[6])-1 || Backup.PhonePhonebook[i] == NULL) {
+			if (i != location || Backup.PhonePhonebook[i] == NULL) {
 				printf("%s\n", _("Phonebook entry not found in file"));
 				GSM_FreeBackup(&Backup);
-				Terminate(3);
+				Terminate(2);
 			}
 			pbk = Backup.PhonePhonebook[i];
 		} else {
 			printf(_("Unknown memory type: \"%s\"\n"),argv[5]);
 			GSM_FreeBackup(&Backup);
-			Terminate(3);
+			Terminate(2);
 		}
-		j = 0;
 		if (strcasecmp(argv[2],"VCARD10") == 0) {
-			error = GSM_EncodeVCARD(GSM_GetDebug(gsm), Buffer, sizeof(Buffer), &j, pbk, TRUE, Nokia_VCard10);
+			error = GSM_EncodeVCARD(GSM_GetDebug(gsm), Buffer, sizeof(Buffer), &data_size, pbk, TRUE, Nokia_VCard10);
 			GSM_FreeBackup(&Backup);
 			Print_Error(error);
 		} else {
-			error = GSM_EncodeVCARD(GSM_GetDebug(gsm), Buffer, sizeof(Buffer), &j, pbk, TRUE, Nokia_VCard21);
+			error = GSM_EncodeVCARD(GSM_GetDebug(gsm), Buffer, sizeof(Buffer), &data_size, pbk, TRUE, Nokia_VCard21);
 			GSM_FreeBackup(&Backup);
 			Print_Error(error);
 		}
 	} else {
 		printf(_("Unknown backup format: \"%s\"\n"), argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	file = fopen(argv[3],"wb");
 	if (file == NULL) {
-		printf_err(_("Error while opening file for writing!\n"));
+		printf_err("%s", _("Error while opening file for writing!\n"));
 		Terminate(3);
 	}
-	if (j != fwrite(Buffer,1,j,file)) {
-		printf_err(_("Error while writing file!\n"));
+	if (data_size != fwrite(Buffer,1,data_size,file)) {
+		printf_err("%s", _("Error while writing file!\n"));
 	}
-	fclose(file);
+	if (fclose(file) != 0) {
+		printf_err("%s", _("Error while closing file!\n"));
+	}
+}
+
+/**
+ * Reads phone phonebook, optionally asking question whether to read it.
+ */
+GSM_Error ReadPhonebook(GSM_MemoryEntry **Phonebook, GSM_MemoryType MemoryType, const char *question, int max_entries)
+{
+	GSM_MemoryStatus MemStatus;
+	GSM_MemoryEntry Pbk;
+	GSM_Error error;
+	gboolean UseNext = FALSE;
+	int i, used;
+
+	MemStatus.MemoryType = MemoryType;
+	Pbk.MemoryType  = MemoryType;
+	Pbk.Location = 0;
+
+	UseNext = FALSE;
+	error = GSM_GetMemoryStatus(gsm, &MemStatus);
+	if (error == ERR_NONE) {
+		if (MemStatus.MemoryUsed == 0) {
+			return ERR_NONE;
+		}
+	} else {
+		UseNext = TRUE;
+		error = GSM_GetNextMemory(gsm, &Pbk, TRUE);
+		if (error != ERR_NONE) {
+			return error;
+		}
+
+	}
+	/* Optionally ask question */
+	if (question != NULL && !answer_yes("   %s", question)) {
+		return ERR_NONE;
+	}
+
+	if (UseNext) {
+		used 		= 0;
+		fprintf(stderr, LISTFORMAT, _("Reading"));
+		error = ERR_NONE;
+		while (error == ERR_NONE) {
+			if (used >= max_entries) {
+				printf("\n   %s\n", _("Only part of data saved, please increase the limit."));
+				break;
+			}
+			Phonebook[used] = malloc(sizeof(GSM_MemoryEntry));
+			if (Phonebook[used] == NULL) {
+				Print_Error(ERR_MOREMEMORY);
+			}
+			Phonebook[used+1] = NULL;
+			*Phonebook[used] = Pbk;
+			used++;
+			error = GSM_GetNextMemory(gsm, &Pbk, FALSE);
+			fprintf(stderr, "*");
+			if (gshutdown) {
+				GSM_Terminate();
+				Terminate(4);
+			}
+		}
+		fprintf(stderr, "\n");
+		fflush(stderr);
+	} else {
+		i		= 1;
+		used 		= 0;
+		while (used < MemStatus.MemoryUsed) {
+			Pbk.Location = i;
+			error = GSM_GetMemory(gsm, &Pbk);
+			if (error != ERR_EMPTY) {
+				Print_Error(error);
+				if (used >= max_entries) {
+					printf("\n   %s\n", _("Only part of data saved, please increase the limit."));
+					break;
+				}
+				Phonebook[used] = malloc(sizeof(GSM_MemoryEntry));
+				if (Phonebook[used] == NULL) {
+					Print_Error(ERR_MOREMEMORY);
+				}
+				Phonebook[used+1] = NULL;
+				*Phonebook[used] = Pbk;
+				used++;
+			}
+			fprintf(stderr, "\r   ");
+			fprintf(stderr, "%s ", _("Reading:"));
+			fprintf(stderr, _("%i percent"),
+				used * 100 / MemStatus.MemoryUsed);
+			i++;
+			if (gshutdown) {
+				GSM_Terminate();
+				Terminate(4);
+			}
+		}
+		fprintf(stderr, "\n");
+		fflush(stderr);
+	}
+	return ERR_NONE;
 }
 
 void DoBackup(int argc, char *argv[])
 {
 	GSM_Error error = ERR_NONE;
 	int			i, used;
-	GSM_MemoryStatus	MemStatus;
 	GSM_ToDoEntry		ToDo;
 	GSM_ToDoStatus		ToDoStatus;
-	GSM_MemoryEntry		Pbk;
 	GSM_CalendarEntry	Calendar;
 	GSM_Bitmap		Bitmap;
 	GSM_WAPBookmark		Bookmark;
@@ -194,7 +295,6 @@ void DoBackup(int argc, char *argv[])
  	GSM_FMStation		FMStation;
  	GSM_GPRSAccessPoint	GPRSPoint;
 	gboolean			DoBackupPart;
-	gboolean			UseNext = FALSE;
 	char buffer[GSM_MAX_INFO_LENGTH];
 
 	if (argc == 4 && strcasecmp(argv[3],"-yes") == 0) always_answer_yes = TRUE;
@@ -218,7 +318,7 @@ void DoBackup(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 	if (Info.UseUnicode) {
-		Info.UseUnicode=answer_yes(_("Use Unicode subformat of backup file?"));
+		Info.UseUnicode=answer_yes("%s", _("Use Unicode subformat of backup file?"));
 	}
 	if (Info.DateTime) {
 		GSM_GetCurrentDateTime (&Backup.DateTime);
@@ -249,136 +349,16 @@ void DoBackup(int argc, char *argv[])
 	}
 	printf("\n");
 
-	DoBackupPart = FALSE;
 	if (Info.PhonePhonebook) {
 		printf("%s\n", _("Checking phone phonebook"));
-		MemStatus.MemoryType = MEM_ME;
-		Pbk.MemoryType  = MEM_ME;
-		Pbk.Location = 0;
-		UseNext = FALSE;
-		error = GSM_GetMemoryStatus(gsm, &MemStatus);
-		if (error == ERR_NONE) {
-			if (MemStatus.MemoryUsed != 0) {
-				DoBackupPart = TRUE;
-			}
-		} else {
-			UseNext = TRUE;
-			error = GSM_GetNextMemory(gsm, &Pbk, TRUE);
-			if (error == ERR_NONE) {
-				DoBackupPart = TRUE;
-			}
+		ReadPhonebook(Backup.PhonePhonebook, MEM_ME, _("Backup phone phonebook?"), GSM_BACKUP_MAX_PHONEPHONEBOOK);
+	}
 
-		}
-		if (DoBackupPart) {
-			if (answer_yes("   %s", _("Backup phone phonebook?"))) DoBackupPart = TRUE;
-			else DoBackupPart = FALSE;
-		}
-	}
-	if (DoBackupPart) {
-		if (UseNext) {
-			used 		= 0;
-			fprintf(stderr, LISTFORMAT, _("Reading"));
-			error = ERR_NONE;
-			while (error == ERR_NONE) {
-				if (used < GSM_BACKUP_MAX_PHONEPHONEBOOK) {
-					Backup.PhonePhonebook[used] = malloc(sizeof(GSM_MemoryEntry));
-					if (Backup.PhonePhonebook[used] == NULL) Print_Error(ERR_MOREMEMORY);
-					Backup.PhonePhonebook[used+1] = NULL;
-				} else {
-					printf("\n   ");
-					printf(_("Only part of data saved, please increase %s.") , "GSM_BACKUP_MAX_PHONEPHONEBOOK");
-					printf("\n");
-					break;
-				}
-				*Backup.PhonePhonebook[used]=Pbk;
-				used++;
-				error = GSM_GetNextMemory(gsm, &Pbk, FALSE);
-				fprintf(stderr, "*");
-				if (gshutdown) {
-					GSM_Terminate();
-					Terminate(0);
-				}
-			}
-			fprintf(stderr, "\n");
-			fflush(stderr);
-		} else {
-			Pbk.MemoryType  = MEM_ME;
-			i		= 1;
-			used 		= 0;
-			while (used != MemStatus.MemoryUsed) {
-				Pbk.Location = i;
-				error=GSM_GetMemory(gsm, &Pbk);
-				if (error != ERR_EMPTY) {
-					Print_Error(error);
-					if (used < GSM_BACKUP_MAX_PHONEPHONEBOOK) {
-						Backup.PhonePhonebook[used] = malloc(sizeof(GSM_MemoryEntry));
-						if (Backup.PhonePhonebook[used] == NULL) Print_Error(ERR_MOREMEMORY);
-						Backup.PhonePhonebook[used+1] = NULL;
-					} else {
-						printf("\n   ");
-						printf(_("Only part of data saved, please increase %s.") , "GSM_BACKUP_MAX_PHONEPHONEBOOK");
-						printf("\n");
-						break;
-					}
-					*Backup.PhonePhonebook[used]=Pbk;
-					used++;
-				}
-				fprintf(stderr, "\r   ");
-				fprintf(stderr, "%s ", _("Reading:"));
-				fprintf(stderr, _("%i percent"),
-					used * 100 / MemStatus.MemoryUsed);
-				i++;
-				if (gshutdown) {
-					GSM_Terminate();
-					Terminate(0);
-				}
-			}
-			fprintf(stderr, "\n");
-		}
-	}
-	DoBackupPart = FALSE;
 	if (Info.SIMPhonebook) {
 		printf("%s\n", _("Checking SIM phonebook"));
-		MemStatus.MemoryType = MEM_SM;
-		error=GSM_GetMemoryStatus(gsm, &MemStatus);
-		if (error==ERR_NONE && MemStatus.MemoryUsed != 0) {
-			if (answer_yes("   %s", _("Backup SIM phonebook?"))) DoBackupPart=TRUE;
-		}
-	}
-	if (DoBackupPart) {
-		Pbk.MemoryType 	= MEM_SM;
-		i		= 1;
-		used 		= 0;
-		while (used != MemStatus.MemoryUsed) {
-			Pbk.Location = i;
-			error=GSM_GetMemory(gsm, &Pbk);
-			if (error != ERR_EMPTY) {
-				Print_Error(error);
-				if (used < GSM_BACKUP_MAX_SIMPHONEBOOK) {
-					Backup.SIMPhonebook[used] = malloc(sizeof(GSM_MemoryEntry));
-				        if (Backup.SIMPhonebook[used] == NULL) Print_Error(ERR_MOREMEMORY);
-					Backup.SIMPhonebook[used + 1] = NULL;
-				} else {
-					printf("\n   ");
-					printf(_("Only part of data saved, please increase %s.") , "GSM_BACKUP_MAX_SIMPHONEBOOK");
-					printf("\n");
-					break;
-				}
-				*Backup.SIMPhonebook[used]=Pbk;
-				used++;
-			}
-			fprintf(stderr, "\r   ");
-			fprintf(stderr, "%s ", _("Reading:"));
-			fprintf(stderr, _("%i percent"),
-				used * 100 / MemStatus.MemoryUsed);
-			i++;
-			if (gshutdown) {
-				GSM_Terminate();
-				Terminate(0);
-			}
-		}
-		fprintf(stderr, "\n");
+		ReadPhonebook(Backup.SIMPhonebook, MEM_SM, _("Backup SIM phonebook?"), GSM_BACKUP_MAX_SIMPHONEBOOK);
 	}
+
 	DoBackupPart = FALSE;
 	if (Info.Calendar) {
 		printf("%s\n", _("Checking phone calendar"));
@@ -408,7 +388,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -446,7 +426,7 @@ void DoBackup(int argc, char *argv[])
 				used * 100 / ToDoStatus.Used);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -480,7 +460,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -518,7 +498,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -619,7 +599,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -656,7 +636,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -693,7 +673,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -730,7 +710,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -766,7 +746,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -809,7 +789,7 @@ void DoBackup(int argc, char *argv[])
 			fprintf(stderr, "*");
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -973,6 +953,7 @@ void Restore(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 	printf("%s\n", _("Please note that restoring data will cause existing data in phone to be deleted."));
+	printf("%s\n", _("Use addnew command if you just want to add some entries to your phone."));
 
 	DoRestore = FALSE;
 	if (Backup.CallerLogos[0] != NULL) {
@@ -980,7 +961,7 @@ void Restore(int argc, char *argv[])
 		Bitmap.Location = 1;
 		error=GSM_GetBitmap(gsm,&Bitmap);
 		if (error == ERR_NONE) {
-			if (answer_yes(_("Restore phone caller groups and logos?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone caller groups and logos?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -995,7 +976,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1003,13 +984,21 @@ void Restore(int argc, char *argv[])
 
 	DoRestore = FALSE;
 	if (Backup.PhonePhonebook[0] != NULL) {
+		max = 0;
+		while (Backup.PhonePhonebook[max]!=NULL) max++;
 		MemStatus.MemoryType = MEM_ME;
 		error=GSM_GetMemoryStatus(gsm, &MemStatus);
-		if (error==ERR_NONE) {
-			max = 0;
-			while (Backup.PhonePhonebook[max]!=NULL) max++;
+		/* Some phones do not support status, try reading some entry */
+		if (error != ERR_NONE) {
+			Pbk.Location = 1;
+			Pbk.MemoryType = MEM_ME;
+			error = GSM_GetMemory(gsm, &Pbk);
+			MemStatus.MemoryUsed = max;
+			MemStatus.MemoryFree = max;
+		}
+		if (error == ERR_NONE || error == ERR_EMPTY) {
 			fprintf(stderr, _("%i entries in backup file\n"),max);
-			if (answer_yes(_("Restore phone phonebook?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone phonebook?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1029,8 +1018,8 @@ void Restore(int argc, char *argv[])
 				}
 				if (error == ERR_MEMORY && GSM_IsPhoneFeatureAvailable(GSM_GetModelInfo(gsm), F_6230iCALLER)) {
 					printf_err("%s\n", _("Probably caller group is missing from your backup, add it and use --restore again."));
-					GSM_TerminateConnection(gsm);
-					exit (-1);
+					GSM_Terminate();
+					Terminate(2);
 				}
 				if (Pbk.EntriesNum != 0 && error==ERR_NONE) {
 					First = TRUE;
@@ -1063,7 +1052,7 @@ void Restore(int argc, char *argv[])
 					);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1077,7 +1066,7 @@ void Restore(int argc, char *argv[])
 			max = 0;
 			while (Backup.SIMPhonebook[max]!=NULL) max++;
 			fprintf(stderr, _("%i entries in backup file\n"),max);
-			if (answer_yes(_("Restore SIM phonebook?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore SIM phonebook?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1115,14 +1104,14 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / (MemStatus.MemoryUsed + MemStatus.MemoryFree));
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
 	}
 
-	if (!strcasecmp(GSM_GetConfig(gsm, -1)->SyncTime,"yes") == 0) {
-		if (answer_yes(_("Do you want to set phone date/time? (NOTE: in some phones it's required to correctly restore calendar notes and other items)"))) {
+	if (GSM_GetConfig(gsm, -1)->SyncTime == FALSE) {
+		if (answer_yes("%s", _("Do you want to set phone date/time? (NOTE: in some phones it's required to correctly restore calendar notes and other items)"))) {
 			GSM_GetCurrentDateTime(&date_time);
 
 			error=GSM_SetDateTime(gsm, &date_time);
@@ -1138,7 +1127,7 @@ void Restore(int argc, char *argv[])
 			max = 0;
 			while (Backup.Calendar[max] != NULL) max++;
 			fprintf(stderr, _("%i entries in backup file\n"),max);
-			if (answer_yes(_("Restore phone calendar notes?"))) {
+			if (answer_yes("%s", _("Restore phone calendar notes?"))) {
 				Past    = answer_yes("   %s", _("Restore notes from the past?"));
 				DoRestore = TRUE;
 			}
@@ -1173,7 +1162,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1187,7 +1176,7 @@ void Restore(int argc, char *argv[])
 			while (Backup.ToDo[max]!=NULL) max++;
 			fprintf(stderr, _("%i entries in backup file\n"),max);
 
-			if (answer_yes(_("Restore phone todo?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone todo?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1222,7 +1211,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1250,7 +1239,7 @@ void Restore(int argc, char *argv[])
 				used * 100 / ToDoStatus.Used);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1266,7 +1255,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1280,7 +1269,7 @@ void Restore(int argc, char *argv[])
 			while (Backup.Note[max]!=NULL) max++;
 			fprintf(stderr, _("%i entries in backup file\n"),max);
 
-			if (answer_yes(_("Restore phone notes?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone notes?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1305,13 +1294,13 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
 	}
 
-	if (Backup.SMSC[0] != NULL && answer_yes(_("Restore SIM SMSC profiles?"))) {
+	if (Backup.SMSC[0] != NULL && answer_yes("%s", _("Restore SIM SMSC profiles?"))) {
 		max = 0;
 		while (Backup.SMSC[max]!=NULL) max++;
 		for (i=0;i<max;i++) {
@@ -1323,16 +1312,16 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
 	}
-	if (Backup.StartupLogo != NULL && answer_yes(_("Restore phone startup logo/text?"))) {
+	if (Backup.StartupLogo != NULL && answer_yes("%s", _("Restore phone startup logo/text?"))) {
 		error=GSM_SetBitmap(gsm,Backup.StartupLogo);
 		Print_Error(error);
 	}
-	if (Backup.OperatorLogo != NULL && answer_yes(_("Restore phone operator logo?"))) {
+	if (Backup.OperatorLogo != NULL && answer_yes("%s", _("Restore phone operator logo?"))) {
 		error=GSM_SetBitmap(gsm,Backup.OperatorLogo);
 		Print_Error(error);
 	}
@@ -1341,7 +1330,7 @@ void Restore(int argc, char *argv[])
 		Bookmark.Location = 1;
 		error = GSM_GetWAPBookmark(gsm,&Bookmark);
 		if (error == ERR_NONE || error == ERR_INVALIDLOCATION) {
-			if (answer_yes(_("Restore phone WAP bookmarks?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone WAP bookmarks?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1372,7 +1361,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1382,7 +1371,7 @@ void Restore(int argc, char *argv[])
 		Settings.Location = 1;
 		error = GSM_GetWAPSettings(gsm,&Settings);
 		if (error == ERR_NONE) {
-			if (answer_yes(_("Restore phone WAP settings?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone WAP settings?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1397,7 +1386,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1407,7 +1396,7 @@ void Restore(int argc, char *argv[])
 		Settings.Location = 1;
 		error = GSM_GetMMSSettings(gsm,&Settings);
 		if (error == ERR_NONE) {
-			if (answer_yes(_("Restore phone MMS settings?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone MMS settings?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1422,7 +1411,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1433,7 +1422,7 @@ void Restore(int argc, char *argv[])
 		Ringtone.Format		= 0;
 		error = GSM_GetRingtone(gsm,&Ringtone,FALSE);
 		if (error == ERR_NONE || error ==ERR_EMPTY) {
-			if (answer_yes(_("Delete all phone user ringtones?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Delete all phone user ringtones?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1442,7 +1431,7 @@ void Restore(int argc, char *argv[])
 		Print_Error(error);
 		fprintf(stderr, "%s\n", _("Done"));
 		DoRestore = FALSE;
-		if (answer_yes(_("Restore user ringtones?"))) DoRestore = TRUE;
+		if (answer_yes("%s", _("Restore user ringtones?"))) DoRestore = TRUE;
 	}
 	if (DoRestore) {
 		max = 0;
@@ -1458,7 +1447,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1468,7 +1457,7 @@ void Restore(int argc, char *argv[])
 		Profile.Location = 1;
 		error = GSM_GetProfile(gsm,&Profile);
 		if (error == ERR_NONE) {
-			if (answer_yes(_("Restore phone profiles?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone profiles?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1481,7 +1470,7 @@ void Restore(int argc, char *argv[])
 			Print_Error(error);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1491,7 +1480,7 @@ void Restore(int argc, char *argv[])
 		FMStation.Location = 1;
 		error = GSM_GetFMStation(gsm,&FMStation);
 		if (error == ERR_NONE || error == ERR_EMPTY) {
-			if (answer_yes(_("Restore phone FM radio stations?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone FM radio stations?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1511,7 +1500,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1521,7 +1510,7 @@ void Restore(int argc, char *argv[])
 		GPRSPoint.Location = 1;
 		error = GSM_GetGPRSAccessPoint(gsm,&GPRSPoint);
 		if (error == ERR_NONE || error == ERR_EMPTY) {
-			if (answer_yes(_("Restore phone GPRS Points?"))) DoRestore = TRUE;
+			if (answer_yes("%s", _("Restore phone GPRS Points?"))) DoRestore = TRUE;
 		}
 	}
 	if (DoRestore) {
@@ -1536,7 +1525,7 @@ void Restore(int argc, char *argv[])
 				(i + 1) * 100 / max);
 			if (gshutdown) {
 				GSM_Terminate();
-				Terminate(0);
+				Terminate(4);
 			}
 		}
 		fprintf(stderr, "\n");
@@ -1557,35 +1546,66 @@ void AddNew(int argc, char *argv[])
 	GSM_ToDoStatus		ToDoStatus;
 	GSM_CalendarEntry	Calendar;
 	GSM_WAPBookmark		Bookmark;
+	GSM_MemoryType		MemoryType = 0;
 	int			i, max;
 
 	error=GSM_ReadBackupFile(argv[2],&Backup,GSM_GuessBackupFormat(argv[2], FALSE));
 	if (error!=ERR_NOTIMPLEMENTED) Print_Error(error);
 
+	if (Backup.DateTimeAvailable) {
+		fprintf(stderr, LISTFORMAT "%s\n", _("Time of backup"),OSDateTime(Backup.DateTime,FALSE));
+	}
+	if (Backup.Model[0]!=0) {
+		fprintf(stderr, LISTFORMAT "%s\n", _("Phone"),Backup.Model);
+	}
+	if (Backup.IMEI[0]!=0) {
+		fprintf(stderr, LISTFORMAT "%s\n", _("IMEI"),Backup.IMEI);
+	}
+
+	for (i = 3; i < argc; i++) {
+		if (strcasecmp(argv[i],"-yes") == 0) {
+			always_answer_yes = TRUE;
+		} else if (strcasecmp(argv[i],"-memory") == 0 && i + 1 < argc) {
+			i++;
+			MemoryType = GSM_StringToMemoryType(argv[i]);
+			if (MemoryType == 0) {
+				printf_err(_("Unknown memory type (\"%s\")\n"),argv[i]);
+				Terminate(2);
+			}
+		} else {
+			printf_err(_("Unknown parameter (\"%s\")\n"), argv[i]);
+			Terminate(2);
+		}
+	}
+
 	signal(SIGINT, interrupt);
 	fprintf(stderr, "%s\n", _("Press Ctrl+C to break..."));
 
-	if (Backup.DateTimeAvailable) 	fprintf(stderr, LISTFORMAT "%s\n", _("Time of backup"),OSDateTime(Backup.DateTime,FALSE));
-	if (Backup.Model[0]!=0) 	fprintf(stderr, LISTFORMAT "%s\n", _("Phone"),Backup.Model);
-	if (Backup.IMEI[0]!=0) 		fprintf(stderr, LISTFORMAT "%s\n", _("IMEI"),Backup.IMEI);
-
-	if (argc == 4 && strcasecmp(argv[3],"-yes") == 0) always_answer_yes = TRUE;
 
 	GSM_Init(TRUE);
 
 	if (Backup.PhonePhonebook[0] != NULL) {
-		MemStatus.MemoryType = MEM_ME;
+		MemStatus.MemoryType = (MemoryType == 0 ? MEM_ME : MemoryType);
 		error=GSM_GetMemoryStatus(gsm, &MemStatus);
-		if (error==ERR_NONE) {
+		/* Some phones do not support status, try reading some entry */
+		if (error != ERR_NONE) {
+			Pbk.Location = 1;
+			Pbk.MemoryType = MEM_ME;
+			error = GSM_GetMemory(gsm, &Pbk);
+			MemStatus.MemoryFree = 9999999;
+		}
+		if (error == ERR_NONE || error == ERR_EMPTY) {
 			max = 0;
-			while (Backup.PhonePhonebook[max]!=NULL) max++;
-			fprintf(stderr, _("%i entries in backup file\n"),max);
+			while (Backup.PhonePhonebook[max] != NULL) {
+				max++;
+			}
+			fprintf(stderr, _("%i entries in backup file\n"), max);
 			if (MemStatus.MemoryFree < max) {
-				fprintf(stderr, _("Memory has only %i free locations.Exiting\n"),MemStatus.MemoryFree);
-			} else if (answer_yes(_("Add phone phonebook entries?"))) {
-				for (i=0;i<max;i++) {
+				fprintf(stderr, _("Memory has only %i free locations.Exiting\n"), MemStatus.MemoryFree);
+			} else if (answer_yes("%s", _("Add phone phonebook entries?"))) {
+				for (i = 0; i < max; i++) {
 					Pbk 		= *Backup.PhonePhonebook[i];
-					Pbk.MemoryType 	= MEM_ME;
+					Pbk.MemoryType 	= (MemoryType == 0 ? MEM_ME : MemoryType);
 					error=GSM_AddMemory(gsm, &Pbk);
 					Print_Error(error);
 					fprintf(stderr, "\r");
@@ -1594,7 +1614,7 @@ void AddNew(int argc, char *argv[])
 						(i + 1) * 100 / max);
 					if (gshutdown) {
 						GSM_Terminate();
-						Terminate(0);
+						Terminate(4);
 					}
 				}
 				fprintf(stderr, "\n");
@@ -1602,7 +1622,7 @@ void AddNew(int argc, char *argv[])
 		}
 	}
 	if (Backup.SIMPhonebook[0] != NULL) {
-		MemStatus.MemoryType = MEM_SM;
+		MemStatus.MemoryType = (MemoryType == 0 ? MEM_SM : MemoryType);
 		error=GSM_GetMemoryStatus(gsm, &MemStatus);
 		if (error==ERR_NONE) {
 			max = 0;
@@ -1610,10 +1630,10 @@ void AddNew(int argc, char *argv[])
 			fprintf(stderr, _("%i entries in backup file\n"),max);
 			if (MemStatus.MemoryFree < max) {
 				fprintf(stderr, _("Memory has only %i free locations.Exiting\n"),MemStatus.MemoryFree);
-			} else if (answer_yes(_("Add SIM phonebook entries?"))) {
+			} else if (answer_yes("%s", _("Add SIM phonebook entries?"))) {
 				for (i=0;i<max;i++) {
 					Pbk 		= *Backup.SIMPhonebook[i];
-					Pbk.MemoryType 	= MEM_SM;
+					Pbk.MemoryType 	= (MemoryType == 0 ? MEM_SM : MemoryType);
 					error=GSM_AddMemory(gsm, &Pbk);
 					Print_Error(error);
 					fprintf(stderr, "\r");
@@ -1622,7 +1642,7 @@ void AddNew(int argc, char *argv[])
 						(i + 1) * 100 / max);
 					if (gshutdown) {
 						GSM_Terminate();
-						Terminate(0);
+						Terminate(4);
 					}
 				}
 				fprintf(stderr, "\n");
@@ -1630,8 +1650,8 @@ void AddNew(int argc, char *argv[])
 		}
 	}
 
-	if (!strcasecmp(GSM_GetConfig(gsm, -1)->SyncTime,"yes") == 0) {
-		if (answer_yes(_("Do you want to set phone date/time? (NOTE: in some phones it's required to correctly restore calendar notes and other items)"))) {
+	if (GSM_GetConfig(gsm, -1)->SyncTime == FALSE) {
+		if (answer_yes("%s", _("Do you want to set phone date/time? (NOTE: in some phones it's required to correctly restore calendar notes and other items)"))) {
 			GSM_GetCurrentDateTime(&date_time);
 
 			error=GSM_SetDateTime(gsm, &date_time);
@@ -1642,7 +1662,7 @@ void AddNew(int argc, char *argv[])
 		Calendar.Location = 1;
 		error = GSM_GetNextCalendar(gsm,&Calendar,TRUE);
 		if (error == ERR_NONE || error == ERR_INVALIDLOCATION || error == ERR_EMPTY) {
-			if (answer_yes(_("Add phone calendar notes?"))) {
+			if (answer_yes("%s", _("Add phone calendar notes?"))) {
 				max = 0;
 				while (Backup.Calendar[max]!=NULL) max++;
 				for (i=0;i<max;i++) {
@@ -1655,7 +1675,7 @@ void AddNew(int argc, char *argv[])
 						(i + 1) * 100 / max);
 					if (gshutdown) {
 						GSM_Terminate();
-						Terminate(0);
+						Terminate(4);
 					}
 				}
 				fprintf(stderr, "\n");
@@ -1666,7 +1686,7 @@ void AddNew(int argc, char *argv[])
 		ToDo.Location = 1;
 		error=GSM_GetToDoStatus(gsm,&ToDoStatus);
 		if (error == ERR_NONE) {
-			if (answer_yes(_("Add phone ToDo?"))) {
+			if (answer_yes("%s", _("Add phone ToDo?"))) {
 				max = 0;
 				while (Backup.ToDo[max]!=NULL) max++;
 				for (i=0;i<max;i++) {
@@ -1679,7 +1699,7 @@ void AddNew(int argc, char *argv[])
 						(i + 1) * 100 / max);
 					if (gshutdown) {
 						GSM_Terminate();
-						Terminate(0);
+						Terminate(4);
 					}
 				}
 				fprintf(stderr, "\n");
@@ -1690,7 +1710,7 @@ void AddNew(int argc, char *argv[])
 		Bookmark.Location = 1;
 		error = GSM_GetWAPBookmark(gsm,&Bookmark);
 		if (error == ERR_NONE || error == ERR_INVALIDLOCATION) {
-			if (answer_yes(_("Add phone WAP bookmarks?"))) {
+			if (answer_yes("%s", _("Add phone WAP bookmarks?"))) {
 				max = 0;
 				while (Backup.WAPBookmark[max]!=NULL) max++;
 				for (i=0;i<max;i++) {
@@ -1704,7 +1724,7 @@ void AddNew(int argc, char *argv[])
 						(i + 1) * 100 / max);
 					if (gshutdown) {
 						GSM_Terminate();
-						Terminate(0);
+						Terminate(4);
 					}
 				}
 				fprintf(stderr, "\n");
