@@ -12,6 +12,7 @@
 #include "calendar.h"
 
 #include "../helper/formats.h"
+#include "../helper/cmdline.h"
 
 void PrintCalendar(GSM_CalendarEntry * Note)
 {
@@ -299,7 +300,7 @@ void PrintCalendar(GSM_CalendarEntry * Note)
 			       repeat_count);
 		}
 		if ((repeat_startdate.Day == 0) && (repeat_stopdate.Day == 0)) {
-			printf(_("forever"));
+			printf("%s", _("forever"));
 		} else if (repeat_startdate.Day == 0) {
 			printf(_("till %s"), OSDate(repeat_stopdate));
 		} else if (repeat_stopdate.Day == 0) {
@@ -310,7 +311,7 @@ void PrintCalendar(GSM_CalendarEntry * Note)
 		}
 		if (repeat_frequency != -1) {
 			if (repeat_frequency == 1) {
-				printf(_(" on each "));
+				printf("%s", _(" on each "));
 			} else {
 				printf(_(" on each %d. "), repeat_frequency);
 			}
@@ -320,13 +321,13 @@ void PrintCalendar(GSM_CalendarEntry * Note)
 					printf(_(" in %d. week of "),
 					       repeat_weekofmonth);
 				} else {
-					printf(_(" in "));
+					printf("%s", _(" in "));
 				}
 				if (repeat_month > 0) {
 					printf("%s",
 					       GetMonthName(repeat_month));
 				} else {
-					printf(_("each month"));
+					printf("%s", _("each month"));
 				}
 			} else if (repeat_day > 0) {
 				printf(_("%d. day of "), repeat_day);
@@ -334,12 +335,12 @@ void PrintCalendar(GSM_CalendarEntry * Note)
 					printf("%s",
 					       GetMonthName(repeat_month));
 				} else {
-					printf(_("each month"));
+					printf("%s", _("each month"));
 				}
 			} else if (repeat_dayofyear > 0) {
 				printf(_("%d. day of year"), repeat_dayofyear);
 			} else {
-				printf(_("day"));
+				printf("%s", _("day"));
 			}
 		}
 		printf("\n");
@@ -391,7 +392,7 @@ void GetDateTime(int argc UNUSED, char *argv[]UNUSED)
 			break;
 		default:
 			Print_Error(error);
-			printf(_("Time format is "));
+			printf("%s", _("Time format is "));
 			if (locale.AMPMTime) {
 				/* l10n: AM/PM time */
 				printf("%s\n", _("12 hours"));
@@ -399,31 +400,31 @@ void GetDateTime(int argc UNUSED, char *argv[]UNUSED)
 				/* l10n: 24 hours time */
 				printf("%s\n", _("24 hours"));
 			}
-			printf(_("Date format is "));
+			printf("%s", _("Date format is "));
 			switch (locale.DateFormat) {
 				case GSM_Date_DDMMYYYY:
-					printf(_("DD MM YYYY"));
+					printf("%s", _("DD MM YYYY"));
 					break;
 				case GSM_Date_MMDDYYYY:
-					printf(_("MM DD YYYY"));
+					printf("%s", _("MM DD YYYY"));
 					break;
 				case GSM_Date_YYYYMMDD:
-					printf(_("YYYY MM DD"));
+					printf("%s", _("YYYY MM DD"));
 					break;
 				case GSM_Date_DDMMMYY:
-					printf(_("DD MMM YY"));
+					printf("%s", _("DD MMM YY"));
 					break;
 				case GSM_Date_MMDDYY:
-					printf(_("MM DD YY"));
+					printf("%s", _("MM DD YY"));
 					break;
 				case GSM_Date_DDMMYY:
-					printf(_("DD MM YY"));
+					printf("%s", _("DD MM YY"));
 					break;
 				case GSM_Date_YYMMDD:
-					printf(_("YY MM DD"));
+					printf("%s", _("YY MM DD"));
 					break;
 				case GSM_Date_OFF:
-					printf(_("OFF"));
+					printf("%s", _("OFF"));
 					break;
 				default:
 					break;
@@ -438,14 +439,14 @@ void GetDateTime(int argc UNUSED, char *argv[]UNUSED)
 void SetDateTime(int argc, char *argv[])
 {
 	GSM_DateTime date_time;
-	char shift, *parse;
+	char shift, *parse, *parse2;
 	GSM_Error error;
 
 	GSM_Init(TRUE);
 	error = ERR_NONE;
 	if (argc < 3) {
 		/* set datetime to the current datetime in the PC */
-		printf("%s\n", _("Setting time in phone to the time on PC."));
+		printf("%s\n", _("Setting time in phone to the same time as is set in computer."));
 		GSM_GetCurrentDateTime(&date_time);
 	} else {
 		/* update only parts the user specified,
@@ -454,37 +455,48 @@ void SetDateTime(int argc, char *argv[])
 		Print_Error(error);
 
 		if (error == ERR_NONE) {
-			printf("%s\n",
-			       _
-			       ("Updating specified parts of date and time in phone."));
 			shift = 0;
+			error = ERR_INVALIDDATETIME;
 			parse = strchr(argv[2], ':');
 			if (parse != NULL) {
-				date_time.Hour = atoi(argv[2]);
-				date_time.Minute = atoi(parse + 1);
-				parse = strchr(parse + 1, ':');
-				if (parse != NULL) {
-					date_time.Second = atoi(parse + 1);
+				*parse = '\0';
+				date_time.Hour = GetInt(argv[2]);
+				parse2 = strchr(parse + 1, ':');
+				if (parse2 != NULL) {
+					*parse2 = '\0';
+					date_time.Second = GetInt(parse2 + 1);
 				}
+				date_time.Minute = GetInt(parse + 1);
 				shift = 1;
+				if (CheckTime(&date_time)) {
+					error = ERR_NONE;
+				} else {
+					error = ERR_INVALIDDATETIME;
+				}
 			}
 			if (argc - 1 >= 2 + shift) {
 				parse = strchr(argv[2 + shift], '/');
 				if (parse != NULL) {
-					date_time.Year = atoi(argv[2 + shift]);
-					date_time.Month = atoi(parse + 1);
-					parse = strchr(parse + 1, '/');
-					if (parse != NULL) {
-						date_time.Day = atoi(parse + 1);
+					*parse = '\0';
+					date_time.Year = GetInt(argv[2 + shift]);
+					parse2 = strchr(parse + 1, '/');
+					if (parse2 != NULL) {
+						*parse2 = '\0';
+						date_time.Day = GetInt(parse2 + 1);
+					}
+					date_time.Month = GetInt(parse + 1);
+					if (CheckDate(&date_time)) {
+						error = ERR_NONE;
+					} else {
+						error = ERR_INVALIDDATETIME;
 					}
 				}
 			}
-			if (!CheckDate(&date_time) || !CheckTime(&date_time))
-				error = ERR_INVALIDDATETIME;
 			/* we got the timezone from the phone */
 		}
 	}
 	if (error == ERR_NONE) {
+		printf("%s\n", _("Updating specified parts of date and time in phone."));
 		error = GSM_SetDateTime(gsm, &date_time);
 	}
 	Print_Error(error);
@@ -502,7 +514,7 @@ void GetAlarm(int argc, char *argv[])
 	if (argc < 3) {
 		Alarm.Location = 1;
 	} else {
-		Alarm.Location = atoi(argv[2]);
+		Alarm.Location = GetInt(argv[2]);
 	}
 	error = GSM_GetAlarm(gsm, &Alarm);
 	switch (error) {
@@ -538,8 +550,8 @@ void SetAlarm(int argc UNUSED, char *argv[])
 	GSM_Alarm Alarm;
 	GSM_Error error;
 
-	Alarm.DateTime.Hour = atoi(argv[2]);
-	Alarm.DateTime.Minute = atoi(argv[3]);
+	Alarm.DateTime.Hour = GetInt(argv[2]);
+	Alarm.DateTime.Minute = GetInt(argv[3]);
 	Alarm.DateTime.Second = 0;
 	Alarm.Location = 1;
 	Alarm.Repeating = TRUE;
@@ -633,7 +645,7 @@ void GetCalendarSettings(int argc UNUSED, char *argv[]UNUSED)
 	Print_Error(error);
 
 	if (settings.AutoDelete == 0) {
-		printf(_("Auto deleting disabled"));
+		printf("%s", _("Auto deleting disabled"));
 	} else {
 		printf(_("Auto deleting notes after %i day(s)"),
 		       settings.AutoDelete);
@@ -949,7 +961,7 @@ void ListToDoCategory(int argc UNUSED, char *argv[])
 	}
 
 	if (Number) {
-		j = atoi(argv[2]);
+		j = GetInt(argv[2]);
 		if (j > 0) {
 			ListToDoCategoryEntries(j);
 		}
