@@ -16,6 +16,7 @@
 
 #include "../../../helper/formats.h"
 #include "../../../helper/string.h"
+#include "../../../helper/cmdline.h"
 
 extern GSM_Reply_Function UserReplyFunctions4[];
 
@@ -52,7 +53,7 @@ GSM_Error CheckDCT4Only(void)
 	return ERR_NONE;
 }
 
-static void CheckDCT4(void)
+void CheckDCT4(void)
 {
 	GSM_Error error;
 
@@ -63,8 +64,8 @@ static void CheckDCT4(void)
 		break;
 	case ERR_OTHERCONNECTIONREQUIRED:
 		printf("%s\n", _("Can't do it with current phone protocol"));
-		GSM_TerminateConnection(gsm);
-		Terminate(3);
+		Print_Error(ERR_NOTSUPPORTED);
+		break;
 	default:
 		break;
 	}
@@ -78,7 +79,9 @@ static gboolean answer_yes2(const char *text)
 	while (1) {
 		printf(_("%s (yes/no) ? "),text);
 		len=GetLine(stdin, ans, 99);
-		if (len==-1) Terminate(3);
+		if (len==-1) {
+			Terminate(2);
+		}
 		if (strcasecmp(ans, _("yes")) == 0) return TRUE;
 		if (strcasecmp(ans, _("no")) == 0) return FALSE;
 	}
@@ -297,7 +300,7 @@ void DCT4SetPhoneMenus(int argc, char *argv[])
 	}
 
 	if (current == 10) {
-		printf("%s\n", _("Sorry, but configuration matrix for this model has not yet been added. See <http://cihar.com/gammu/report> for information how to report it."));
+		printf("%s\n", _("Sorry, but configuration matrix for this model has not yet been added. See <http://wammu.eu/support/bugs/> for information how to report it."));
 		return;
 	}
 
@@ -363,14 +366,14 @@ static GSM_Error DCT4_ReplyTestsStatus(GSM_Protocol_Message msg, GSM_StateMachin
 			if (DCT4Tests.Tests[j].ID == msg.Buffer[pos+2]) {
 				printf("\"%40s\" : ",DCT4Tests.Tests[j].Name);
 				switch(msg.Buffer[pos+3]) {
-					case 0x00: printf(_("Passed")); 		break;
-					case 0x01: printf(_("Fail"));   		break;
-					case 0x03: printf(_("Not executed")); 	break;
-					case 0x06: printf(_("No signal"));		break;
-					case 0x0D: printf(_("Timeout"));		break;
+					case 0x00: printf("%s", _("Passed")); 		break;
+					case 0x01: printf("%s", _("Fail"));   		break;
+					case 0x03: printf("%s", _("Not executed")); 	break;
+					case 0x06: printf("%s", _("No signal"));		break;
+					case 0x0D: printf("%s", _("Timeout"));		break;
 					default  : printf(_("Unknown (%x)"),msg.Buffer[pos+3]);
 				}
-				if (DCT4Tests.Tests[j].Startup) printf(_(" (startup)"));
+				if (DCT4Tests.Tests[j].Startup) printf("%s", _(" (startup)"));
 				printf("\n");
 				break;
 			}
@@ -457,7 +460,7 @@ void DCT4SetVibraLevel(int argc, char *argv[])
 
 	gsm->User.UserReplyFunctions=UserReplyFunctions4;
 
-	SetLevel[4] = atoi(argv[2]);
+	SetLevel[4] = GetInt(argv[2]);
 	error=GSM_WaitFor (gsm, SetLevel, 6, 0x1C, 4, ID_User3);
 	Print_Error(error);
 
@@ -679,7 +682,7 @@ void DCT4GetVoiceRecord(int argc, char *argv[])
 	FILE		*WAVFile;
 	GSM_Error error;
 
-	Location = atoi(argv[2]);
+	Location = GetInt(argv[2]);
 	if (Location == 0x00) {
 		printf("%s\n", _("Please enumerate locations from 1"));
 		return;
@@ -956,19 +959,18 @@ void DCT4SetLight(int argc, char *argv[])
 	} else if (strcasecmp(argv[2],"torch") == 0) {	type = N6510_LIGHT_TORCH;
 	} else {
 		printf(_("What lights should I enable (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	if (strcasecmp(argv[3],"on") == 0) { 		enable = TRUE;
 	} else if (strcasecmp(argv[3],"off") == 0) {	enable = FALSE;
 	} else {
 		printf(_("What should I do (\"%s\") ?\n"),argv[3]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	for (i=0;i<gsm->ConfigNum;i++) {
-		free(gsm->Config[i].StartInfo);
-		gsm->Config[i].StartInfo = strdup("FALSE");
+		gsm->Config[i].StartInfo = FALSE;
 	}
 
 	GSM_Init(TRUE);
@@ -998,7 +1000,7 @@ void DCT4DisplayTest(int argc, char *argv[])
 
 	gsm->Protocol.Functions->WriteMessage(gsm, req0, 6, 0x40);
 
-	req[8] = atoi(argv[2]);
+	req[8] = GetInt(argv[2]);
 	gsm->Protocol.Functions->WriteMessage(gsm, req, 10, 0x40);
 
 	printf("%s\n", _("Press any key to continue..."));
@@ -1262,13 +1264,13 @@ void DCT4PlaySavedRingtone(int argc, char *argv[])
 	error=GSM_GetRingtonesInfo(gsm,&Info);
 	Print_Error(error);
 
-	if (atoi(argv[2]) > Info.Number-1) {
+	if (GetInt(argv[2]) > Info.Number-1) {
 		GSM_Terminate();
 		return;
 	}
-	req[4] = Info.Ringtone[atoi(argv[2])-1].ID / 256;
-	req[5] = Info.Ringtone[atoi(argv[2])-1].ID % 256;
-	req[6] = Info.Ringtone[atoi(argv[2])-1].Group;
+	req[4] = Info.Ringtone[GetInt(argv[2])-1].ID / 256;
+	req[5] = Info.Ringtone[GetInt(argv[2])-1].ID % 256;
+	req[6] = Info.Ringtone[GetInt(argv[2])-1].Group;
 
 	error=GSM_WaitFor (gsm, req, 18, 0x1F, 4, ID_User3);
 	Print_Error(error);
@@ -1345,8 +1347,9 @@ void DCT4GetScreenDump(int argc, char *argv[])
 	error=GSM_WaitFor (gsm, req, 6, 0x0E, 4, ID_User3);
 	Print_Error(error);
 	len = 2000;
-	while (len >= 200) GSM_ReadDevice(gsm,TRUE);
-
+	while (len >= 200) {
+		GSM_ReadDevice(gsm,TRUE);
+	}
 	GSM_Terminate();
 }
 
@@ -1359,39 +1362,39 @@ static GSM_Error DCT4_ReplyGetPBKFeatures(GSM_Protocol_Message msg, GSM_StateMac
 	for (i=0;i<msg.Buffer[5]-1;i++) {
 		printf(_("  entry ID %02X"),msg.Buffer[pos+4]);
 		switch (msg.Buffer[pos+4]) {
-		case N7110_PBK_SIM_SPEEDDIAL	: printf(_(" (Speed dial on SIM)")); 			break;
-		case N7110_PBK_NAME	    	: printf(_(" (Text: name (always the only one))"));		break;
-		case N7110_PBK_EMAIL	    	: printf(_(" (Text: email address)"));			break;
-		case N7110_PBK_POSTAL	    	: printf(_(" (Text: postal address)"));			break;
-		case N7110_PBK_NOTE	    	: printf(_(" (Text: note)"));				break;
-		case N7110_PBK_NUMBER 	    	: printf(_(" (Phone number)"));				break;
-		case N7110_PBK_RINGTONE_ID  	: printf(_(" (Ringtone ID)"));				break;
-		case N7110_PBK_DATETIME    	: printf(_(" (Call register: date and time)"));		break;
-		case N7110_PBK_UNKNOWN1	    	: printf(_(" (Call register: with missed calls)"));	break;
-		case N7110_PBK_SPEEDDIAL    	: printf(_(" (Speed dial)"));				break;
-		case N7110_PBK_GROUPLOGO    	: printf(_(" (Caller group: logo)"));			break;
-		case N7110_PBK_LOGOON	    	: printf(_(" (Caller group: is logo on ?)"));		break;
-		case N7110_PBK_GROUP	    	: printf(_(" (Caller group number in pbk entry)"));	break;
+		case N7110_PBK_SIM_SPEEDDIAL	: printf("%s", _(" (Speed dial on SIM)")); 			break;
+		case N7110_PBK_NAME	    	: printf("%s", _(" (Text: name (always the only one))"));		break;
+		case N7110_PBK_EMAIL	    	: printf("%s", _(" (Text: email address)"));			break;
+		case N7110_PBK_POSTAL	    	: printf("%s", _(" (Text: postal address)"));			break;
+		case N7110_PBK_NOTE	    	: printf("%s", _(" (Text: note)"));				break;
+		case N7110_PBK_NUMBER 	    	: printf("%s", _(" (Phone number)"));				break;
+		case N7110_PBK_RINGTONE_ID  	: printf("%s", _(" (Ringtone ID)"));				break;
+		case N7110_PBK_DATETIME    	: printf("%s", _(" (Call register: date and time)"));		break;
+		case N7110_PBK_UNKNOWN1	    	: printf("%s", _(" (Call register: with missed calls)"));	break;
+		case N7110_PBK_SPEEDDIAL    	: printf("%s", _(" (Speed dial)"));				break;
+		case N7110_PBK_GROUPLOGO    	: printf("%s", _(" (Caller group: logo)"));			break;
+		case N7110_PBK_LOGOON	    	: printf("%s", _(" (Caller group: is logo on ?)"));		break;
+		case N7110_PBK_GROUP	    	: printf("%s", _(" (Caller group number in pbk entry)"));	break;
 
 		/* DCT4 only */
-		case N6510_PBK_URL		: printf(_(" (Text: URL address)"));			break;
-		case N6510_PBK_SMSLIST_ID	: printf(_(" (SMS list assignment)"));			break;
-		case N6510_PBK_VOICETAG_ID	: printf(_(" (Voice tag assignment)"));			break;
-		case N6510_PBK_PICTURE_ID	: printf(_(" (Picture ID assignment)"));			break;
-		case N6510_PBK_RINGTONEFILE_ID  : printf(_(" (Ringtone ID from filesystem/internal)"));	break;
-		case N6510_PBK_USER_ID          : printf(_(" (Text: user ID)"));				break;
-		case N6510_PBK_UNKNOWN2	        : printf(_(" (conversation list ID)"));			break;
-		case N6510_PBK_UNKNOWN3	 	: printf(_(" (Instant Messaging service list ID ?)"));	break;
-		case N6510_PBK_UNKNOWN4	 	: printf(_(" (presence list ID ?)"));			break;
-		case N6510_PBK_PUSHTOTALK_ID	: printf(_(" (SIP Address (Push to Talk address))"));	break;
-		case N6510_PBK_GROUP2_ID	: printf(_(" (Group ID (6230i or later))"));		break;
+		case N6510_PBK_URL		: printf("%s", _(" (Text: URL address)"));			break;
+		case N6510_PBK_SMSLIST_ID	: printf("%s", _(" (SMS list assignment)"));			break;
+		case N6510_PBK_VOICETAG_ID	: printf("%s", _(" (Voice tag assignment)"));			break;
+		case N6510_PBK_PICTURE_ID	: printf("%s", _(" (Picture ID assignment)"));			break;
+		case N6510_PBK_RINGTONEFILE_ID  : printf("%s", _(" (Ringtone ID from filesystem/internal)"));	break;
+		case N6510_PBK_USER_ID          : printf("%s", _(" (Text: user ID)"));				break;
+		case N6510_PBK_UNKNOWN2	        : printf("%s", _(" (conversation list ID)"));			break;
+		case N6510_PBK_UNKNOWN3	 	: printf("%s", _(" (Instant Messaging service list ID ?)"));	break;
+		case N6510_PBK_UNKNOWN4	 	: printf("%s", _(" (presence list ID ?)"));			break;
+		case N6510_PBK_PUSHTOTALK_ID	: printf("%s", _(" (SIP Address (Push to Talk address))"));	break;
+		case N6510_PBK_GROUP2_ID	: printf("%s", _(" (Group ID (6230i or later))"));		break;
 		}
-		printf(_(", type "));
+		printf("%s", _(", type "));
 		switch (msg.Buffer[pos+5]) {
-		case 0x05: printf(_("string")); 	break;
-		case 0x02: printf(_("byte")); 	break;
-		case 0x03: printf(_("2 bytes")); 	break;
-		case 0x06: printf(_("4 bytes")); 	break;
+		case 0x05: printf("%s", _("string")); 	break;
+		case 0x02: printf("%s", _("byte")); 	break;
+		case 0x03: printf("%s", _("2 bytes")); 	break;
+		case 0x06: printf("%s", _("4 bytes")); 	break;
 		default  : printf("%02X",msg.Buffer[pos+5]);
 		}
 		printf("\n");
@@ -1431,7 +1434,7 @@ void DCT4GetPBKFeatures(int argc, char *argv[])
 	if (strcasecmp(argv[2],"FD") == 0) MemoryType=MEM_FD;
 	if (MemoryType==0) {
 		printf(_("ERROR: unknown memory type (\"%s\")\n"),argv[2]);
-		exit (-1);
+		Terminate(2);
 	}
 
 	req[4] = NOKIA_GetMemoryType(gsm, MemoryType,N71_65_MEMORY_TYPES);
