@@ -27,6 +27,7 @@
 #include "../helper/locales.h"
 #include "../helper/printing.h"
 #include "../helper/string.h"
+#include "../helper/cmdline.h"
 
 #ifdef DEBUG
 #  include "sniff.h"
@@ -52,7 +53,7 @@
 
 #define ALL_MEMORY_TYPES "DC|MC|RC|ON|VM|SM|ME|MT|FD|SL"
 
-#define RSS_URL "http://blog.cihar.com/archives/gammu_releases/index-rss.xml"
+#define RSS_URL "http://wammu.eu/news/rss/"
 #define RSS_STABLE_STRING "Gammu stable version "
 #define RSS_TESTING_STRING "Gammu test version "
 
@@ -110,7 +111,7 @@ static void ListNetworks(int argc, char *argv[])
 		if (!*country) {
 			printf(_("Unknown country name: %s."), argv[2]);
 			printf("\n");
-			Terminate(3);
+			Terminate(2);
 		}
 	}
 	printf("%-10s %s\n", _("Network"), _("Name"));
@@ -284,15 +285,17 @@ int VersionToInt(const char *Buffer)
 	retval = atoi(Buffer) * 10000;
 	while (Buffer[pos] != '.') {
 		pos++;
-		if (pos == strlen(Buffer))
+		if (Buffer[pos] == '\0') {
 			return retval;
+		}
 	}
 	pos++;
 	retval += atoi(Buffer + pos) * 100;
 	while (Buffer[pos] != '.') {
 		pos++;
-		if (pos == strlen(Buffer))
+		if (Buffer[pos] == '\0') {
 			return retval;
+		}
 	}
 	pos++;
 	return retval + atoi(Buffer + pos);
@@ -309,6 +312,7 @@ static void CheckVersion(int argc, char *argv[])
 	const char *pos;
 	char new_version[20];
 	size_t i;
+	GSM_Error error;
 
 	if (argc >= 3) {
 		if (strcasecmp(argv[2], "STABLE") == 0) {
@@ -319,8 +323,8 @@ static void CheckVersion(int argc, char *argv[])
 	/* Read file */
 	RSS.Buffer = NULL;
 	RSS.Used = 0;
-	if (!GSM_ReadHTTPFile(RSS_URL, &RSS))
-		return;
+	error = GSM_ReadHTTPFile(RSS_URL, &RSS);
+	Print_Error(error);
 
 	if (checkstable) {
 		pos = strstr(RSS.Buffer, RSS_STABLE_STRING);
@@ -365,7 +369,7 @@ static void Version(int argc UNUSED, char *argv[]UNUSED)
 {
 	PrintVersion();
 
-	printf("%s\n", _("Copyright (C) 2003 - 2009 Michal Cihar <michal@cihar.com> and other authors."));
+	printf("%s\n", _("Copyright (C) 2003 - 2010 Michal Cihar <michal@cihar.com> and other authors."));
 
 	printf("\n");
 
@@ -377,7 +381,7 @@ static void Version(int argc UNUSED, char *argv[]UNUSED)
 
 	printf("\n");
 
-	printf("%s\n", _("Check <http://cihar.com/gammu/> for updates."));
+	printf("%s\n", _("Check <http://wammu.eu/gammu/> for updates."));
 
 	printf("\n");
 }
@@ -425,9 +429,9 @@ static void RunBatch(int argc, char *argv[])
 		ln[0] = 0;
 		if (fgets(ln, sizeof(ln) - 2, bf) == NULL) {
 			if (!feof(bf)) {
-				printf_err(_("Error reading batch! Terminating.\n"));
+				printf_err("%s", _("Error reading batch! Terminating.\n"));
 			} else {
-				printf_info(_("Batch processed, terminating.\n"));
+				printf_info("%s", _("Batch processed, terminating.\n"));
 			}
 			break;
 		}
@@ -488,14 +492,14 @@ NORETURN
 void SendSMSDSMSObsolete(int argc, char *argv[])
 {
 	printf_err("%s\n", _("SMS daemon is now in separate binary, please use gammu-smsd-inject instead of gammu sendsmsdsms!"));
-	Terminate(100);
+	Terminate(99);
 }
 
 NORETURN
 void SMSDaemonObsolete(int argc, char *argv[])
 {
 	printf_err("%s\n", _("SMS daemon is now in separate binary, please use gammu-smsd instead of gammu smsd!"));
-	Terminate(100);
+	Terminate(99);
 }
 
 void Help(int argc, char *argv[]);
@@ -509,26 +513,27 @@ static GSM_Parameters Parameters[] = {
 	{"checkversion",		0, 1, CheckVersion,		{H_Gammu,0},			"[STABLE]"},
 	{"checkfirmware",		0, 0, CheckFirmware,		{H_Info,0},			""},
 	{"getdisplaystatus",		0, 0, GetDisplayStatus,		{H_Info,0},			""},
+	{"getlocation",			0, 0, GetLocation,		{H_Info,0},			""},
 	{"monitor",			0, 1, Monitor,			{H_Info,H_Network,H_Call,0},	"[times]"},
 	{"setautonetworklogin",	0, 0, SetAutoNetworkLogin,	{H_Network,0},			""},
 	{"listnetworks",		0, 1, ListNetworks,		{H_Network,0},			"[country]"},
 	{"getgprspoint",		1, 2, GetGPRSPoint,		{H_Network,0},			"start [stop]"},
 	{"getfilesystemstatus",	0, 0, GetFileSystemStatus,	{H_Filesystem,0},		""},
 	{"getfilesystem",		0, 1, GetFileSystem,		{H_Filesystem,0},		"[-flatall|-flat]"},
-	{"getfilefolder",		1,40, GetFileFolder,		{H_Filesystem,0},		"ID1, ID2, ..."},
+	{"getfilefolder",		1,40, GetFileFolder,		{H_Filesystem,0},		"fileID, fileID, ..."},
 	{"addfolder",			2, 2, AddFolder,		{H_Filesystem,0},		"parentfolderID name"},
 	{"deletefolder",		1, 1, DeleteFolder,		{H_Filesystem,0},		"name"},
 	{"getfolderlisting",		1, 1, GetFolderListing,		{H_Filesystem,0},		"folderID"},
 	{"getrootfolders",		0, 0, GetRootFolders,		{H_Filesystem,0},		""},
 	{"setfileattrib",		1, 5, SetFileAttrib,		{H_Filesystem,0},		"folderID [-system] [-readonly] [-hidden] [-protected]"},
-	{"getfiles",			1,40, GetFiles,			{H_Filesystem,0},		"ID1, ID2, ..."},
+	{"getfiles",			1,40, GetFiles,			{H_Filesystem,0},		"fileID, fileID, ..."},
 	{"addfile",			2, 9, AddSendFile,		{H_Filesystem,0},		"folderID name [-type JAR|BMP|PNG|GIF|JPG|MIDI|WBMP|AMR|3GP|NRT][-readonly][-protected][-system][-hidden][-newtime]"},
 	{"sendfile",			1, 1, AddSendFile,		{H_Filesystem,0},		"name"},
 	{"deletefiles",		1,20, DeleteFiles,		{H_Filesystem,0},		"fileID"},
 #if defined(GSM_ENABLE_NOKIA_DCT3) || defined(GSM_ENABLE_NOKIA_DCT4)
 	{"nokiaaddplaylists",		0, 0, NokiaAddPlayLists,	{H_Filesystem,H_Nokia,0},	""},
-	{"nokiaaddfile",		2, 5, NokiaAddFile,		{H_Filesystem,H_Nokia,0},	"Application|Game file [-readonly][-overwrite][-overwriteall]"},
-	{"nokiaaddfile",		2, 5, NokiaAddFile,		{H_Filesystem,H_Nokia,0},	"Gallery|Gallery2|Camera|Tones|Tones2|Records|Video|Playlist|MemoryCard file [-name name][-protected][-readonly][-system][-hidden][-newtime]"},
+	{"nokiaaddfile",		2, 5, NokiaAddFile,		{H_Filesystem,H_Nokia,0},	"APPLICATION|GAME file [-readonly][-overwrite][-overwriteall]"},
+	{"nokiaaddfile",		2, 5, NokiaAddFile,		{H_Filesystem,H_Nokia,0},	"GALLERY|GALLERY2|CAMERA|TONES|TONES2|RECORDS|VIDEO|PLAYLIST|MEMORYCARD file [-name name][-protected][-readonly][-system][-hidden][-newtime]"},
 	{"playsavedringtone",		1, 1, DCT4PlaySavedRingtone, 	{H_Ringtone,0},			"number"},
 #endif
 	{"playringtone",		1, 1, PlayRingtone, 		{H_Ringtone,0},			"file"},
@@ -625,14 +630,14 @@ static GSM_Parameters Parameters[] = {
 	{"dialvoice",			1, 2, DialVoice,		{H_Call,0},			"number [show|hide]"},
 	{"maketerminatedcall",	2, 3, MakeTerminatedCall,	{H_Call,0},			"number length [show|hide]"},
 	{"getspeeddial",		1, 2, GetSpeedDial,		{H_Call,H_Memory,0},		"start [stop]"},
-	{"cancelcall",		0, 1, CancelCall,		{H_Call,0},			"[ID]"},
-	{"answercall",		0, 1, AnswerCall,		{H_Call,0},			"[ID]"},
-	{"unholdcall",		1, 1, UnholdCall,		{H_Call,0},			"ID"},
-	{"holdcall",			1, 1, HoldCall,			{H_Call,0},			"ID"},
-	{"conferencecall",		1, 1, ConferenceCall,		{H_Call,0},			"ID"},
-	{"splitcall",			1, 1, SplitCall,		{H_Call,0},			"ID"},
-	{"switchcall",		0, 1, SwitchCall,		{H_Call,0},			"[ID]"},
-	{"transfercall",		0, 1, TransferCall,		{H_Call,0},			"[ID]"},
+	{"cancelcall",		0, 1, CancelCall,		{H_Call,0},			"[id]"},
+	{"answercall",		0, 1, AnswerCall,		{H_Call,0},			"[id]"},
+	{"unholdcall",		1, 1, UnholdCall,		{H_Call,0},			"id"},
+	{"holdcall",			1, 1, HoldCall,			{H_Call,0},			"id"},
+	{"conferencecall",		1, 1, ConferenceCall,		{H_Call,0},			"id"},
+	{"splitcall",			1, 1, SplitCall,		{H_Call,0},			"id"},
+	{"switchcall",		0, 1, SwitchCall,		{H_Call,0},			"[id]"},
+	{"transfercall",		0, 1, TransferCall,		{H_Call,0},			"[id]"},
 	{"divert",			3, 5, CallDivert,		{H_Call,0},			"get|set all|busy|noans|outofreach all|voice|fax|data [number timeout]"},
 	{"canceldiverts",		0, 0, CancelAllDiverts,		{H_Call,0},			""},
 	{"senddtmf",			1, 1, SendDTMF,			{H_Call,0},			"sequence"},
@@ -687,7 +692,7 @@ static GSM_Parameters Parameters[] = {
 	{"backup",			1, 2, DoBackup,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes]"},
 	{"backupsms",			1, 2, BackupSMS,		{H_Backup,H_SMS,0},		"file [-yes|-all]"},
 	{"restore",			1, 2, Restore,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes]"},
-	{"addnew",			1, 2, AddNew,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes]"},
+	{"addnew",			1, 4, AddNew,			{H_Backup,H_Memory,H_Calendar,H_ToDo,H_Category,H_Ringtone,H_WAP,H_FM,0},			"file [-yes] [-memory ME|SM|..]"},
 	{"restoresms",		1, 2, RestoreSMS,		{H_Backup,H_SMS,0},		"file [-yes]"},
 	{"addsms",			2, 3, AddSMS,			{H_Backup,H_SMS,0},		"folder file [-yes]"},
 #endif
@@ -695,7 +700,7 @@ static GSM_Parameters Parameters[] = {
 	{"networkinfo",		0, 0, NetworkInfo,		{H_Network,0},			""},
 #ifdef GSM_ENABLE_AT
 	{"siemenssatnetmon",		0, 0, ATSIEMENSSATNetmon,	{H_Siemens,H_Network,0},	""},
-	{"siemensnetmonact",		1, 1, ATSIEMENSActivateNetmon,	{H_Siemens,H_Network,0},	"netmon_type (1-full, 2-simple)"},
+	{"siemensnetmonact",		1, 1, ATSIEMENSActivateNetmon,	{H_Siemens,H_Network,0},	"netmon_type"},
 	{"siemensnetmonitor",		1, 1, ATSIEMENSNetmonitor,	{H_Siemens,H_Network,0},	"test"},
 #endif
 #ifdef GSM_ENABLE_NOKIA6110
@@ -1042,7 +1047,7 @@ int ProcessParameters(int start, int argc, char *argv[])
 			printf("%s\n", _("Bad option!"));
 			return 2;
 		}
-		return 1;
+		return 2;
 	}
 	return 0;
 }
@@ -1082,7 +1087,7 @@ int main(int argc, char *argv[])
 		    strcasecmp(argv[i], "-s") == 0) &&
 		    i + 1 < argc) {
 			i++;
-			only_config = atoi(argv[i]);
+			only_config = GetInt(argv[i]);
 			start += 2;
 		} else if ((strcasecmp(argv[i], "--debug") == 0 ||
 		    strcasecmp(argv[i], "-d") == 0) &&
@@ -1102,7 +1107,7 @@ int main(int argc, char *argv[])
 			start += 2;
 		} else if (isdigit((int)argv[i][0])) {
 			/* Compatibilitty: config file section */
-			only_config = atoi(argv[i]);
+			only_config = GetInt(argv[i]);
 			if (only_config >= 0)
 				start++;
 			else
@@ -1142,7 +1147,7 @@ int main(int argc, char *argv[])
 
 	gsm = GSM_AllocStateMachine();
 	if (gsm == NULL) {
-		printf_err(_("Failed to allocate memory, aborting!\n"));
+		printf_err("%s", _("Failed to allocate memory, aborting!\n"));
 		exit(1);
 	}
 
@@ -1174,7 +1179,7 @@ int main(int argc, char *argv[])
 	if (argc <= start + 1) {
 		HelpGeneral();
 		printf("%s\n", _("Too few parameters!"));
-		Terminate(3);
+		Terminate(2);
 	}
 
 	smcfg0 = GSM_GetConfig(gsm, 0);
@@ -1244,7 +1249,7 @@ int main(int argc, char *argv[])
 	if (!strcasecmp(GetGammuVersion(), VERSION) == 0) {
 		printf_err(_("Version of installed libGammu.so (%s) is different to version of Gammu (%s)\n"),
 			   GetGammuVersion(), VERSION);
-		Terminate(4);
+		Terminate(98);
 	}
 
 	ret = ProcessParameters(start, argc, argv);
