@@ -12,8 +12,7 @@
 #include "../helper/memory-display.h"
 #include "../helper/printing.h"
 #include "../helper/string.h"
-
-#define GAMMU_CALLER_GROUPS	20
+#include "../helper/cmdline.h"
 
 void GetAllMemory(int argc UNUSED, char *argv[])
 {
@@ -29,7 +28,7 @@ void GetAllMemory(int argc UNUSED, char *argv[])
 
 	if (Entry.MemoryType == 0) {
 		printf_err(_("Unknown memory type (\"%s\")\n"),argv[2]);
-		exit (-1);
+		Terminate(2);
 	}
 
 	GSM_Init(TRUE);
@@ -63,7 +62,7 @@ void GetMemory(int argc, char *argv[])
 
 	if (entry.MemoryType==0) {
 		printf_err(_("Unknown memory type (\"%s\")\n"),argv[2]);
-		exit (-1);
+		Terminate(2);
 	}
 
 	GetStartStop(&start, &stop, 3, argc, argv);
@@ -73,7 +72,7 @@ void GetMemory(int argc, char *argv[])
 			empty = FALSE;
 		} else {
 			printf_err(_("Unknown parameter (\"%s\")\n"),argv[5]);
-			exit (-1);
+			Terminate(2);
 		}
 	}
 
@@ -135,7 +134,7 @@ void DeleteMemory(int argc, char *argv[])
 
 	if (entry.MemoryType==0) {
 		printf_err(_("Unknown memory type (\"%s\")\n"),argv[2]);
-		exit (-1);
+		Terminate(2);
 	}
 
 	GetStartStop(&start, &stop, 3, argc, argv);
@@ -171,7 +170,7 @@ void DeleteAllMemory(int argc, char *argv[])
 
 	if (MemoryType == 0) {
 		printf_err(_("Unknown memory type (\"%s\")\n"),argv[2]);
-		exit (-1);
+		Terminate(2);
 	}
 
 	GSM_Init(TRUE);
@@ -183,6 +182,11 @@ void DeleteAllMemory(int argc, char *argv[])
 	GSM_Terminate();
 }
 
+/**
+ * Searches if memory entry contains given text.
+ *
+ * It prints it in match.
+ */
 void SearchOneEntry(GSM_MemoryEntry *Entry, const unsigned char *Text)
 {
 	int i;
@@ -256,6 +260,11 @@ void SearchOneEntry(GSM_MemoryEntry *Entry, const unsigned char *Text)
 	}
 }
 
+/**
+ * Reads all entries from one memory and searches them for some text.
+ *
+ * All matched entries are printed.
+ */
 void SearchOneMemory(GSM_MemoryType MemoryType, const char *Title, const unsigned char *Text)
 {
 	GSM_MemoryEntry		Entry;
@@ -380,7 +389,7 @@ void ListMemoryCategory(int argc UNUSED, char *argv[])
 	}
 
 	if (Number) {
-		j = atoi(argv[2]);
+		j = GetInt(argv[2]);
 		if (j > 0) {
 			ListMemoryCategoryEntries(j);
 		}
