@@ -19,6 +19,7 @@
 #include "../helper/formats.h"
 #include "../helper/printing.h"
 #include "../helper/string.h"
+#include "../helper/cmdline.h"
 
 #ifdef GSM_ENABLE_NOKIA_DCT3
 #  include "depend/nokia/dct3.h"
@@ -57,6 +58,18 @@ void PrintNetworkInfo(GSM_NetworkInfo NetInfo)
 				DecodeUnicodeConsole(NetInfo.NetworkName));
 		}
 	}
+	if (NetInfo.GPRS != 0) {
+		printf(LISTFORMAT, _("GPRS"));
+		switch (NetInfo.GPRS) {
+			case GSM_GPRS_Attached:
+				printf("%s", _("attached"));
+				break;
+			case GSM_GPRS_Detached:
+				printf("%s", _("detached"));
+				break;
+		}
+		printf("\n");
+	}
 }
 
 GSM_Error GSM_PlayRingtone(GSM_Ringtone ringtone)
@@ -126,8 +139,8 @@ void CheckFirmware(int argc UNUSED, char *argv[]UNUSED)
 	sprintf(url, "http://www.gammu.org/support/phones/phonedbxml.php?model=%s", model);
 	PhoneDB.Buffer = NULL;
 	PhoneDB.Used = 0;
-	if (!GSM_ReadHTTPFile(url, &PhoneDB))
-		return;
+	error = GSM_ReadHTTPFile(url, &PhoneDB);
+	Print_Error(error);
 
 	/* Parse reply */
 	while (pos < PhoneDB.Used) {
@@ -167,13 +180,117 @@ void CheckFirmware(int argc UNUSED, char *argv[]UNUSED)
 		return;
 
 	/* Print information to user */
-	printf_info(_("Never version of firmware is available!\n"));
+	printf_info("%s", _("Never version of firmware is available!\n"));
 	printf_info(_("Latest version is %s and you run %s.\n"),
 			latest_version, current_version);
 
 	GSM_Terminate();
 }
 
+/**
+ * Get's location from OpenCellID.
+ */
+void GetLocation(int argc UNUSED, char *argv[]UNUSED)
+{
+	GSM_File OpenCell;
+	char url[70 + GSM_MAX_MODEL_LENGTH];
+	char *pos;
+	GSM_Error error;
+	GSM_NetworkInfo netinfo;
+	float latitude, longitude;
+	long int mnc, mcc, lac, cellid, nbSamples, range;
+
+	GSM_Init(TRUE);
+
+	/* Get model information */
+	error = GSM_GetNetworkInfo(gsm, &netinfo);
+	Print_Error(error);
+
+	/* We need decimal numbers */
+	lac = strtol(netinfo.LAC, NULL, 16);
+	cellid = strtol(netinfo.CID, NULL, 16);
+
+	/* Split code to country and network */
+	if (sscanf(netinfo.NetworkCode, "%ld %ld", &mcc, &mnc) != 2) {
+		printf_err("%s", _("Wrong network code from phone!\n"));
+		return;
+	}
+
+	/* Request information from OpenCellID */
+	sprintf(url, "http://www.opencellid.org/cell/get?key=%s&mnc=%ld&mcc=%ld&lac=%ld&cellid=%ld",
+		OPENCELLID_API_KEY,
+		mnc, mcc, lac, cellid);
+
+	OpenCell.Buffer = NULL;
+	OpenCell.Used = 0;
+	error = GSM_ReadHTTPFile(url, &OpenCell);
+	Print_Error(error);
+
+	/* Parse reply:
+		<?xml version="1.0" encoding="UTF-8"?>
+		<rsp stat="ok">
+		  <cell range="6000" lac="0" lat="54.4910893937777" nbSamples="46" lon="27.9390742994699" cellId="29513" mcc="250" mnc="99"/>
+		</rsp>
+	*/
+	if (strstr(OpenCell.Buffer, "stat=\"ok\"") == NULL) {
+		printf_err("%s", _("Request for information from OpenCellID failed!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	pos = strstr(OpenCell.Buffer, "lat=\"");
+	if (pos == NULL) {
+		printf_err("%s", _("Failed to find latitude in OpenCellID reply!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	if (sscanf(pos, "lat=\"%f\"", &latitude) == 0) {
+		printf_err("%s", _("Failed to parse latitude from OpenCellID reply!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	pos = strstr(OpenCell.Buffer, "lon=\"");
+	if (pos == NULL) {
+		printf_err("%s", _("Failed to find longitude in OpenCellID reply!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	if (sscanf(pos, "lon=\"%f\"", &longitude) == 0) {
+		printf_err("%s", _("Failed to parse longitude from OpenCellID reply!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	pos = strstr(OpenCell.Buffer, "range=\"");
+	if (pos == NULL) {
+		printf_err("%s", _("Failed to find range in OpenCellID reply!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	if (sscanf(pos, "range=\"%ld\"", &range) == 0) {
+		printf_err("%s", _("Failed to parse range from OpenCellID reply!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	pos = strstr(OpenCell.Buffer, "nbSamples=\"");
+	if (pos == NULL) {
+		printf_err("%s", _("Failed to find nbSamples in OpenCellID reply!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	if (sscanf(pos, "nbSamples=\"%ld\"", &nbSamples) == 0) {
+		printf_err("%s", _("Failed to parse nbSamples from OpenCellID reply!\n"));
+		free(OpenCell.Buffer);
+		return;
+	}
+	free(OpenCell.Buffer);
+
+	printf(LISTFORMAT "%f\n", _("Latitude"), latitude);
+	printf(LISTFORMAT "%f\n", _("Longitude"), longitude);
+	printf(LISTFORMAT "%ld\n", _("Range"), range);
+	printf(LISTFORMAT "%ld\n", _("Number of samples"), nbSamples);
+
+	GSM_Terminate();
+}
+
 
 
 void Identify(int argc, char *argv[])
@@ -182,9 +299,14 @@ void Identify(int argc, char *argv[])
 	char date[GSM_MAX_VERSION_DATE_LENGTH];
 	double num;
 	GSM_Error error;
+	GSM_Config *curcfg;
 
 	GSM_Init(TRUE);
 
+	/* Read current configuration */
+	curcfg = GSM_GetConfig(gsm, -1);
+	printf(LISTFORMAT "%s\n", _("Device"), curcfg->Device);
+
 	error=GSM_GetManufacturer(gsm, buffer);
 	Print_Error(error);
 	printf(LISTFORMAT "%s\n", _("Manufacturer"), buffer);
@@ -273,7 +395,10 @@ void NetworkInfo(int argc UNUSED, char *argv[] UNUSED)
 void IncomingCall(GSM_StateMachine *sm UNUSED, GSM_Call call, void *user_data)
 {
 	printf(LISTFORMAT, _("Call info"));
-	if (call.CallIDAvailable) printf(_("ID %i, "),call.CallID);
+
+	if (call.CallIDAvailable) {
+		printf(_("ID %i, "),call.CallID);
+	}
 	switch(call.Status) {
 		case GSM_CALL_IncomingCall  	: printf(_("incoming call from \"%s\"\n"),DecodeUnicodeConsole(call.PhoneNumber));  	break;
 		case GSM_CALL_OutgoingCall  	: printf(_("outgoing call to \"%s\"\n"),DecodeUnicodeConsole(call.PhoneNumber));    	break;
@@ -323,7 +448,7 @@ void Monitor(int argc, char *argv[])
 	int 			count = -1;
 
 	if (argc >= 3) {
-		count = atoi(argv[2]);
+		count = GetInt(argv[2]);
 		if (count <= 0) count = -1;
 	}
 
@@ -415,26 +540,26 @@ void Monitor(int argc, char *argv[])
                 		printf(LISTFORMAT, _("Charge state"));
                 		switch (BatteryCharge.ChargeState) {
                     			case GSM_BatteryPowered:
-						printf(_("powered from battery"));
+						printf("%s", _("powered from battery"));
 						break;
                     			case GSM_BatteryConnected:
-						printf(_("battery connected, but not powered from battery"));
+						printf("%s", _("battery connected, but not powered from battery"));
                         			break;
                     			case GSM_BatteryCharging:
-						printf(_("battery connected and is being charged"));
+						printf("%s", _("battery connected and is being charged"));
                         			break;
                     			case GSM_BatteryFull:
-						printf(_("battery connected and is fully charged"));
+						printf("%s", _("battery connected and is fully charged"));
                         			break;
                     			case GSM_BatteryNotConnected:
-                        			printf(_("battery not connected"));
+                        			printf("%s", _("battery not connected"));
                         			break;
                     			case GSM_PowerFault:
-                        			printf(_("detected power failure"));
+                        			printf("%s", _("detected power failure"));
                         			break;
 #ifndef CHECK_CASES
                     			default:
-                        			printf(_("unknown"));
+                        			printf("%s", _("unknown"));
                        				break;
 #endif
                 		}
@@ -444,19 +569,19 @@ void Monitor(int argc, char *argv[])
                 		printf(LISTFORMAT, _("Battery type"));
                 		switch (BatteryCharge.BatteryType) {
                     			case GSM_BatteryLiIon:
-						printf(_("Lithium Ion"));
+						printf("%s", _("Lithium Ion"));
 						break;
                     			case GSM_BatteryLiPol:
-						printf(_("Lithium Polymer"));
+						printf("%s", _("Lithium Polymer"));
 						break;
                     			case GSM_BatteryNiMH:
-						printf(_("NiMH"));
+						printf("%s", _("NiMH"));
 						break;
 					case GSM_BatteryUnknown:
 #ifndef CHECK_CASES
                     			default:
 #endif
-                        			printf(_("unknown"));
+                        			printf("%s", _("unknown"));
                        				break;
                 		}
                 		printf("\n");
@@ -542,10 +667,10 @@ void GetRingtone(int argc, char *argv[])
 	Print_Error(error);
 
 	switch (ringtone.Format) {
-		case RING_NOTETONE	: printf(_("Smart Messaging"));	break;
-		case RING_NOKIABINARY	: printf(_("Nokia binary"));	break;
-		case RING_MIDI		: printf(_("MIDI"));		break;
-		case RING_MMF		: printf(_("SMAF (MMF)"));	break;
+		case RING_NOTETONE	: printf("%s", _("Smart Messaging"));	break;
+		case RING_NOKIABINARY	: printf("%s", _("Nokia binary"));	break;
+		case RING_MIDI		: printf("%s", _("MIDI"));		break;
+		case RING_MMF		: printf("%s", _("SMAF (MMF)"));	break;
 	}
 	printf(_(" format, ringtone \"%s\"\n"),DecodeUnicodeConsole(ringtone.Name));
 
@@ -586,7 +711,7 @@ void DialVoice(int argc, char *argv[])
 		} else if (strcasecmp(argv[3],"hide") == 0) {	ShowNumber = GSM_CALL_HideNumber;
 		} else {
 			printf(_("Unknown parameter (\"%s\")\n"),argv[3]);
-			Terminate(3);
+			Terminate(2);
 		}
 	}
 
@@ -615,7 +740,7 @@ void MakeTerminatedCall(int argc, char *argv[])
 		} else if (strcasecmp(argv[4],"hide") == 0) {	ShowNumber = GSM_CALL_HideNumber;
 		} else {
 			printf(_("Unknown parameter (\"%s\")\n"),argv[4]);
-			Terminate(3);
+			Terminate(2);
 		}
 	}
 
@@ -630,7 +755,7 @@ void MakeTerminatedCall(int argc, char *argv[])
 	error=GSM_DialVoice(gsm, argv[2], ShowNumber);
 	Print_Error(error);
 
-	sleep(atoi(argv[3]));
+	sleep(GetInt(argv[3]));
 	GSM_ReadDevice(gsm,TRUE);
 
 	if (TerminateID != -1) {
@@ -648,7 +773,7 @@ void CancelCall(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 	if (argc>2) {
-		error=GSM_CancelCall(gsm,atoi(argv[2]),FALSE);
+		error=GSM_CancelCall(gsm,GetInt(argv[2]),FALSE);
 	} else {
 		error=GSM_CancelCall(gsm,0,TRUE);
 	}
@@ -663,7 +788,7 @@ void AnswerCall(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 	if (argc>2) {
-		error=GSM_AnswerCall(gsm,atoi(argv[2]),FALSE);
+		error=GSM_AnswerCall(gsm,GetInt(argv[2]),FALSE);
 	} else {
 		error=GSM_AnswerCall(gsm,0,TRUE);
 	}
@@ -677,7 +802,7 @@ void UnholdCall(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(TRUE);
 
-	error=GSM_UnholdCall(gsm,atoi(argv[2]));
+	error=GSM_UnholdCall(gsm,GetInt(argv[2]));
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -688,7 +813,7 @@ void HoldCall(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(TRUE);
 
-	error=GSM_HoldCall(gsm,atoi(argv[2]));
+	error=GSM_HoldCall(gsm,GetInt(argv[2]));
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -699,7 +824,7 @@ void ConferenceCall(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(TRUE);
 
-	error=GSM_ConferenceCall(gsm,atoi(argv[2]));
+	error=GSM_ConferenceCall(gsm,GetInt(argv[2]));
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -710,7 +835,7 @@ void SplitCall(int argc UNUSED, char *argv[])
 	GSM_Error error;
 	GSM_Init(TRUE);
 
-	error=GSM_SplitCall(gsm,atoi(argv[2]));
+	error=GSM_SplitCall(gsm,GetInt(argv[2]));
 	Print_Error(error);
 
 	GSM_Terminate();
@@ -722,7 +847,7 @@ void SwitchCall(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 	if (argc > 2) {
-		error=GSM_SwitchCall(gsm,atoi(argv[2]),FALSE);
+		error=GSM_SwitchCall(gsm,GetInt(argv[2]),FALSE);
 	} else {
 		error=GSM_SwitchCall(gsm,0,TRUE);
 	}
@@ -737,7 +862,7 @@ void TransferCall(int argc, char *argv[])
 	GSM_Init(TRUE);
 
 	if (argc > 2) {
-		error=GSM_TransferCall(gsm,atoi(argv[2]),FALSE);
+		error=GSM_TransferCall(gsm,GetInt(argv[2]),FALSE);
 	} else {
 		error=GSM_TransferCall(gsm,0,TRUE);
 	}
@@ -755,7 +880,7 @@ void Reset(int argc UNUSED, char *argv[])
 	} else if (strcasecmp(argv[2],"HARD") == 0) {	hard=TRUE;
 	} else {
 		printf(_("What type of reset do you want (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	GSM_Init(TRUE);
@@ -825,7 +950,7 @@ void GetGPRSPoint(int argc, char *argv[])
 		} else {
 			printf(_("%i. Access point %i"),point.Location,point.Location);
 		}
-		if (point.Active) printf(_(" (active)"));
+		if (point.Active) printf("%s", _(" (active)"));
 		printf("\n");
 		if (error != ERR_EMPTY) {
 			printf(LISTFORMAT "\"%s\"\n\n", _("Address"),DecodeUnicodeConsole(point.URL));
@@ -853,7 +978,7 @@ void GetBitmap(int argc, char *argv[])
 		GetStartStop(&location, NULL, 3, argc, argv);
 		if (location>5) {
 			printf("%s\n", _("Maximal location for caller logo can be 5"));
-			exit (-1);
+			Terminate(2);
 		}
 	} else if (strcasecmp(argv[2],"PICTURE") == 0) {
 		MultiBitmap.Bitmap[0].Type=GSM_PictureImage;
@@ -866,7 +991,7 @@ void GetBitmap(int argc, char *argv[])
 		MultiBitmap.Bitmap[0].Type=GSM_OperatorLogo;
 	} else {
 		printf(_("What type of logo do you want to get (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 	MultiBitmap.Bitmap[0].Location=location;
 
@@ -976,7 +1101,7 @@ void SetBitmap(int argc, char *argv[])
 	if (strcasecmp(argv[2],"STARTUP") == 0) {
 		if (argc<4) {
 			printf("%s\n", _("More parameters required!"));
-			Terminate(3);
+			Terminate(2);
 		}
 		MultiBitmap.Bitmap[0].Type=GSM_StartupLogo;
 		MultiBitmap.Bitmap[0].Location=1;
@@ -991,26 +1116,26 @@ void SetBitmap(int argc, char *argv[])
 	} else if (strcasecmp(argv[2],"TEXT") == 0) {
 		if (argc<4) {
 			printf("%s\n", _("More parameters required!"));
-			Terminate(3);
+			Terminate(2);
 		}
 		Bitmap.Type=GSM_WelcomeNote_Text;
 		EncodeUnicode(Bitmap.Text,argv[3],strlen(argv[3]));
 	} else if (strcasecmp(argv[2],"DEALER") == 0) {
 		if (argc<4) {
 			printf("%s\n", _("More parameters required!"));
-			Terminate(3);
+			Terminate(2);
 		}
 		Bitmap.Type=GSM_DealerNote_Text;
 		EncodeUnicode(Bitmap.Text,argv[3],strlen(argv[3]));
 	} else if (strcasecmp(argv[2],"CALLER") == 0) {
 		if (argc<4) {
 			printf("%s\n", _("More parameters required!"));
-			Terminate(3);
+			Terminate(2);
 		}
 		GetStartStop(&i, NULL, 3, argc, argv);
 		if (i>5 && i!=255) {
 			printf("%s\n", _("Maximal location for caller logo can be 5"));
-			exit (-1);
+			Terminate(1);
 		}
 		MultiBitmap.Bitmap[0].Type 	= GSM_CallerGroupLogo;
 		MultiBitmap.Bitmap[0].Location	= i;
@@ -1035,10 +1160,10 @@ void SetBitmap(int argc, char *argv[])
 	} else if (strcasecmp(argv[2],"PICTURE") == 0) {
 		if (argc<5) {
 			printf("%s\n", _("More parameters required!"));
-			Terminate(3);
+			Terminate(2);
 		}
 		MultiBitmap.Bitmap[0].Type		= GSM_PictureImage;
-		MultiBitmap.Bitmap[0].Location		= atoi(argv[4]);
+		MultiBitmap.Bitmap[0].Location		= GetInt(argv[4]);
 		error=GSM_ReadBitmapFile(argv[3],&MultiBitmap);
 		Print_Error(error);
 		memcpy(&Bitmap,&MultiBitmap.Bitmap[0],sizeof(GSM_Bitmap));
@@ -1051,7 +1176,7 @@ void SetBitmap(int argc, char *argv[])
 		Bitmap.Type = GSM_ColourOperatorLogo_ID;
 		strcpy(Bitmap.NetworkCode,"000 00");
 		if (argc > 3) {
-			Bitmap.ID = atoi(argv[3]);
+			Bitmap.ID = GetInt(argv[3]);
 			if (argc>4) {
 				strncpy(Bitmap.NetworkCode,argv[4],6);
 			} else {
@@ -1067,12 +1192,12 @@ void SetBitmap(int argc, char *argv[])
 		Bitmap.Location = 0;
 		if (argc > 3) {
 			Bitmap.Location = 1;
-			Bitmap.ID 	= atoi(argv[3]);
+			Bitmap.ID 	= GetInt(argv[3]);
 		}
 	} else if (strcasecmp(argv[2],"WALLPAPER") == 0) {
 		Bitmap.Type 		= GSM_ColourWallPaper_ID;
 		Bitmap.ID		= 0;
-		if (argc > 3) Bitmap.ID = atoi(argv[3]);
+		if (argc > 3) Bitmap.ID = GetInt(argv[3]);
 	} else if (strcasecmp(argv[2],"OPERATOR") == 0) {
 		MultiBitmap.Bitmap[0].Type	= GSM_OperatorLogo;
 		MultiBitmap.Bitmap[0].Location 	= 1;
@@ -1093,7 +1218,7 @@ void SetBitmap(int argc, char *argv[])
 		memcpy(&Bitmap,&MultiBitmap.Bitmap[0],sizeof(GSM_Bitmap));
 	} else {
 		printf(_("What type of logo do you want to set (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	if (init) GSM_Init(TRUE);
@@ -1134,9 +1259,9 @@ void SetRingtone(int argc, char *argv[])
 				break;
 			}
 			printf(_("Unknown parameter (\"%s\")"),argv[i]);
-			Terminate(3);
+			Terminate(2);
 		case 1:
-			ringtone.Location=atoi(argv[i]);
+			ringtone.Location=GetInt(argv[i]);
 			nextlong = 0;
 			break;
 		case 2:
@@ -1147,11 +1272,11 @@ void SetRingtone(int argc, char *argv[])
 	}
 	if (nextlong!=0) {
 		printf_err("%s\n", _("Parameter missing!"));
-		Terminate(3);
+		Terminate(2);
 	}
 	if (ringtone.Location==0) {
 		printf_err("%s\n", _("Please enumerate locations from 1"));
-		exit (-1);
+		Terminate(1);
 	}
 
 	GSM_Init(TRUE);
@@ -1192,7 +1317,7 @@ void ClearMemory(GSM_MemoryType type, const char *question)
 					(i + 1) * 100 / (MemStatus.MemoryUsed + MemStatus.MemoryFree));
 				if (gshutdown) {
 					GSM_Terminate();
-					Terminate(0);
+					Terminate(4);
 				}
 			}
 			fprintf(stderr, "\n");
@@ -1226,7 +1351,7 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 	DoClear = FALSE;
 	error = GSM_GetNextCalendar(gsm,&Calendar,TRUE);
 	if (error == ERR_NONE) {
- 		if (answer_yes(_("Delete phone calendar notes?"))) DoClear = TRUE;
+ 		if (answer_yes("%s", _("Delete phone calendar notes?"))) DoClear = TRUE;
 	}
 	if (DoClear) {
 		fprintf(stderr, LISTFORMAT, _("Deleting"));
@@ -1250,7 +1375,7 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 	DoClear = FALSE;
 	error = GSM_GetToDoStatus(gsm,&ToDoStatus);
 	if (error == ERR_NONE && ToDoStatus.Used != 0) {
-		if (answer_yes(_("Delete phone todos?"))) DoClear = TRUE;
+		if (answer_yes("%s", _("Delete phone todos?"))) DoClear = TRUE;
 	}
 	if (DoClear) {
 		fprintf(stderr, LISTFORMAT, _("Deleting"));
@@ -1274,7 +1399,7 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 	DoClear = FALSE;
 	error = GSM_GetNotesStatus(gsm,&ToDoStatus);
 	if (error == ERR_NONE && ToDoStatus.Used != 0) {
-		if (answer_yes(_("Delete phone notes?"))) DoClear = TRUE;
+		if (answer_yes("%s", _("Delete phone notes?"))) DoClear = TRUE;
 	}
 	if (DoClear) {
 		fprintf(stderr, LISTFORMAT, _("Deleting"));
@@ -1292,7 +1417,7 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 	Bookmark.Location = 1;
 	error = GSM_GetWAPBookmark(gsm,&Bookmark);
 	if (error == ERR_NONE || error == ERR_INVALIDLOCATION) {
-		if (answer_yes(_("Delete phone WAP bookmarks?"))) {
+		if (answer_yes("%s", _("Delete phone WAP bookmarks?"))) {
 			fprintf(stderr, LISTFORMAT, _("Deleting"));
 			/* One thing to explain: DCT4 phones seems to have bug here.
 			 * When delete for example first bookmark, phone change
@@ -1310,7 +1435,7 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 			fflush(stderr);
 		}
 	}
-	if (answer_yes(_("Delete all phone user ringtones?"))) {
+	if (answer_yes("%s", _("Delete all phone user ringtones?"))) {
 		fprintf(stderr, LISTFORMAT, _("Deleting"));
 		error=GSM_DeleteUserRingtones(gsm);
 		Print_Error(error);
@@ -1319,7 +1444,7 @@ void ClearAll(int argc UNUSED, char *argv[] UNUSED)
 	Station.Location = 1;
 	error=GSM_GetFMStation(gsm,&Station);
 	if (error == ERR_NONE || error == ERR_EMPTY) {
-	 	if (answer_yes(_("Delete all phone FM radio stations?"))) {
+	 	if (answer_yes("%s", _("Delete all phone FM radio stations?"))) {
  			error=GSM_ClearFMStations(gsm);
  			Print_Error(error);
 		}
@@ -1349,14 +1474,14 @@ void DisplayConnectionSettings(GSM_MultiWAPSettings *settings,int j)
 	switch (settings->Settings[j].Bearer) {
 	case WAPSETTINGS_BEARER_SMS:
 		printf(LISTFORMAT "%s", _("Bearer"), _("SMS"));
-		if (settings->ActiveBearer == WAPSETTINGS_BEARER_SMS) printf(_(" (active)"));
+		if (settings->ActiveBearer == WAPSETTINGS_BEARER_SMS) printf("%s", _(" (active)"));
 		printf("\n");
 		printf(LISTFORMAT "\"%s\"\n", _("Server number"),DecodeUnicodeConsole(settings->Settings[j].Server));
 		printf(LISTFORMAT "\"%s\"\n", _("Service number"),DecodeUnicodeConsole(settings->Settings[j].Service));
 		break;
 	case WAPSETTINGS_BEARER_DATA:
 		printf(LISTFORMAT "%s", _("Bearer"), _("Data (CSD)"));
-		if (settings->ActiveBearer == WAPSETTINGS_BEARER_DATA) printf(_(" (active)"));
+		if (settings->ActiveBearer == WAPSETTINGS_BEARER_DATA) printf("%s", _(" (active)"));
 		printf("\n");
 		printf(LISTFORMAT "\"%s\"\n", _("Dial-up number"),DecodeUnicodeConsole(settings->Settings[j].DialUp));
 		printf(LISTFORMAT "\"%s\"\n", _("IP address"),DecodeUnicodeConsole(settings->Settings[j].IPAddress));
@@ -1391,7 +1516,7 @@ void DisplayConnectionSettings(GSM_MultiWAPSettings *settings,int j)
 		break;
 	case WAPSETTINGS_BEARER_USSD:
 		printf(LISTFORMAT "%s", _("Bearer"), _("USSD"));
-		if (settings->ActiveBearer == WAPSETTINGS_BEARER_USSD) printf(_(" (active)"));
+		if (settings->ActiveBearer == WAPSETTINGS_BEARER_USSD) printf("%s", _(" (active)"));
 		printf("\n");
 		printf(LISTFORMAT "\"%s\"\n", _("Service code"),DecodeUnicodeConsole(settings->Settings[j].Code));
 		if (settings->Settings[j].IsIP) {
@@ -1404,7 +1529,7 @@ void DisplayConnectionSettings(GSM_MultiWAPSettings *settings,int j)
 		break;
 	case WAPSETTINGS_BEARER_GPRS:
 		printf(LISTFORMAT "%s", _("Bearer"), _("GPRS"));
-		if (settings->ActiveBearer == WAPSETTINGS_BEARER_GPRS) printf(_(" (active)"));
+		if (settings->ActiveBearer == WAPSETTINGS_BEARER_GPRS) printf("%s", _(" (active)"));
 		printf("\n");
 		if (settings->Settings[j].ManualLogin) {
 			printf(LISTFORMAT "%s\n", _("Login type"), _("Manual"));
@@ -1443,7 +1568,7 @@ void GetSyncMLSettings(int argc, char *argv[])
 		} else {
 			printf("%s", DecodeUnicodeConsole(settings.Name));
 		}
-		if (settings.Active) printf(_(" (active)"));
+		if (settings.Active) printf("%s", _(" (active)"));
 		printf("\n");
 		printf(LISTFORMAT "\"%s\"\n", _("User"),DecodeUnicodeConsole(settings.User));
 		printf(LISTFORMAT "\"%s\"\n", _("Password"),DecodeUnicodeConsole(settings.Password));
@@ -1492,7 +1617,7 @@ void GetChatSettings(int argc, char *argv[])
 		} else {
 			printf("%s", DecodeUnicodeConsole(settings.Name));
 		}
-		if (settings.Active) printf(_(" (active)"));
+		if (settings.Active) printf("%s", _(" (active)"));
 		printf("\n");
 		printf(LISTFORMAT "\"%s\"\n", _("Homepage"),DecodeUnicodeConsole(settings.HomePage));
 		printf(LISTFORMAT "\"%s\"\n", _("User"),DecodeUnicodeConsole(settings.User));
@@ -1567,10 +1692,10 @@ void CopyBitmap(int argc, char *argv[])
 	if (argc==3) {
 		for (i=0;i<Bitmap.Number;i++) {
 			switch (Bitmap.Bitmap[i].Type) {
-				case GSM_StartupLogo :	printf(_("Startup logo"));		break;
-				case GSM_OperatorLogo:	printf(_("Operator logo")); 	break;
-				case GSM_PictureImage:	printf(_("Picture")); 	break;
-				case GSM_CallerGroupLogo  :	printf(_("Caller group logo")); 	break;
+				case GSM_StartupLogo :	printf("%s", _("Startup logo"));		break;
+				case GSM_OperatorLogo:	printf("%s", _("Operator logo")); 	break;
+				case GSM_PictureImage:	printf("%s", _("Picture")); 	break;
+				case GSM_CallerGroupLogo  :	printf("%s", _("Caller group logo")); 	break;
 				default		     : 					break;
 			}
 			printf(_(", width %i, height %i\n"),
@@ -1591,7 +1716,7 @@ void CopyBitmap(int argc, char *argv[])
 					Bitmap.Bitmap[i].Type = GSM_OperatorLogo;
 				} else {
 					printf(_("What format of output file logo (\"%s\") ?\n"),argv[4]);
-					Terminate(3);
+					Terminate(2);
 				}
 			}
 		}
@@ -1616,7 +1741,7 @@ void CopyRingtone(int argc, char *argv[])
 		} else if (strcasecmp(argv[4],"BINARY") == 0) {	Format = RING_NOKIABINARY;
 		} else {
 			printf(_("What format of output ringtone file (\"%s\") ?\n"),argv[4]);
-			Terminate(3);
+			Terminate(2);
 		}
 	}
 
@@ -1636,7 +1761,7 @@ void PressKeySequence(int argc UNUSED, char *argv[])
 	error = MakeKeySequence(argv[2], KeyCode, &Length);
 	if (error == ERR_NOTSUPPORTED) {
 		printf(_("Unknown key/function name: \"%c\"\n"),argv[2][Length]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	GSM_Init(TRUE);
@@ -1666,7 +1791,7 @@ void GetAllCategories(int argc UNUSED, char *argv[])
         	Status.Type 	= Category_Phonebook;
 	} else {
 		printf(_("What type of categories do you want to get (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	GSM_Init(TRUE);
@@ -1704,7 +1829,7 @@ void GetCategory(int argc, char *argv[])
     		Category.Type = Category_Phonebook;
 	} else {
 		printf(_("What type of categories do you want to get (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	GetStartStop(&start, &stop, 2, argc - 1, argv + 1);
@@ -1742,7 +1867,7 @@ void AddCategory(int argc UNUSED, char *argv[])
     		Category.Type = Category_Phonebook;
 	} else {
 		printf(_("What type of category do you want to add (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	GSM_Init(TRUE);
@@ -1789,7 +1914,7 @@ void EnterSecurityCode(int argc UNUSED, char *argv[])
 	} else if (strcasecmp(argv[2],"NETWORK") == 0) {	Code.Type = SEC_Network;
 	} else {
 		printf_err("%s: %s\n", _("Invalid security code type"), argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	if (strcmp(argv[3], "-") == 0) {
@@ -1806,7 +1931,7 @@ void EnterSecurityCode(int argc UNUSED, char *argv[])
 #endif
 		if (fscanf(stdin, "%15s", Code.Code) != 1) {
 			printf_err("%s\n", _("No PIN code entered!"));
-			Terminate(3);
+			Terminate(2);
 		}
 #endif
 	} else {
@@ -1846,10 +1971,10 @@ void GetProfile(int argc, char *argv[])
 		Print_Error(error);
 
 		printf("%i. \"%s\"",i,DecodeUnicodeConsole(Profile.Name));
-		if (Profile.Active)		printf(_(" (active)"));
-		if (Profile.DefaultName) 	printf(_(" (default name)"));
-		if (Profile.HeadSetProfile) 	printf(_(" (Head set profile)"));
-		if (Profile.CarKitProfile) 	printf(_(" (Car kit profile)"));
+		if (Profile.Active)		printf("%s", _(" (active)"));
+		if (Profile.DefaultName) 	printf("%s", _(" (default name)"));
+		if (Profile.HeadSetProfile) 	printf("%s", _(" (Head set profile)"));
+		if (Profile.CarKitProfile) 	printf("%s", _(" (Car kit profile)"));
 		printf("\n");
 		for (j=0;j<Profile.FeaturesNumber;j++) {
 			special = FALSE;
@@ -2009,7 +2134,7 @@ void ResetPhoneSettings(int argc UNUSED, char *argv[])
 	} else if (strcasecmp(argv[2],"FACTORY") == 0) { Type = GSM_RESET_FULLFACTORY;
 	} else {
 		printf(_("What type of reset phone settings (\"%s\") ?\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	GSM_Init(TRUE);
@@ -2109,7 +2234,7 @@ void CallDivert(int argc, char *argv[])
 	else if (strcasecmp("set",	argv[2]) == 0) {}
 	else {
 		printf(_("Unknown divert action (\"%s\")\n"),argv[2]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	     if (strcasecmp("all"       , argv[3]) == 0) {cd.Request.DivertType = GSM_DIVERT_AllTypes  ;}
@@ -2118,7 +2243,7 @@ void CallDivert(int argc, char *argv[])
 	else if (strcasecmp("outofreach", argv[3]) == 0) {cd.Request.DivertType = GSM_DIVERT_OutOfReach;}
 	else {
 		printf(_("Unknown divert type (\"%s\")\n"),argv[3]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	     if (strcasecmp("all"  , argv[4]) == 0) {cd.Request.CallType = GSM_DIVERT_AllCalls  ;}
@@ -2127,7 +2252,7 @@ void CallDivert(int argc, char *argv[])
 	else if (strcasecmp("data" , argv[4]) == 0) {cd.Request.CallType = GSM_DIVERT_DataCalls ;}
 	else {
 		printf(_("Unknown call type (\"%s\")\n"),argv[4]);
-		Terminate(3);
+		Terminate(2);
 	}
 
 	GSM_Init(TRUE);
@@ -2135,7 +2260,7 @@ void CallDivert(int argc, char *argv[])
 	if (strcasecmp("get", argv[2]) == 0) {
 		error = GSM_GetCallDivert(gsm,&cd);
 	    	Print_Error(error);
-		printf(_("Query:"));
+		printf("%s", _("Query:"));
 		printf("\n");
 		printf("  " LISTFORMAT, _("Divert type"));
 	} else {
@@ -2144,42 +2269,42 @@ void CallDivert(int argc, char *argv[])
 		if (argc > 5) EncodeUnicode(cd.Request.Number,argv[5],strlen(argv[5]));
 
 		cd.Request.Timeout = 0;
-		if (argc > 6) cd.Request.Timeout = atoi(argv[6]);
+		if (argc > 6) cd.Request.Timeout = GetInt(argv[6]);
 
 		error = GSM_SetCallDivert(gsm,&cd);
 	    	Print_Error(error);
-		printf(_("Changed:"));
+		printf("%s", _("Changed:"));
 		printf("\n");
 		printf("  " LISTFORMAT, _("Divert type"));
 	}
 
       	switch (cd.Request.DivertType) {
-   		case GSM_DIVERT_Busy      : printf(_("when busy"));				break;
-	        case GSM_DIVERT_NoAnswer  : printf(_("when not answered"));			break;
-      	        case GSM_DIVERT_OutOfReach: printf(_("when phone off or no coverage"));	break;
-                case GSM_DIVERT_AllTypes  : printf(_("all types of diverts"));			break;
+   		case GSM_DIVERT_Busy      : printf("%s", _("when busy"));				break;
+	        case GSM_DIVERT_NoAnswer  : printf("%s", _("when not answered"));			break;
+      	        case GSM_DIVERT_OutOfReach: printf("%s", _("when phone off or no coverage"));	break;
+                case GSM_DIVERT_AllTypes  : printf("%s", _("all types of diverts"));			break;
                 default		          : printf(_("unknown %i"),cd.Request.DivertType);			break;
         }
 	printf("\n");
 	printf("  " LISTFORMAT, _("Call type"));
 	switch (cd.Request.CallType) {
-	 	case GSM_DIVERT_VoiceCalls: printf(_("voice"));				break;
-                case GSM_DIVERT_FaxCalls  : printf(_("fax"));				break;
-                case GSM_DIVERT_DataCalls : printf(_("data"));		 		break;
-		case GSM_DIVERT_AllCalls  : printf(_("data & fax & voice"));		break;
+	 	case GSM_DIVERT_VoiceCalls: printf("%s", _("voice"));				break;
+                case GSM_DIVERT_FaxCalls  : printf("%s", _("fax"));				break;
+                case GSM_DIVERT_DataCalls : printf("%s", _("data"));		 		break;
+		case GSM_DIVERT_AllCalls  : printf("%s", _("data & fax & voice"));		break;
                 default                   : printf(_("unknown %i"),cd.Request.CallType);   		break;
         }
 	printf("\n");
-	printf(_("Response:"));
+	printf("%s", _("Response:"));
 	printf("\n");
 
 	for (i=0;i<cd.Response.EntriesNum;i++) {
 		printf("\n");
 		printf("  " LISTFORMAT, _("Call type"));
         	switch (cd.Response.Entries[i].CallType) {
-                	case GSM_DIVERT_VoiceCalls: printf(_("voice"));		 	break;
-                	case GSM_DIVERT_FaxCalls  : printf(_("fax"));		 	break;
-                	case GSM_DIVERT_DataCalls : printf(_("data"));		 	break;
+                	case GSM_DIVERT_VoiceCalls: printf("%s", _("voice"));		 	break;
+                	case GSM_DIVERT_FaxCalls  : printf("%s", _("fax"));		 	break;
+                	case GSM_DIVERT_DataCalls : printf("%s", _("data"));		 	break;
                 	default                   : printf(_("unknown %i"),cd.Response.Entries[i].CallType);break;
               	}
 		printf("\n");
