@@ -49,101 +49,80 @@ void PrintSMSLocation(const GSM_SMSMessage *sms, const GSM_SMSFolders *folders)
 	printf("\n");
 }
 
+/**
+ * Searches for memory entry in NULL terminated entries list.
+ */
+const GSM_MemoryEntry *SearchPhoneNumber(const unsigned char *number, const GSM_MemoryEntry **List, int *pos)
+{
+	int i;
+	for (i = 0; List[i] != NULL; i++) {
+		for (*pos = 0; *pos <  List[i]->EntriesNum; (*pos)++) {
+			switch (List[i]->Entries[*pos].EntryType) {
+				case PBK_Number_General:
+				case PBK_Number_Mobile:
+				case PBK_Number_Work:
+				case PBK_Number_Fax:
+				case PBK_Number_Home:
+				case PBK_Number_Pager:
+				case PBK_Number_Other:
+					if (mywstrncmp(List[i]->Entries[*pos].Text,number,-1)) {
+						return List[i];
+					}
+				default:
+					break;
+			}
+		}
+	}
+	return NULL;
+}
+
 /**
  * Prints single phone number optionally showing name of contact from backup data.
  */
-void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info)
+void PrintPhoneNumber(const unsigned char *number, const GSM_Backup *Info)
 {
-	gboolean 	found=FALSE,found2=FALSE;
-	int 	i,j,z;
+	const GSM_MemoryEntry *pbk;
+	int pos;
 
-	printf("\"%s\"",DecodeUnicodeConsole(number));
+	printf("\"%s\"", DecodeUnicodeConsole(number));
 
 	if (Info == NULL) return;
 
-	i=0;
-	while (Info->PhonePhonebook[i]!=NULL) {
-		for (j=0;j<Info->PhonePhonebook[i]->EntriesNum;j++) {
-			switch (Info->PhonePhonebook[i]->Entries[j].EntryType) {
-			case PBK_Number_General:
-			case PBK_Number_Mobile:
-			case PBK_Number_Work:
-			case PBK_Number_Fax:
-			case PBK_Number_Home:
-			case PBK_Number_Pager:
-			case PBK_Number_Other:
-				if (mywstrncmp(Info->PhonePhonebook[i]->Entries[j].Text,number,-1)) {
-					found2=TRUE;
-					switch (Info->PhonePhonebook[i]->Entries[j].EntryType) {
-					case PBK_Number_Mobile:
-						printf(" (%s", _("mobile"));
-						break;
-					case PBK_Number_Work:
-						printf(" (%s", _("work"));
-						break;
-					case PBK_Number_Fax:
-						printf(" (%s", _("fax"));
-						break;
-					case PBK_Number_Home:
-						printf(" (%s", _("home"));
-						break;
-					case PBK_Number_Pager:
-						printf(" (%s", _("pager"));
-						break;
-					default:
-						found2=FALSE;
-						break;
-					}
-					found=TRUE;
-				}
-			default:
-				break;
-			}
-			if (found) break;
-		}
-		if (!found) {
-			i++;
-			continue;
-		}
-		found=FALSE;
-		for (z=0;z<Info->PhonePhonebook[i]->EntriesNum;z++) {
-			switch (Info->PhonePhonebook[i]->Entries[z].EntryType) {
-			case PBK_Text_LastName:
-			case PBK_Text_FirstName:
-				if (!found2) {
-					printf(" (");
-					found2=TRUE;
-				} else {
-					if (!found) {
-						printf(", ");
-					} else {
-						printf(" ");
-					}
-				}
-				printf("%s",DecodeUnicodeConsole(Info->PhonePhonebook[i]->Entries[z].Text));
-				found=TRUE;
-				break;
-			default:
-				break;
-			}
-		}
-		for (z=0;z<Info->PhonePhonebook[i]->EntriesNum;z++) {
-			switch (Info->PhonePhonebook[i]->Entries[z].EntryType) {
-			case PBK_Text_Name:
-				if (!found2) {
-					printf(" (");
-					found2=TRUE;
-				} else {
-					printf(", ");
-				}
-				printf("%s",DecodeUnicodeConsole(Info->PhonePhonebook[i]->Entries[z].Text));
-				break;
-			default:
-				break;
-			}
-		}
-		printf(")");
-		break;
+	/* First try phone phonebook */
+	pbk = SearchPhoneNumber(number, (const GSM_MemoryEntry **)Info->PhonePhonebook, &pos);
+	if (pbk == NULL) {
+		/* Fall back to SIM */
+		pbk = SearchPhoneNumber(number, (const GSM_MemoryEntry **)Info->SIMPhonebook, &pos);
+	}
+
+	/* Nothing found */
+	if (pbk == NULL) return;
+
+	/* Print name */
+	printf("%s", DecodeUnicodeConsole(GSM_PhonebookGetEntryName(pbk)));
+
+	/* Print phone type */
+	switch (pbk->Entries[pos].EntryType) {
+		case PBK_Number_Mobile:
+			printf(" (%s)", _("mobile"));
+			break;
+		case PBK_Number_Work:
+			printf(" (%s)", _("work"));
+			break;
+		case PBK_Number_Fax:
+			printf(" (%s)", _("fax"));
+			break;
+		case PBK_Number_Home:
+			printf(" (%s)", _("home"));
+			break;
+		case PBK_Number_Pager:
+			printf(" (%s)", _("pager"));
+			break;
+		case PBK_Number_General:
+			printf(" (%s)", _("general"));
+			break;
+		default:
+			break;
 	}
 }
 
@@ -158,10 +137,10 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean dis
 
 		printf(LISTFORMAT, _("Status"));
 		switch (sms.State) {
-			case SMS_Sent	: printf(_("Sent"));	break;
-			case SMS_Read	: printf(_("Read"));	break;
-			case SMS_UnRead	: printf(_("UnRead"));	break;
-			case SMS_UnSent	: printf(_("UnSent"));	break;
+			case SMS_Sent	: printf("%s", _("Sent"));	break;
+			case SMS_Read	: printf("%s", _("Read"));	break;
+			case SMS_UnRead	: printf("%s", _("UnRead"));	break;
+			case SMS_UnSent	: printf("%s", _("UnSent"));	break;
 		}
 		printf("\n");
 
@@ -177,39 +156,39 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean dis
 		printf(LISTFORMAT, _("Details"));
 		if (sms.DeliveryStatus & 0x40) {
 			if (sms.DeliveryStatus & 0x20) {
-				printf(_("Temporary error, "));
+				printf("%s", _("Temporary error, "));
 			} else {
-	     			printf(_("Permanent error, "));
+	     			printf("%s", _("Permanent error, "));
 			}
 	    	} else if (sms.DeliveryStatus & 0x20) {
-			printf(_("Temporary error, "));
+			printf("%s", _("Temporary error, "));
 		}
 		switch (sms.DeliveryStatus) {
-			case 0x00: printf(_("SM received by the SME"));				break;
-			case 0x01: printf(_("SM forwarded by the SC to the SME but the SC is unable to confirm delivery"));break;
-			case 0x02: printf(_("SM replaced by the SC"));				break;
-			case 0x20: printf(_("Congestion"));					break;
-			case 0x21: printf(_("SME busy"));					break;
-			case 0x22: printf(_("No response from SME"));				break;
-			case 0x23: printf(_("Service rejected"));				break;
-			case 0x24: printf(_("Quality of service not available"));		break;
-			case 0x25: printf(_("Error in SME"));					break;
-		        case 0x40: printf(_("Remote procedure error"));				break;
-		        case 0x41: printf(_("Incompatibile destination"));			break;
-		        case 0x42: printf(_("Connection rejected by SME"));			break;
-		        case 0x43: printf(_("Not obtainable"));					break;
-		        case 0x44: printf(_("Quality of service not available"));		break;
-		        case 0x45: printf(_("No internetworking available"));			break;
-		        case 0x46: printf(_("SM Validity Period Expired"));			break;
-		        case 0x47: printf(_("SM deleted by originating SME"));			break;
-		        case 0x48: printf(_("SM Deleted by SC Administration"));			break;
-		        case 0x49: printf(_("SM does not exist"));				break;
-		        case 0x60: printf(_("Congestion"));					break;
-		        case 0x61: printf(_("SME busy"));					break;
-		        case 0x62: printf(_("No response from SME"));				break;
-		        case 0x63: printf(_("Service rejected"));				break;
-		        case 0x64: printf(_("Quality of service not available"));		break;
-		        case 0x65: printf(_("Error in SME"));					break;
+			case 0x00: printf("%s", _("SM received by the SME"));				break;
+			case 0x01: printf("%s", _("SM forwarded by the SC to the SME but the SC is unable to confirm delivery"));break;
+			case 0x02: printf("%s", _("SM replaced by the SC"));				break;
+			case 0x20: printf("%s", _("Congestion"));					break;
+			case 0x21: printf("%s", _("SME busy"));					break;
+			case 0x22: printf("%s", _("No response from SME"));				break;
+			case 0x23: printf("%s", _("Service rejected"));				break;
+			case 0x24: printf("%s", _("Quality of service not available"));		break;
+			case 0x25: printf("%s", _("Error in SME"));					break;
+		        case 0x40: printf("%s", _("Remote procedure error"));				break;
+		        case 0x41: printf("%s", _("Incompatibile destination"));			break;
+		        case 0x42: printf("%s", _("Connection rejected by SME"));			break;
+		        case 0x43: printf("%s", _("Not obtainable"));					break;
+		        case 0x44: printf("%s", _("Quality of service not available"));		break;
+		        case 0x45: printf("%s", _("No internetworking available"));			break;
+		        case 0x46: printf("%s", _("SM Validity Period Expired"));			break;
+		        case 0x47: printf("%s", _("SM deleted by originating SME"));			break;
+		        case 0x48: printf("%s", _("SM Deleted by SC Administration"));			break;
+		        case 0x49: printf("%s", _("SM does not exist"));				break;
+		        case 0x60: printf("%s", _("Congestion"));					break;
+		        case 0x61: printf("%s", _("SME busy"));					break;
+		        case 0x62: printf("%s", _("No response from SME"));				break;
+		        case 0x63: printf("%s", _("Service rejected"));				break;
+		        case 0x64: printf("%s", _("Quality of service not available"));		break;
+		        case 0x65: printf("%s", _("Error in SME"));					break;
 		        default  : printf(_("Reserved/Specific to SC: %x"),sms.DeliveryStatus);	break;
 		}
 		printf("\n");
@@ -220,7 +199,7 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean dis
 			printf(LISTFORMAT "%s\n", _("Saved"), OSDateTime(sms.DateTime,TRUE));
 		} else {
 			printf(LISTFORMAT "\"%s\"", _("SMSC number"), DecodeUnicodeConsole(sms.SMSC.Number));
-			if (sms.ReplyViaSameSMSC) printf(_(" (set for reply)"));
+			if (sms.ReplyViaSameSMSC) printf("%s", _(" (set for reply)"));
 			printf("\n");
 			printf(LISTFORMAT "%s\n", _("Sent"), OSDateTime(sms.DateTime,TRUE));
 		}
@@ -233,10 +212,12 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean dis
 		/* If we went here from "case SMS_Deliver", we don't write "SMS Message" */
 		if (sms.PDU==SMS_Submit) {
 			printf("%s\n", _("SMS message"));
-			if (sms.State==SMS_UnSent && sms.Memory==MEM_ME) {
-			} else {
+			if (sms.State == SMS_Sent) {
 				printf(LISTFORMAT "%d\n", _("Reference number"),sms.MessageReference);
 			}
+			if (CheckDate(&(sms.DateTime)) && CheckTime(&(sms.DateTime))) {
+				printf(LISTFORMAT "%s\n", _("Sent"), OSDateTime(sms.DateTime,TRUE));
+			}
 		}
 		if (sms.Name[0] != 0x00 || sms.Name[1] != 0x00) {
 			printf(LISTFORMAT "\"%s\"\n", _("Name"),DecodeUnicodeConsole(sms.Name));
@@ -247,20 +228,20 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean dis
 		printf(LISTFORMAT, _("Coding"));
 		switch (sms.Coding) {
 			case SMS_Coding_Unicode_No_Compression 	:
-				printf(_("Unicode (no compression)"));
+				printf("%s", _("Unicode (no compression)"));
 				break;
 			case SMS_Coding_Unicode_Compression 	:
-				printf(_("Unicode (compression)"));
+				printf("%s", _("Unicode (compression)"));
 				break;
 			case SMS_Coding_Default_No_Compression 	:
-				printf(_("Default GSM alphabet (no compression)"));
+				printf("%s", _("Default GSM alphabet (no compression)"));
 				break;
 			case SMS_Coding_Default_Compression 	:
-				printf(_("Default GSM alphabet (compression)"));
+				printf("%s", _("Default GSM alphabet (compression)"));
 				break;
 			case SMS_Coding_8bit			:
 				/* l10n: 8-bit message coding */
-				printf(_("8-bit"));
+				printf("%s", _("8-bit"));
 				break;
 		}
 		printf("\n");
@@ -276,36 +257,36 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean dis
 		}
 		printf(LISTFORMAT, _("Status"));
 		switch (sms.State) {
-			case SMS_Sent	:	printf(_("Sent"));	break;
-			case SMS_Read	:	printf(_("Read"));	break;
-			case SMS_UnRead	:	printf(_("UnRead"));	break;
-			case SMS_UnSent	:	printf(_("UnSent"));	break;
+			case SMS_Sent	:	printf("%s", _("Sent"));	break;
+			case SMS_Read	:	printf("%s", _("Read"));	break;
+			case SMS_UnRead	:	printf("%s", _("UnRead"));	break;
+			case SMS_UnSent	:	printf("%s", _("UnSent"));	break;
 		}
 		printf("\n");
 		if (sms.UDH.Type != UDH_NoUDH) {
 			printf(LISTFORMAT, _("User Data Header"));
 			switch (sms.UDH.Type) {
-			case UDH_ConcatenatedMessages	   : printf(_("Concatenated (linked) message")); 	 break;
-			case UDH_ConcatenatedMessages16bit : printf(_("Concatenated (linked) message")); 	 break;
-			case UDH_DisableVoice		   : printf(_("Disables voice indicator"));	 	 break;
-			case UDH_EnableVoice		   : printf(_("Enables voice indicator"));	 	 break;
-			case UDH_DisableFax		   : printf(_("Disables fax indicator"));	 	 break;
-			case UDH_EnableFax		   : printf(_("Enables fax indicator"));	 		 break;
-			case UDH_DisableEmail		   : printf(_("Disables email indicator"));	 	 break;
-			case UDH_EnableEmail		   : printf(_("Enables email indicator"));	 	 break;
-			case UDH_VoidSMS		   : printf(_("Void SMS"));			 	 break;
-			case UDH_NokiaWAP		   : printf(_("Nokia WAP bookmark"));		 	 break;
-			case UDH_NokiaOperatorLogoLong	   : printf(_("Nokia operator logo"));	 	 	 break;
-			case UDH_NokiaWAPLong		   : printf(_("Nokia WAP bookmark or WAP/MMS settings")); break;
-			case UDH_NokiaRingtone		   : printf(_("Nokia ringtone"));		 	 break;
-			case UDH_NokiaRingtoneLong	   : printf(_("Nokia ringtone"));		 	 break;
-			case UDH_NokiaOperatorLogo	   : printf(_("Nokia GSM operator logo"));	 	 break;
-			case UDH_NokiaCallerLogo	   : printf(_("Nokia caller logo"));		 	 break;
-			case UDH_NokiaProfileLong	   : printf(_("Nokia profile"));		 		 break;
-			case UDH_NokiaCalendarLong	   : printf(_("Nokia calendar note"));	 		 break;
-			case UDH_NokiaPhonebookLong	   : printf(_("Nokia phonebook entry"));	 		 break;
-			case UDH_UserUDH		   : printf(_("User UDH"));			 	 break;
-			case UDH_MMSIndicatorLong	   : printf(_("MMS indicator"));			 	 break;
+			case UDH_ConcatenatedMessages	   : printf("%s", _("Concatenated (linked) message")); 	 break;
+			case UDH_ConcatenatedMessages16bit : printf("%s", _("Concatenated (linked) message")); 	 break;
+			case UDH_DisableVoice		   : printf("%s", _("Disables voice indicator"));	 	 break;
+			case UDH_EnableVoice		   : printf("%s", _("Enables voice indicator"));	 	 break;
+			case UDH_DisableFax		   : printf("%s", _("Disables fax indicator"));	 	 break;
+			case UDH_EnableFax		   : printf("%s", _("Enables fax indicator"));	 		 break;
+			case UDH_DisableEmail		   : printf("%s", _("Disables email indicator"));	 	 break;
+			case UDH_EnableEmail		   : printf("%s", _("Enables email indicator"));	 	 break;
+			case UDH_VoidSMS		   : printf("%s", _("Void SMS"));			 	 break;
+			case UDH_NokiaWAP		   : printf("%s", _("Nokia WAP bookmark"));		 	 break;
+			case UDH_NokiaOperatorLogoLong	   : printf("%s", _("Nokia operator logo"));	 	 	 break;
+			case UDH_NokiaWAPLong		   : printf("%s", _("Nokia WAP bookmark or WAP/MMS settings")); break;
+			case UDH_NokiaRingtone		   : printf("%s", _("Nokia ringtone"));		 	 break;
+			case UDH_NokiaRingtoneLong	   : printf("%s", _("Nokia ringtone"));		 	 break;
+			case UDH_NokiaOperatorLogo	   : printf("%s", _("Nokia GSM operator logo"));	 	 break;
+			case UDH_NokiaCallerLogo	   : printf("%s", _("Nokia caller logo"));		 	 break;
+			case UDH_NokiaProfileLong	   : printf("%s", _("Nokia profile"));		 		 break;
+			case UDH_NokiaCalendarLong	   : printf("%s", _("Nokia calendar note"));	 		 break;
+			case UDH_NokiaPhonebookLong	   : printf("%s", _("Nokia phonebook entry"));	 		 break;
+			case UDH_UserUDH		   : printf("%s", _("User UDH"));			 	 break;
+			case UDH_MMSIndicatorLong	   : printf("%s", _("MMS indicator"));			 	 break;
 			case UDH_NoUDH:								 		 break;
 			}
 			if (sms.UDH.Type != UDH_NoUDH) {
@@ -323,8 +304,8 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean dis
 		}
 		if (displaytext) {
 			printf("\n");
-			if (sms.Coding!=SMS_Coding_8bit) {
-				printf("%s\n",DecodeUnicodeConsole(sms.Text));
+			if (sms.Coding != SMS_Coding_8bit) {
+				printf("%s\n", DecodeUnicodeConsole(sms.Text));
 			} else {
 				if (GSM_DecodeSiemensOTASMS(GSM_GetGlobalDebug(), &SiemensOTA,&sms)) {
 					printf("%s\n", _("Siemens file"));
@@ -340,6 +321,7 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean dis
 		break;
 #endif
 	}
+	fflush(stdout);
 }
 
 void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, gboolean eachsms, gboolean ems, const GSM_Backup *Info, GSM_StateMachine *sm)
@@ -383,7 +365,7 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, gboolean eachsms, gboolean e
 	for (i=0;i<SMSInfo.EntriesNum;i++) {
 		switch (SMSInfo.Entries[i].ID) {
 		case SMS_SiemensFile:
-			printf(_("Siemens OTA file"));
+			printf("%s", _("Siemens OTA file"));
 			if (strstr(DecodeUnicodeString(SMSInfo.Entries[i].File->Name),".vcf")) {
 				printf("%s\n", _(" - VCARD"));
 				SMSInfo.Entries[i].File->Buffer = realloc(SMSInfo.Entries[i].File->Buffer,1+SMSInfo.Entries[i].File->Used);
@@ -404,7 +386,7 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, gboolean eachsms, gboolean e
 			printf("\n");
 #if 0
 			/* Disabled for now */
-			if (answer_yes(_("Do you want to play it?")))
+			if (answer_yes("%s", _("Do you want to play it?")))
 				GSM_PlayRingtone(*SMSInfo.Entries[i].Ringtone);
 #endif
 			break;
@@ -459,6 +441,12 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, gboolean eachsms, gboolean e
 		case SMS_EMSPredefinedAnimation:
 			printf("\n" LISTFORMAT "%i\n", _("EMS animation ID"),SMSInfo.Entries[i].Number);
 			break;
+		case SMS_MMSIndicatorLong:
+			printf(LISTFORMAT "%s\n", _("Sender"),SMSInfo.Entries[i].MMSIndicator->Sender);
+			printf(LISTFORMAT "%s\n", _("Subject"),SMSInfo.Entries[i].MMSIndicator->Title);
+			printf(LISTFORMAT "%s\n", _("Address"),SMSInfo.Entries[i].MMSIndicator->Address);
+			printf(LISTFORMAT "%li\n", _("Message size"), (long)SMSInfo.Entries[i].MMSIndicator->MessageSize);
+			break;
 		case SMS_Text:
 		case SMS_NokiaRingtoneLong:
 		case SMS_NokiaOperatorLogoLong:
@@ -483,7 +471,6 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, gboolean eachsms, gboolean e
 		case SMS_EMSSound12Long:
 		case SMS_EMSSonyEricssonSoundLong:
 		case SMS_EMSVariableBitmapLong:
-		case SMS_MMSIndicatorLong:
 		case SMS_WAPIndicatorLong:
 		case SMS_AlcatelMonoBitmapLong:
 		case SMS_AlcatelMonoAnimationLong:
@@ -496,6 +483,7 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, gboolean eachsms, gboolean e
 		}
 	}
 	printf("\n");
+	fflush(stdout);
 	GSM_FreeMultiPartSMSInfo(&SMSInfo);
 }
 
@@ -545,6 +533,7 @@ void DisplaySMSFrame(GSM_SMSMessage *SMS, GSM_StateMachine *sm)
 	EncodeHexBin(hexreq, req, current);
         printf(LISTFORMAT "%s\n", _("Whole PDU"), hexreq);
 	printf("\n");
+	fflush(stdout);
 }
 
 /* How should editor hadle tabs in this file? Add editor commands here.
