@@ -62,6 +62,22 @@ typedef enum {
 	GSM_RequestingNetwork
 } GSM_NetworkInfo_State;
 
+/**
+ * Status of GPRS connection.
+ *
+ * \ingroup Info
+ */
+typedef enum {
+	/**
+	 * GRPS is detached.
+	 */
+	GSM_GPRS_Detached = 1,
+	/**
+	 * GRPS is attached.
+	 */
+	GSM_GPRS_Attached
+} GSM_GPRS_State;
+
 /**
  * Structure for getting the current network info.
  *
@@ -71,7 +87,7 @@ typedef struct {
 	/**
 	 * Cell ID (CID)
 	 */
-	unsigned char CID[10];
+	char CID[10];
 	/**
 	 * GSM network code.
 	 */
@@ -84,11 +100,15 @@ typedef struct {
 	/**
 	 * LAC (Local Area Code).
 	 */
-	unsigned char LAC[10];
+	char LAC[10];
 	/**
 	 * Name of current network like returned from phone (or empty).
 	 */
 	unsigned char NetworkName[15 * 2];
+	/**
+	 * GPRS state.
+	 */
+	GSM_GPRS_State GPRS;
 } GSM_NetworkInfo;
 
 /**
@@ -588,6 +608,18 @@ typedef enum {
 	 * Phone does not end CPIN reply with OK/ERROR.
 	 */
 	F_CPIN_NO_OK,
+	/**
+	 * Phone require four digit year in time.
+	 */
+	F_FOUR_DIGIT_YEAR,
+	/**
+	 * Phone does not have a phone SMS memory even if it reports so.
+	 */
+	F_SMS_NO_ME,
+	/**
+	 * Phone does not have a SIM SMS memory even if it reports so.
+	 */
+	F_SMS_NO_SM,
 
 	/**
 	 * Just marker of highest feature code, should not be used.
