@@ -11,7 +11,6 @@
 #include <errno.h>
 #include <string.h>
 
-//#include "../../misc/coding/coding.h"
 #include "../../gsmcomon.h"
 #include "../devfunc.h"
 #include "bluetoth.h"
@@ -45,13 +44,19 @@ GSM_Error bluetooth_findrfchannel(GSM_StateMachine *s)
 	}
 
 	/* Does the string contain channel information? */
+	/* Default device on *NIX is /dev/.., so we need to ignore it here as well. */
 	channel = strchr(device, '/');
-	if (channel == NULL &&
+	if ((device[0] == '/' || channel == NULL) &&
 			strncasecmp(s->CurrentConfig->Connection, "bluerf", 6) != 0) {
 		free(device);
+		device=NULL;
 #ifdef BLUETOOTH_RF_SEARCHING
 		return bluetooth_findchannel(s);
 #else
+		smprintf(s, "WARNING: Channel searching not implemented on your platform!\n");
+		smprintf(s, "Please user bluerf* connection or define channel in configuration\n");
+		smprintf(s, "You can specify channel by adding it after phone address separated by slash\n");
+		smprintf(s, "For example: 11:22:33:44:55:66/12\n");
 		return ERR_SOURCENOTAVAILABLE;
 #endif
 	}
@@ -116,6 +121,7 @@ GSM_Error bluetooth_findrfchannel(GSM_StateMachine *s)
 
 done:
 	free(device);
+	device=NULL;
 	return error;
 }
 
