@@ -95,9 +95,9 @@ static PrintErrorEntry PrintErrorEntries[] = {
 	{ERR_DEVICEREADERROR, "DEVICEREADERROR",		N_("Error during reading from the device.")},
 	{ERR_DEVICEPARITYERROR, "DEVICEPARITYERROR",		N_("Can't set parity on the device.")},
 	{ERR_TIMEOUT, "TIMEOUT",			N_("No response in specified timeout. Probably phone not connected.")},
-	{ERR_FRAMENOTREQUESTED, "FRAMENOTREQUESTED",		N_("Frame not requested right now. See <http://cihar.com/gammu/report> for information how to report it.")},
-	{ERR_UNKNOWNRESPONSE, "UNKNOWNRESPONSE",		N_("Unknown response from phone. See <http://cihar.com/gammu/report> for information how to report it.")},
-	{ERR_UNKNOWNFRAME, "UNKNOWNFRAME",		N_("Unknown frame. See <http://cihar.com/gammu/report> for information how to report it.")},
+	{ERR_FRAMENOTREQUESTED, "FRAMENOTREQUESTED",		N_("Frame not requested right now. See <http://wammu.eu/support/bugs/> for information how to report it.")},
+	{ERR_UNKNOWNRESPONSE, "UNKNOWNRESPONSE",		N_("Unknown response from phone. See <http://wammu.eu/support/bugs/> for information how to report it.")},
+	{ERR_UNKNOWNFRAME, "UNKNOWNFRAME",		N_("Unknown frame. See <http://wammu.eu/support/bugs/> for information how to report it.")},
 	{ERR_UNKNOWNCONNECTIONTYPESTRING, "UNKNOWNCONNECTIONTYPESTRING",N_("Unknown connection type string. Check config file.")},
 	{ERR_UNKNOWNMODELSTRING, "UNKNOWNMODELSTRING",	N_("Unknown model type string. Check config file.")},
 	{ERR_SOURCENOTAVAILABLE, "SOURCENOTAVAILABLE",	N_("Some functions not available for your system (disabled in config or not implemented).")},
@@ -110,7 +110,7 @@ static PrintErrorEntry PrintErrorEntries[] = {
 	{ERR_UNKNOWN, "UNKNOWN",			N_("Unknown error.")},
 	{ERR_CANTOPENFILE, "CANTOPENFILE",		N_("Can not open specified file.")},
 	{ERR_MOREMEMORY, "MOREMEMORY",		N_("More memory required...")},
-	{ERR_PERMISSION, "PERMISSION",		N_("Permission to file/device required...")},
+	{ERR_PERMISSION, "PERMISSION",		N_("Operation not allowed by phone.")},
 	{ERR_EMPTYSMSC, "EMPTYSMSC",			N_("Empty SMSC number. Set in phone or use -smscnumber.")},
 	{ERR_INSIDEPHONEMENU, "INSIDEPHONEMENU",		N_("You're inside phone menu (maybe editing?). Leave it and try again.")},
 	{ERR_NOTCONNECTED, "NOTCONNECTED",		N_("Phone is not connected.")},
@@ -125,7 +125,7 @@ static PrintErrorEntry PrintErrorEntries[] = {
 	{ERR_INVALIDDATETIME, "INVALIDDATETIME",		N_("Invalid date or time specified.")},
 	{ERR_MEMORY, "MEMORY",			N_("Phone memory error, maybe it is read only.")},
 	{ERR_INVALIDDATA, "INVALIDDATA",		N_("Invalid data given to phone.")},
-	{ERR_FILEALREADYEXIST, "FILEALREADYEXIST",		N_("File with specified name already exist.")},
+	{ERR_FILEALREADYEXIST, "FILEALREADYEXIST",		N_("File with specified name already exists.")},
 	{ERR_FILENOTEXIST, "FILENOTEXIST",		N_("File with specified name doesn't exist.")},
 	{ERR_SHOULDBEFOLDER, "SHOULDBEFOLDER",		N_("You have to give folder name and not file name.")},
 	{ERR_SHOULDBEFILE, "SHOULDBEFILE",		N_("You have to give file name and not folder name.")},
@@ -147,14 +147,16 @@ static PrintErrorEntry PrintErrorEntries[] = {
 	{ERR_NOTRUNNING, "NOTRUNNING", N_("Service is not runnig.")},
 	{ERR_NOSERVICE, "NOSERVICE", N_("Service configuration is missing.")},
 	{ERR_BUSY, "BUSY", N_("Command rejected because device was busy. Wait and restart.")},
+	{ERR_COULDNT_CONNECT, "COULDNT_CONNECT", N_("Could not connect to the server.")},
+	{ERR_COULDNT_RESOLVE, "COULDNT_RESOLVE", N_("Could not resolve the host name.")},
 
 	{0,	"",				""}
 };
 
 const char *GSM_ErrorName(GSM_Error e)
 {
-	const char	*def 	= NULL;
-	int	i	= 0;
+	const char *def = NULL;
+	int i = 0;
 
 	while (PrintErrorEntries[i].ErrorNum != 0) {
 		if (PrintErrorEntries[i].ErrorNum == e) {
@@ -169,8 +171,8 @@ const char *GSM_ErrorName(GSM_Error e)
 
 const char *GSM_ErrorString(GSM_Error e)
 {
-	const char	*def 	= NULL;
-	int	i	= 0;
+	const char *def	= NULL;
+	int i = 0;
 
 	while (PrintErrorEntries[i].ErrorNum != 0) {
 		if (PrintErrorEntries[i].ErrorNum == e) {
