@@ -17,9 +17,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-#ifdef HAVE_WCTYPE_H
-#  include <wctype.h>
-#endif
+#include <ctype.h>
 
 #include "../helper/string.h"
 
@@ -113,6 +111,9 @@ GSM_FeatureName AllFeatureNames[] = {
 	{"ENCODED_USSD", F_ENCODED_USSD},
 	{"USE_SMSTEXTMODE", F_USE_SMSTEXTMODE},
 	{"CPIN_NO_OK", F_CPIN_NO_OK},
+	{"FOUR_DIGIT_YEAR", F_FOUR_DIGIT_YEAR},
+	{"SMS_NO_ME", F_SMS_NO_ME},
+	{"SMS_NO_SM", F_SMS_NO_SM},
 	{"", 0},
 };
 
@@ -154,7 +155,7 @@ GSM_Error GSM_SetFeatureString(GSM_Feature *list, const char *string)
 			*end = 0;
 		}
 
-		while (iswspace(*pos))
+		while (isspace(*pos))
 			pos++;
 
 		while ((tmp = strchr(pos, ' ')) != NULL)
@@ -180,9 +181,8 @@ GSM_Error GSM_SetFeatureString(GSM_Feature *list, const char *string)
 			break;
 		}
 	}
-
-
 	free(buffer);
+	buffer=NULL;
 	return error;
 }
 
@@ -256,6 +256,7 @@ GSM_PhoneModel allmodels[] = {
 	{"1209", "RH-105","Nokia 1209", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2125i","RH-71" ,"Nokia 2125i",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"1600", "RH-64" ,"Nokia 1600",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
+	{"1650", "RM-305","Nokia 1650",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,0}},/* guess */
 	{"1680", "RM-394","Nokia 1680",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,0}},/* guess */
 	{"1681c","RH-118","Nokia 1681c",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,0}},/* guess */
 	{"2600", "RH-340","Nokia 2600",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
@@ -264,6 +265,7 @@ GSM_PhoneModel allmodels[] = {
 	{"2610", "RH-87" ,"Nokia 2610",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2630", "RM-298","Nokia 2630",{F_SERIES40_30,F_FILES2,F_TODO66,F_PBKUSER,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKFAVORITEMESSAGE,F_6230iCALLER,0}},/* guess */
 	{"2630b","RM-299","Nokia 2630b",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKFAVORITEMESSAGE,F_6230iCALLER,0}},/* guess */
+	{"2660", "RM-292","Nokia 2660", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2680", "RM-392","Nokia 2680", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2760", "RM-258","Nokia 2760",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"3109c","RM-274","Nokia 3109c",{F_SERIES40_30,F_FILES2,F_TODO66,F_PBKUSER,F_PBKTONEGAL,F_NOTES,F_SMS_FILES,F_CHAT,F_SYNCML,F_6230iCALLER,0}},/* guess */
@@ -271,6 +273,8 @@ GSM_PhoneModel allmodels[] = {
 	{"3220" ,"RH-37" ,"",           {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_SYNCML,F_FILES2,F_3220_MMS,0}},
 	{"3220" ,"RH-49" ,"",           {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_SYNCML,F_FILES2,F_3220_MMS,0}},
 	{"3500" ,"RM-272","Nokia 3500", {F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},/* guess */
+	{"3500" ,"RM-273","Nokia 3500", {F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},/* guess */
+	{"3720c","RM-518","Nokia 3720c",{F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},/* guess */
 	{"5000", "RM-362","Nokia 5000", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"5100" ,"NPM-6" ,"Nokia 5100", {F_PBKTONEGAL,F_TODO66,F_RADIO,0}},
 	{"5130" ,"RM-495","Nokia 5130", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
@@ -284,6 +288,7 @@ GSM_PhoneModel allmodels[] = {
 	{"5300" ,"RM-146","Nokia 5300", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
 	{"5310" ,"RM-303","Nokia 5310", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"6020" ,"RM-30" ,"Nokia 6020", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES,0}},/* guess */
+	{"6020b","RM-31" ,"Nokia 6020b", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES,0}},/* guess */
 	{"6021" ,"RM-94" ,"Nokia 6021", {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,F_6230iWAP,F_6230iCALLER,0}},/* guess */
 	{"6030" ,"RM-74" ,"Nokia 6030", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES, F_NOFILE1, F_RADIO,0}},/* guess */
 	{"6030b","RM-75" ,"Nokia 6030b",{F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES, F_NOFILE1,0}},/* guess */
@@ -300,6 +305,7 @@ GSM_PhoneModel allmodels[] = {
 	{"6103" ,"RM-161","Nokia 6103", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_NOFILE1,0}},/* fixme */
 	{"6102i","RM-162","Nokia 6102i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_NOFILE1,0}},/* fixme */
 	{"6111" ,"RM-82" ,"Nokia 6111", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
+	{"6111" ,"RM-92" ,"Nokia 6111", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
 	{"6125" ,"RM-178","Nokia 6125", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6126" ,"RM-124","Nokia 6126", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6131" ,"RM-115","Nokia 6131", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
@@ -316,16 +322,23 @@ GSM_PhoneModel allmodels[] = {
 	{"6233" ,"RM-145","Nokia 6233", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6234" ,"RM-123","Nokia 6234", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6270" ,"RM-56","Nokia 6270", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
+	{"6275i","RM-154","Nokia 6275i", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6280" ,"RM-78","Nokia 6280", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_6230iCALLER,0}},/* fixme */
 	{"6300" ,"RM-217" ,"Nokia 6300", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
+	{"6303c","RM-443" ,"Nokia 6303c", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
 	{"6310" ,"NPE-4" ,"Nokia 6310", {F_TODO63,F_CAL65,F_NOMIDI,F_NOMMS,F_VOICETAGS,0}},
 	{"6310i","NPL-1" ,"Nokia 6310i",{F_TODO63,F_CAL65,F_NOMIDI,F_BLUETOOTH,F_NOMMS,F_VOICETAGS,F_PROFILES,0}},
+	{"6340i","RH-13" ,"Nokia 6340i",{F_TODO63,F_CAL65,F_NOMIDI,F_BLUETOOTH,F_NOMMS,F_VOICETAGS,F_PROFILES,0}},
+	{"6350", "RM-455","Nokia 6350", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6385" ,"NHP-2AX","Nokia 6385",{F_TODO63,F_CAL65,F_NOMIDI,F_NOMMS,F_VOICETAGS,0}},
 	{"6500s","RM-240","Nokia 6500s", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6500c","RM-265","Nokia 6500c", {F_SERIES40_30,F_FILES2,F_TODO66,F_NOTES,F_SMS_FILES,0}},
 	{"6510" ,"NPM-9" ,"Nokia 6510", {F_TODO63,F_CAL65,F_NOMIDI,F_RADIO,F_NOFILESYSTEM,F_NOMMS,F_VOICETAGS,0}},
 	{"6610" ,"NHL-4U","Nokia 6610", {F_PBKTONEGAL,F_TODO66,F_RADIO,0}},
 	{"6610i","RM-37" ,"Nokia 6610i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_SYNCML,0}},
+	{"6600", "RM-325","Nokia 6600", {F_SERIES40_30,F_FILES2,F_TODO66,F_NOTES,F_SMS_FILES,0}},
+	{"6600s","RM-570","Nokia 6600s",{F_SERIES40_30,F_FILES2,F_TODO66,F_NOTES,F_SMS_FILES,0}},
+	{"6750-1b","RM-381","Nokia 3750-1b", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6800" ,"NSB-9" ,"Nokia 6800", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,0}},
 	{"6800" ,"NHL-6" ,"Nokia 6800", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,0}},
 	{"6810" ,"RM-2"  ,"Nokia 6810", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_NOTES,F_CHAT,F_SYNCML,0}},/* guess */
@@ -375,6 +388,7 @@ GSM_PhoneModel allmodels[] = {
 	/* Siemens */
 	{"M20"  ,	  "M20",	  "",				   {F_M20SMS,F_SLOWWRITE,0}},
 	{"MC35" ,	  "MC35",	  "",				   {0}},
+	{"MC35i" ,	  "MC35i",	  "",				   {0}},
 	{"TC35" ,	  "TC35",	  "",				   {0}},
 	{"S25",		  "S25",  	  "SIEMENS S25",		   {0}},
 	{"C35i" ,	  "C35i",	  "",				   {0}},
@@ -392,6 +406,7 @@ GSM_PhoneModel allmodels[] = {
 	{"ME45" ,	  "3618" ,	  "",				   {0}},
 	{"S55" ,	  "S55" ,	  "",				   {0}},
 	{"S65" ,	  "S65" ,	  "SIEMENS S65",		   {0}},
+	{"MC75" ,	  "MC75",	  "",				   {F_NO_ATOBEX, 0}},
 
 	/* Samsung */
 	{"E250",	  "SAMSUNG SGH-E250" , "",			   {F_FORCE_UTF8, F_SMS_SM, F_SMS_ME, 0}},
@@ -408,6 +423,7 @@ GSM_PhoneModel allmodels[] = {
 	{"J750",	  "SGH-J750" ,	  "",				   {F_NO_ATOBEX, 0}},
 	{"J700",	  "SGH-J700" ,	  "",				   {F_NO_ATOBEX, 0}},
 	{"J700",	  "SAMSUNG SGH-J700" , "",			   {F_NO_ATOBEX, 0}},
+	{"D980",	  "SAMSUNG SGH-D980" , "",			   {F_NO_ATOBEX, 0}},
 
 	/* Ericsson/Sony Ericsson */
 	{"T28s",	"1101101-BVT28s","",				   {F_OBEX, 0}},
@@ -592,7 +608,7 @@ GSM_PhoneModel allmodels[] = {
 	{"K530c",	"AAB-1022131-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"C902c",	"AAB-1022141-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"R300",	"AAB-1022151-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"R306",	"AAB-1022161-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"R306/R306c",	"AAB-1022161-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"T303",	"AAB-1022171-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"T616",	"AAB-1031011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"T637",	"AAB-1031012-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -609,6 +625,10 @@ GSM_PhoneModel allmodels[] = {
 	{"R300a",	"AAB-1032071-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"R306a",	"AAB-1032081-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"T303a",	"AAB-1032091-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W205",	"AAB-1880010-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W205a",	"AAB-1880011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"S312",	"AAB-1880013-BV" ,"S312",			   {F_OBEX, F_IRMC_LEVEL_2, F_SUBMIT_SIM_ONLY, 0}},
+	{"W395/W395c",	"AAB-1880014-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z520i/Z520c",	"AAC-1052011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z520a",	"AAC-1052012-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z525i",	"AAC-1052013-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -622,12 +642,12 @@ GSM_PhoneModel allmodels[] = {
 	{"W908c",	"AAC-1052051-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K858c",	"AAC-1052061-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W760c",	"AAC-1052101-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"C702a/C702c",	"AAC-1052141-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"F305c/F305",	"AAC-1052161-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"G502c",	"AAC-1052171-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"W595a",	"AAC-1052191-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"S302",	"AAC-1052121-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"C702a/C702c",	"AAC-1052141-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"C905c",	"AAC-1052151-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"F305/F305c",	"AAC-1052161-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"G502c",	"AAC-1052171-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W595a/W595c",	"AAC-1052191-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z1010",	"AAD-3011011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"V800/V802SE/Z800i",	"AAD-3021011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K600i",	"AAD-3021021-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -652,21 +672,23 @@ GSM_PhoneModel allmodels[] = {
 	{"W910i",	"AAD-3052021-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W890i",	"AAD-3052041-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"T700",	"AAD-3052042-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"Z770i",	"AAD-3052051-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"Z770i/Ducati",	"AAD-3052051-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K660i",	"AAD-3052071-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"C702",	"AAD-3052081-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W980",	"AAD-3052091-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"C902",	"AAD-3052101-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W595",	"AAD-3052111-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W595s",	"AAD-3052112-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"W902",	"AAD-3052121-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W902/W902 plus",	"AAD-3052121-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"TM506",	"AAD-3132011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"CS8",	"AAD-3152021-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K850i",	"AAD-3252011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z750i",	"AAD-3252022-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z750a",	"AAD-3252023-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W760i",	"AAD-3252041-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z780i",	"AAD-3252051-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"C905a",	"AAD-3252071-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"G705a",	"AAD-3252081-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"C905",	"AAD-3352021-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"G705/G705u",	"AAD-3352031-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"FOMA SO905i (PTX-824)",	"AAD-3624011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -675,6 +697,33 @@ GSM_PhoneModel allmodels[] = {
 	{"X1",	"AAD-3880001-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"X1a",	"AAD-3880002-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"FOMA SO706i (PTX-828)",	"AAD-3880003-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W705a",	"AAD-3880005-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W705/W705u",	"AAD-3880006-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"C901a",	"AAD-3880008-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"C510",	"AAD-3880009-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"C510a",	"AAD-3880010-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"C901",	"AAD-3880015-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W508",	"AAD-3880016-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W518a",	"AAD-3880017-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"U1i (Satio)",	"AAD-3880020-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W995",	"AAD-3880023-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W508a",	"AAD-3880024-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W715",	"AAD-3880025-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"C903",	"AAD-3380026-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"C903a",	"AAD-3880027-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"T707",	"AAD-3880029-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"TM717",	"AAD-3880030-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"T707a",	"AAD-3880031-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"U10i (Aino)",	"AAD-3880032-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"U10a (Aino)",	"AAD-3880033-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"W995a",	"AAD-3880035-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"U1a (Satio)",	"AAD-3880037-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"T715",	"AAD-3880039-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"T715a",	"AAD-3880040-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"F100i (Jalou)",	"AAD-3880041-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"U100i (Yari)",	"AAD-3880046-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"J105i (Naite)",	"AAD-3880052-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"J105a (Naite)",	"AAD-3880053-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K790i/K790c",	"AAF-1022011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z500a",	"AAF-1031011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"S710a",	"AAF-1031021-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -689,6 +738,8 @@ GSM_PhoneModel allmodels[] = {
 	{"Z502a",	"AAF-1061011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W62S (PTX-924)",	"AAH-5025011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"W64S (PTX-930)",	"AAH-5880001-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"SO001 (PTX-932)",	"AAH-5880002-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"SOX01 (PTX-934)",	"AAH-5880003-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"GR64",	"BAC-1051012-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"GS64",	"BAC-1051022-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"GA64",	"BAC-1051023-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -756,10 +807,13 @@ GSM_PhoneModel allmodels[] = {
 	{"E815m",	"E815m",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
 	{"V635",	"V635",	"",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
 	{"L7",		"L7", "",					   {F_NO_ATOBEX, F_CKPD_NO_UNICODE, F_USE_SMSTEXTMODE, 0}},
+	{"L7cm",	"L7cm", "",					   {F_NO_ATOBEX, F_CKPD_NO_UNICODE, F_USE_SMSTEXTMODE, 0}},
 	{"K1",		"K1", "",					   {F_NO_ATOBEX, F_PBK_UNICODE, F_USE_SMSTEXTMODE, 0}},
 	{"K1v",		"K1v", "",					   {F_NO_ATOBEX, F_PBK_UNICODE, 0}},
 	{"Z6c",		"Z6c", "",					   {F_NO_ATOBEX, F_PBK_UNICODE, 0}},
 	{"V180",	"V180", "",					   {F_NO_ATOBEX, 0}},
+	{"E790",	"E790", "",					   {F_NO_ATOBEX, 0}},
+	{"A1200e",	"A1200e", "",					   {F_NO_ATOBEX, 0}},
 	{"RAZRV3x",	"RAZRV3x",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
 
 	/* Sharp */
@@ -770,6 +824,8 @@ GSM_PhoneModel allmodels[] = {
 	{"iPAQ" ,	  "iPAQ"  ,	  "" ,				   {0}},
 	{"A2D"  ,	  "A2D"  ,	  "" ,				   {0}},
 	{"9210" ,	  "RAE-3",	  "Nokia Communicator GSM900/1800",{0}},
+	{"MTK1" ,	  "MTK1",	  "",				   {0}},
+	{"MTK2" ,	  "MTK2",	  "",				   {0}},
 
 	/* Sagem */
 	{"myV-65",	"myV-65 GPRS",	  "",				   {F_SMSME900,0}},
@@ -779,11 +835,18 @@ GSM_PhoneModel allmodels[] = {
 	{"KG800", "KG800", "", {F_NO_UCS2, 0}},
 
 	/* Huawei */
+	{"E17X",	"E17X",		"",		{F_NO_UCS2, 0}},
 	{"E220",	"E220",		"",		{0}},
-	{"E160",	"E160",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, 0}},
-	{"E162",	"E162",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, 0}},
-	{"E160G",	"E160G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, 0}},
-	{"E162G",	"E162G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, 0}},
+	{"E160",	"E160",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
+	{"E161",	"E161",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
+	{"E162",	"E162",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
+	{"E160G",	"E160G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
+	{"E162G",	"E162G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
+	{"E169",	"E169",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
+	{"E169G",	"E169G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, F_FOUR_DIGIT_YEAR, 0}},
+
+	/* Ubinetics */
+	{"GDC201",	"GDC201",	"",		{F_SMS_NO_ME, 0}},
 
 #endif
 #if defined(GSM_ENABLE_ATGEN) || defined(GSM_ENABLE_ALCATEL)
@@ -823,7 +886,7 @@ GSM_PhoneModel *GetModelData(GSM_StateMachine *s, const char *model, const char
 
 gboolean GSM_IsPhoneFeatureAvailable(GSM_PhoneModel *model, GSM_Feature feature)
 {
-	int	i	= 0;
+	int i = 0;
 
 	while (model->features[i] != 0) {
 		if (model->features[i] == feature) {
