@@ -22,9 +22,15 @@
 
 #include "../helper/string.h"
 
+#if defined(HAVE_GETPWUID) && defined(HAVE_GETUID)
+#include <sys/types.h>
+#include <pwd.h>
+#include <unistd.h>
+#endif
+
 #if defined(WIN32) || defined(DJGPP)
 /* Needed for SHGFP_TYPE_CURRENT */
-#define _WIN32_IE 0x0500
+#define _WIN32_IE 0x0501
 #include <shlobj.h>
 
 #define FALLBACK_GAMMURC "gammurc"
@@ -60,9 +66,21 @@ static void GSM_RegisterConnection(GSM_StateMachine *s, unsigned int connection,
 	}
 }
 
+/**
+ * Information about connection names and parameters.
+ */
 typedef struct {
+	/**
+	 * Name of the connection used in config file.
+	 */
 	const char *Name;
+	/**
+	 * Connection type.
+	 */
 	const GSM_ConnectionType Connection;
+	/**
+	 * Whether to disable DTR/RTS handling on this connection.
+	 */
 	gboolean SkipDtrRts;
 } GSM_ConnectionInfo;
 
@@ -195,6 +213,7 @@ static GSM_Error GSM_RegisterAllConnections(GSM_StateMachine *s, const char *con
 
 	/* Free allocated memory */
 	free(buff);
+	buff = NULL;
 
 	if (s->ConnectionType == 0) {
 		return ERR_UNKNOWNCONNECTIONTYPESTRING;
@@ -371,7 +390,7 @@ GSM_Error GSM_RegisterAllPhoneModules(GSM_StateMachine *s)
 				s->ConnectionType ==  GCT_BLUEPHONET) {
 			/* Try to detect phone type */
 			if (strcmp(model->model, "unknown") == 0 && model->features[0] == 0) {
-				smprintf(s, "WARNING: phone not known, please report it to authors (see <http://cihar.com/gammu/report>). Thank you.\n");
+				smprintf(s, "WARNING: phone not known, please report it to authors (see <http://wammu.eu/support/bugs/>). Thank you.\n");
 				if (strncmp(s->Phone.Data.Model, "RM-", 3) == 0) {
 					/* 167 is really a wild guess */
 					if (atoi(s->Phone.Data.Model + 3) > 167) {
@@ -408,12 +427,12 @@ GSM_Error GSM_RegisterAllPhoneModules(GSM_StateMachine *s)
 #endif
 		if (model->model[0] == 0) return ERR_UNKNOWNMODELSTRING;
 	}
-	s->Phone.Functions=NULL;
+	s->Phone.Functions = NULL;
 #ifdef GSM_ENABLE_ATGEN
 	/* AT module can have the same models ID to "normal" Nokia modules */
 	if (s->ConnectionType==GCT_AT || s->ConnectionType==GCT_BLUEAT || s->ConnectionType==GCT_IRDAAT || s->ConnectionType==GCT_DKU2AT) {
 		GSM_RegisterModule(s,&ATGENPhone);
-		if (s->Phone.Functions!=NULL) return ERR_NONE;
+		if (s->Phone.Functions != NULL) return ERR_NONE;
 	}
 #endif
 	GSM_RegisterModule(s, &DUMMYPhone);
@@ -464,7 +483,7 @@ GSM_Error GSM_OpenConnection(GSM_StateMachine *s)
 {
 	GSM_Error error;
 
-	if (s->CurrentConfig->LockDevice != NULL && strcasecmp(s->CurrentConfig->LockDevice,"yes") == 0) {
+	if (s->CurrentConfig->LockDevice) {
 		error = lock_device(s, s->CurrentConfig->Device, &(s->LockFile));
 		if (error != ERR_NONE) return error;
 	}
@@ -493,16 +512,22 @@ GSM_Error GSM_CloseConnection(GSM_StateMachine *s)
 {
 	GSM_Error error;
 
-	smprintf(s,"[Closing]\n");
+	smprintf(s, "[Closing]\n");
 
-	error=s->Protocol.Functions->Terminate(s);
-	if (error!=ERR_NONE) return error;
+	/* Terminate protocol */
+	error = s->Protocol.Functions->Terminate(s);
+	if (error != ERR_NONE) return error;
 
+	/* Close the device */
 	error = s->Device.Functions->CloseDevice(s);
-	if (error!=ERR_NONE) return error;
+	if (error != ERR_NONE) return error;
 
-	if (s->LockFile!=NULL) unlock_device(s, &(s->LockFile));
+	/* Release lock if there was any */
+	if (s->LockFile != NULL) {
+		unlock_device(s, &(s->LockFile));
+	}
 
+	/* Null all structures in case we will be asked for new initialisation */
 	s->Phone.Data.ModelInfo		  = NULL;
 	s->Phone.Data.Manufacturer[0]	  = 0;
 	s->Phone.Data.Model[0]		  = 0;
@@ -571,18 +596,22 @@ GSM_Error GSM_TryGetModel(GSM_StateMachine *s)
 			default:
 				s->Phone.Functions = NULL;
 		}
-		if (s->Phone.Functions == NULL) return ERR_UNKNOWN;
+		/* Did we find matching phone driver? */
+		if (s->Phone.Functions == NULL) {
+			smprintf(s, "ERROR: Could not find proper module for autodetection!\n");
+			return ERR_UNKNOWN;
+		}
 
-		/* Please note, that AT module need to send first
-		 * command for enabling echo
-		 */
-		error=s->Phone.Functions->Initialise(s);
+		/* Initialize the phone driver */
+		error = s->Phone.Functions->Initialise(s);
 		if (error != ERR_NONE) return error;
 
-		error=s->Phone.Functions->GetModel(s);
+		/* Get model name from phone */
+		error = s->Phone.Functions->GetModel(s);
 		if (error != ERR_NONE) return error;
 
-		error=s->Phone.Functions->Terminate(s);
+		/* And terminate it again */
+		error = s->Phone.Functions->Terminate(s);
 		if (error != ERR_NONE) return error;
 	}
 	return ERR_NONE;
@@ -740,12 +769,12 @@ autodetect:
 			return error;
 		}
 
-		if (strcasecmp(s->CurrentConfig->StartInfo,"yes") == 0) {
+		if (s->CurrentConfig->StartInfo) {
 			s->Phone.Functions->ShowStartInfo(s,TRUE);
 			s->Phone.Data.StartInfoCounter = 30;
 		}
 
-		if (strcasecmp(s->CurrentConfig->SyncTime,"yes") == 0) {
+		if (s->CurrentConfig->SyncTime) {
 			GSM_GetCurrentDateTime (&current_time);
 			s->Phone.Functions->SetDateTime(s,&current_time);
 		}
@@ -786,11 +815,9 @@ GSM_Error GSM_InitConnection(GSM_StateMachine *s, int ReplyNum)
 
 int GSM_ReadDevice (GSM_StateMachine *s, gboolean waitforreply)
 {
-	unsigned char	buff[65536];
-	int		res = 0, count;
-
-	int	i;
 	GSM_DateTime	Date;
+	unsigned char	buff[65536]={'\0'};
+	int		res=0,count=0,i=0;
 
 	if (!GSM_IsConnected(s)) {
 		return ERR_NOTCONNECTED;
@@ -800,15 +827,19 @@ int GSM_ReadDevice (GSM_StateMachine *s, gboolean waitforreply)
 	i=Date.Second;
 	while (i==Date.Second) {
 		res = s->Device.Functions->ReadDevice(s, buff, sizeof(buff));
-		if (!waitforreply) break;
-		if (res > 0) break;
+
+		if (!waitforreply) {
+			break;
+		}
+		if (res > 0) {
+			break;
+		}
 		usleep(5000);
 		GSM_GetCurrentDateTime(&Date);
 	}
-
-	for (count = 0; count < res; count++)
+	for (count = 0; count < res; count++) {
 		s->Protocol.Functions->StateMachine(s,buff[count]);
-
+	}
 	return res;
 }
 
@@ -820,7 +851,7 @@ GSM_Error GSM_TerminateConnection(GSM_StateMachine *s)
 
 	smprintf(s,"[Terminating]\n");
 
-	if (strcasecmp(s->CurrentConfig->StartInfo,"yes") == 0) {
+	if (s->CurrentConfig->StartInfo) {
 		if (s->Phone.Data.StartInfoCounter > 0) s->Phone.Functions->ShowStartInfo(s,FALSE);
 	}
 
@@ -846,11 +877,10 @@ gboolean GSM_IsConnected(GSM_StateMachine *s) {
 GSM_Error GSM_WaitForOnce(GSM_StateMachine *s, unsigned const char *buffer,
 			  int length, unsigned char type, int timeout)
 {
-	GSM_Phone_Data			*Phone = &s->Phone.Data;
-	GSM_Protocol_Message 		sentmsg;
-	int				i;
+	GSM_Phone_Data *Phone = &s->Phone.Data;
+	GSM_Protocol_Message sentmsg;
+	int i = 0;
 
-	i=0;
 	do {
 		if (length != 0) {
 			sentmsg.Length 	= length;
@@ -861,20 +891,22 @@ GSM_Error GSM_WaitForOnce(GSM_StateMachine *s, unsigned const char *buffer,
 		}
 
 		/* Some data received. Reset timer */
-		if (GSM_ReadDevice(s, TRUE) != 0) {
+		if (GSM_ReadDevice(s, TRUE) > 0) {
 			i = 0;
 		} else {
 			usleep(10000);
 		}
 
 		if (length != 0) {
-			free (sentmsg.Buffer);
-			Phone->SentMsg  = NULL;
+			free(sentmsg.Buffer);
+			sentmsg.Buffer = NULL;
+			Phone->SentMsg = NULL;
 		}
 
 		/* Request completed */
-		if (Phone->RequestID==ID_None) return Phone->DispatchError;
-
+		if (Phone->RequestID==ID_None) {
+			return Phone->DispatchError;
+		}
 		i++;
 	} while (i<timeout);
 
@@ -889,7 +921,7 @@ GSM_Error GSM_WaitFor (GSM_StateMachine *s, unsigned const char *buffer,
 	GSM_Error		error;
 	int			reply;
 
-	if (strcasecmp(s->CurrentConfig->StartInfo,"yes") == 0) {
+	if (s->CurrentConfig->StartInfo) {
 		if (Phone->StartInfoCounter > 0) {
 			Phone->StartInfoCounter--;
 			if (Phone->StartInfoCounter == 0) s->Phone.Functions->ShowStartInfo(s,FALSE);
@@ -973,7 +1005,7 @@ GSM_Error GSM_DispatchMessage(GSM_StateMachine *s)
 	GSM_DumpMessageLevel3Recv(s, msg->Buffer, msg->Length, msg->Type);
 
 	Reply=s->User.UserReplyFunctions;
-	if (Reply!=NULL) error=CheckReplyFunctions(s,Reply,&reply);
+	if (Reply != NULL) error=CheckReplyFunctions(s,Reply,&reply);
 
 	if (error==ERR_UNKNOWNFRAME) {
 		Reply=s->Phone.Functions->ReplyFunctions;
@@ -1013,7 +1045,7 @@ GSM_Error GSM_DispatchMessage(GSM_StateMachine *s)
 	}
 
 	if (disp) {
-		smprintf(s,". If you can, please report it (see <http://cihar.com/gammu/report>). Thank you\n");
+		smprintf(s,". If you can, please report it (see <http://wammu.eu/support/bugs/>). Thank you\n");
 		if (Phone->SentMsg != NULL) {
 			smprintf(s,"LAST SENT frame ");
 			smprintf(s, "type 0x%02X/length %ld", Phone->SentMsg->Type, (long)Phone->SentMsg->Length);
@@ -1039,6 +1071,9 @@ GSM_Error GSM_FindGammuRC (INI_Section **result, const char *force_config)
 	char configfile[PATH_MAX + 1];
 	char *envpath;
 	GSM_Error error;
+#if defined(HAVE_GETPWUID) && defined(HAVE_GETUID)
+	struct passwd *pwent;
+#endif
 
 	*result = NULL;
 
@@ -1069,6 +1104,18 @@ GSM_Error GSM_FindGammuRC (INI_Section **result, const char *force_config)
 		if (error == ERR_NONE) return ERR_NONE;
 	}
 
+#if defined(HAVE_GETPWUID) && defined(HAVE_GETUID)
+	pwent = getpwuid(getuid());
+	if (pwent != NULL) {
+		strcat(configfile, pwent->pw_dir);
+		strcat(configfile, GAMMURC_NAME);
+
+		error = GSM_TryReadGammuRC(configfile, result);
+		if (error == ERR_NONE) return ERR_NONE;
+	}
+
+#endif
+
 #if defined(WIN32)
 	/* Reset as we're using strcat */
 	configfile[0] = 0;
@@ -1120,7 +1167,7 @@ void GSM_SetConfigNum(GSM_StateMachine *s, int sections)
  */
 void GSM_ExpandUserPath(char **string)
 {
-	char *tmp, *home;
+	char *tmp = NULL, *home = NULL;
 
 	/* Is there something to expand */
 	if (*string[0] != '~') return;
@@ -1145,9 +1192,9 @@ void GSM_ExpandUserPath(char **string)
 GSM_Error GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 {
 	INI_Section 	*h;
-	unsigned char 	section[50];
-	gboolean		found = FALSE;
-	char *Temp;
+	unsigned char 	section[50]={0};
+	gboolean	found = FALSE;
+	char		*Temp = NULL;
 
 #if defined(WIN32) || defined(DJGPP)
         static const char *DefaultPort		= "com2:";
@@ -1156,11 +1203,11 @@ GSM_Error GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 #endif
         static const char *DefaultModel		= "";
         static const char *DefaultConnection		= "fbus";
-	static const char *DefaultSynchronizeTime	= "no";
+	static gboolean DefaultSynchronizeTime	= FALSE;
 	static const char *DefaultDebugFile		= "";
 	static const char *DefaultDebugLevel		= "";
-	static const char *DefaultLockDevice		= "no";
-	static const char *DefaultStartInfo		= "no";
+	static gboolean DefaultLockDevice		= FALSE;
+	static gboolean DefaultStartInfo		= FALSE;
 
 	/* By default all debug output will go to one filedescriptor */
 	static const gboolean DefaultUseGlobalDebugFile 	= TRUE;
@@ -1169,7 +1216,7 @@ GSM_Error GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 	cfg->UseGlobalDebugFile	 = DefaultUseGlobalDebugFile;
 
 	/* If we don't have valid config, bail out */
-	if (cfg_info==NULL) {
+	if (cfg_info == NULL) {
 		error = ERR_UNCONFIGURED;
 		goto fail;
 	}
@@ -1183,7 +1230,7 @@ GSM_Error GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 
 	/* Scan for section */
         for (h = cfg_info; h != NULL; h = h->Next) {
-                if (strncasecmp(section, h->SectionName, strlen(section)) == 0) {
+                if (strcasecmp(section, h->SectionName) == 0) {
 			found = TRUE;
 			break;
 		}
@@ -1212,18 +1259,12 @@ GSM_Error GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 	}
 
 	/* Set time sync */
-	free(cfg->SyncTime);
-	cfg->SyncTime 	 = INI_GetValue(cfg_info, section, "synchronizetime",	FALSE);
-	if (!cfg->SyncTime) {
-		cfg->SyncTime		 	 = strdup(DefaultSynchronizeTime);
-	} else {
-		cfg->SyncTime			 = strdup(cfg->SyncTime);
-	}
+	cfg->SyncTime = INI_GetBool(cfg_info, section, "synchronizetime", DefaultSynchronizeTime);
 
 	/* Set debug file */
 	free(cfg->DebugFile);
 	cfg->DebugFile   = INI_GetValue(cfg_info, section, "logfile", 		FALSE);
-	if (!cfg->DebugFile) {
+	if (cfg->DebugFile == NULL) {
 		cfg->DebugFile		 	 = strdup(DefaultDebugFile);
 	} else {
 		cfg->DebugFile			 = strdup(cfg->DebugFile);
@@ -1231,97 +1272,95 @@ GSM_Error GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 	}
 
 	/* Set file locking */
-	free(cfg->LockDevice);
-	cfg->LockDevice  = INI_GetValue(cfg_info, section, "use_locking", 	FALSE);
-	if (!cfg->LockDevice) {
-		cfg->LockDevice	 		 = strdup(DefaultLockDevice);
-	} else {
-		cfg->LockDevice			 = strdup(cfg->LockDevice);
-	}
+	cfg->LockDevice  = INI_GetBool(cfg_info, section, "use_locking", DefaultLockDevice);
 
 	/* Set model */
 	Temp		 = INI_GetValue(cfg_info, section, "model", 		FALSE);
-	if (!Temp || strcmp(Temp, "auto") == 0) {
+	if (Temp == NULL || strcmp(Temp, "auto") == 0) {
 		strcpy(cfg->Model,DefaultModel);
 	} else {
 		if (strlen(Temp) >= sizeof(cfg->Model))
-			Temp[sizeof(cfg->Model) - 1] = 0;
+			Temp[sizeof(cfg->Model) - 1] = '\0';
 		strcpy(cfg->Model,Temp);
 	}
 
 	/* Set Log format */
 	Temp		 = INI_GetValue(cfg_info, section, "logformat", 	FALSE);
-	if (!Temp) {
+
+	if (Temp == NULL) {
 		strcpy(cfg->DebugLevel,DefaultDebugLevel);
 	} else {
 		if (strlen(Temp) >= sizeof(cfg->DebugLevel))
-			Temp[sizeof(cfg->DebugLevel) - 1] = 0;
+			Temp[sizeof(cfg->DebugLevel) - 1] = '\0';
 		strcpy(cfg->DebugLevel,Temp);
 	}
 
 	/* Set startup info */
-	free(cfg->StartInfo);
-	cfg->StartInfo   = INI_GetValue(cfg_info, section, "startinfo", 	FALSE);
-	if (!cfg->StartInfo) {
-		cfg->StartInfo	 		 = strdup(DefaultStartInfo);
-	} else {
-		cfg->StartInfo			 = strdup(cfg->StartInfo);
-	}
+	cfg->StartInfo = INI_GetBool(cfg_info, section, "startinfo", DefaultStartInfo);
 
 	/* Read localised strings for some phones */
 
 	Temp		 = INI_GetValue(cfg_info, section, "reminder", 		FALSE);
-	if (!Temp) {
+
+	if (Temp == NULL) {
 		strcpy(cfg->TextReminder,"Reminder");
 	} else {
 		if (strlen(Temp) >= sizeof(cfg->TextReminder))
-			Temp[sizeof(cfg->TextReminder) - 1] = 0;
+			Temp[sizeof(cfg->TextReminder) - 1] = '\0';
 		strcpy(cfg->TextReminder,Temp);
 	}
 
 	Temp		 = INI_GetValue(cfg_info, section, "meeting", 		FALSE);
-	if (!Temp) {
+
+	if (Temp == NULL) {
 		strcpy(cfg->TextMeeting,"Meeting");
 	} else {
 		if (strlen(Temp) >= sizeof(cfg->TextMeeting))
-			Temp[sizeof(cfg->TextMeeting) - 1] = 0;
+			Temp[sizeof(cfg->TextMeeting) - 1] = '\0';
 		strcpy(cfg->TextMeeting,Temp);
 	}
 
 	Temp		 = INI_GetValue(cfg_info, section, "call", 		FALSE);
-	if (!Temp) {
+
+	if (Temp == NULL) {
 		strcpy(cfg->TextCall,"Call");
 	} else {
 		if (strlen(Temp) >= sizeof(cfg->TextCall))
-			Temp[sizeof(cfg->TextCall) - 1] = 0;
+			Temp[sizeof(cfg->TextCall) - 1] = '\0';
 		strcpy(cfg->TextCall,Temp);
 	}
 
 	Temp		 = INI_GetValue(cfg_info, section, "birthday", 		FALSE);
-	if (!Temp) {
+
+	if (Temp == NULL) {
 		strcpy(cfg->TextBirthday,"Birthday");
 	} else {
 		if (strlen(Temp) >= sizeof(cfg->TextBirthday))
-			Temp[sizeof(cfg->TextBirthday) - 1] = 0;
+			Temp[sizeof(cfg->TextBirthday) - 1] = '\0';
 		strcpy(cfg->TextBirthday,Temp);
 	}
 
 	Temp		 = INI_GetValue(cfg_info, section, "memo", 		FALSE);
-	if (!Temp) {
+
+	if (Temp == NULL) {
 		strcpy(cfg->TextMemo,"Memo");
 	} else {
 		if (strlen(Temp) >= sizeof(cfg->TextMemo))
-			Temp[sizeof(cfg->TextMemo) - 1] = 0;
+			Temp[sizeof(cfg->TextMemo) - 1] = '\0';
 		strcpy(cfg->TextMemo,Temp);
 	}
 
 	/* Phone features */
 	Temp		 = INI_GetValue(cfg_info, section, "features", 		FALSE);
-	if (!Temp) {
+
+	if (Temp == NULL) {
 		cfg->PhoneFeatures[0] = 0;
 	} else {
 		error = GSM_SetFeatureString(cfg->PhoneFeatures, Temp);
-		if (error != ERR_NONE) goto fail;
+
+		if (error != ERR_NONE) {
+			goto fail;
+		}
 	}
 	return ERR_NONE;
 
@@ -1330,12 +1369,12 @@ fail:
 	if (num == 0) {
 		cfg->Device		 	 = strdup(DefaultPort);
 		cfg->Connection	 		 = strdup(DefaultConnection);
-		cfg->SyncTime		 	 = strdup(DefaultSynchronizeTime);
+		cfg->SyncTime		 	 = DefaultSynchronizeTime;
 		cfg->DebugFile		 	 = strdup(DefaultDebugFile);
-		cfg->LockDevice	 		 = strdup(DefaultLockDevice);
+		cfg->LockDevice	 		 = DefaultLockDevice;
 		strcpy(cfg->Model,DefaultModel);
 		strcpy(cfg->DebugLevel,DefaultDebugLevel);
-		cfg->StartInfo	 		 = strdup(DefaultStartInfo);
+		cfg->StartInfo	 		 = DefaultStartInfo;
 		strcpy(cfg->TextReminder,"Reminder");
 		strcpy(cfg->TextMeeting,"Meeting");
 		strcpy(cfg->TextCall,"Call");
@@ -1377,7 +1416,7 @@ void GSM_DumpMessageLevel2Recv(GSM_StateMachine *s, unsigned const char *message
 
 void GSM_DumpMessageLevel3_Custom(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type, int direction)
 {
-	int i;
+	int i=0;
 	GSM_Debug_Info *curdi;
 
 	curdi = GSM_GetDI(s);
@@ -1387,7 +1426,10 @@ void GSM_DumpMessageLevel3_Custom(GSM_StateMachine *s, unsigned const char *mess
 		smprintf(s,"%c",type);
 		smprintf(s,"%c",messagesize/256);
 		smprintf(s,"%c",messagesize%256);
-		for (i=0;i<messagesize;i++) smprintf(s,"%c",message[i]);
+
+		for (i=0;i<messagesize;i++) {
+			smprintf(s,"%c",message[i]);
+		}
 	}
 }
 void GSM_DumpMessageLevel3(GSM_StateMachine *s, unsigned const char *message, int messagesize, int type)
@@ -1403,8 +1445,8 @@ void GSM_DumpMessageLevel3Recv(GSM_StateMachine *s, unsigned const char *message
 void GSM_OSErrorInfo(GSM_StateMachine *s, const char *description)
 {
 #ifdef WIN32
-	int 		i;
-	unsigned char 	*lpMsgBuf;
+	int 		i=0;
+	unsigned char 	*lpMsgBuf = NULL;
 #endif
 	GSM_Debug_Info *curdi;
 
@@ -1574,21 +1616,21 @@ GSM_StateMachine *GSM_AllocStateMachine(void)
 
 void GSM_FreeStateMachine(GSM_StateMachine *s)
 {
-	int i;
+	int i=0;
 
 	if (s == NULL) return;
 
 	/* Free allocated memory */
 	for (i = 0; i <= MAX_CONFIG_NUM; i++) {
 		free(s->Config[i].Device);
+		s->Config[i].Device = NULL;
 		free(s->Config[i].Connection);
-		free(s->Config[i].SyncTime);
+		s->Config[i].Connection = NULL;
 		free(s->Config[i].DebugFile);
-		free(s->Config[i].LockDevice);
-		free(s->Config[i].StartInfo);
+		s->Config[i].DebugFile = NULL;
 	}
-
 	free(s);
+	s = NULL;
 }
 
 
