@@ -14,6 +14,15 @@
  * to publish their code under.
  */
 
+#include <gammu-config.h>
+
+#ifdef HAVE_WCHAR_H
+#  include <wchar.h>
+#endif
+#ifdef HAVE_WCTYPE_H
+#  include <wctype.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -665,35 +674,35 @@ void FindDefaultAlphabetLen(const unsigned char *src, size_t *srclen, size_t *sm
 #define ByteMask ((1 << Bits) - 1)
 
 int GSM_UnpackEightBitsToSeven(int offset, int in_length, int out_length,
-                           unsigned char *input, unsigned char *output)
+                           const unsigned char *input, unsigned char *output)
 {
 	/* (c) by Pavel Janik and Pawel Kot */
 
-        unsigned char *OUTPUT 	= output; /* Current pointer to the output buffer */
-        unsigned char *INPUT  	= input;  /* Current pointer to the input buffer */
+        unsigned char *output_pos 	= output; /* Current pointer to the output buffer */
+        const unsigned char *input_pos  	= input;  /* Current pointer to the input buffer */
         unsigned char Rest 	= 0x00;
         int	      Bits;
 
         Bits = offset ? offset : 7;
 
-        while ((INPUT - input) < in_length) {
+        while ((input_pos - input) < in_length) {
 
-                *OUTPUT = ((*INPUT & ByteMask) << (7 - Bits)) | Rest;
-                Rest = *INPUT >> Bits;
+                *output_pos = ((*input_pos & ByteMask) << (7 - Bits)) | Rest;
+                Rest = *input_pos >> Bits;
 
                 /* If we don't start from 0th bit, we shouldn't go to the
-                   next char. Under *OUTPUT we have now 0 and under Rest -
+                   next char. Under *output_pos we have now 0 and under Rest -
                    _first_ part of the char. */
-                if ((INPUT != input) || (Bits == 7)) OUTPUT++;
-                INPUT++;
+                if ((input_pos != input) || (Bits == 7)) output_pos++;
+                input_pos++;
 
-                if ((OUTPUT - output) >= out_length) break;
+                if ((output_pos - output) >= out_length) break;
 
                 /* After reading 7 octets we have read 7 full characters but
                    we have 7 bits as well. This is the next character */
                 if (Bits == 1) {
-                        *OUTPUT = Rest;
-                        OUTPUT++;
+                        *output_pos = Rest;
+                        output_pos++;
                         Bits = 7;
                         Rest = 0x00;
                 } else {
@@ -701,15 +710,15 @@ int GSM_UnpackEightBitsToSeven(int offset, int in_length, int out_length,
                 }
         }
 
-        return OUTPUT - output;
+        return output_pos - output;
 }
 
-int GSM_PackSevenBitsToEight(int offset, unsigned char *input, unsigned char *output, int length)
+int GSM_PackSevenBitsToEight(int offset, const unsigned char *input, unsigned char *output, int length)
 {
 	/* (c) by Pavel Janik and Pawel Kot */
 
-        unsigned char 	*OUTPUT = output; /* Current pointer to the output buffer */
-        unsigned char 	*INPUT  = input;  /* Current pointer to the input buffer */
+        unsigned char 	*output_pos = output; /* Current pointer to the output buffer */
+        const unsigned char 	*input_pos  = input;  /* Current pointer to the input buffer */
         int		Bits;             /* Number of bits directly copied to
                                            * the output buffer */
         Bits = (7 + offset) % 8;
@@ -717,38 +726,34 @@ int GSM_PackSevenBitsToEight(int offset, unsigned char *input, unsigned char *ou
         /* If we don't begin with 0th bit, we will write only a part of the
            first octet */
         if (offset) {
-                *OUTPUT = 0x00;
-                OUTPUT++;
+                *output_pos = 0x00;
+                output_pos++;
         }
 
-        while ((INPUT - input) < length) {
-                unsigned char Byte = *INPUT;
+        while ((input_pos - input) < length) {
+                unsigned char Byte = *input_pos;
 
-                *OUTPUT = Byte >> (7 - Bits);
+                *output_pos = Byte >> (7 - Bits);
                 /* If we don't write at 0th bit of the octet, we should write
                    a second part of the previous octet */
                 if (Bits != 7)
-                        *(OUTPUT-1) |= (Byte & ((1 << (7-Bits)) - 1)) << (Bits+1);
+                        *(output_pos-1) |= (Byte & ((1 << (7-Bits)) - 1)) << (Bits+1);
 
                 Bits--;
 
-                if (Bits == -1) Bits = 7; else OUTPUT++;
+                if (Bits == -1) Bits = 7; else output_pos++;
 
-                INPUT++;
+                input_pos++;
         }
-        return (OUTPUT - output);
+        return (output_pos - output);
 }
 
-int GSM_UnpackSemiOctetNumber(GSM_Debug_Info *di, unsigned char *retval, unsigned char *Number, gboolean semioctet)
+int GSM_UnpackSemiOctetNumber(GSM_Debug_Info *di, unsigned char *retval, const unsigned char *Number, gboolean semioctet)
 {
 	unsigned char	Buffer[GSM_MAX_NUMBER_LENGTH + 1];
 	int		length		= Number[0];
 
 	smfprintf(di, "L=%d\n", length);
-	if (length == 0) {
-		strcpy(Buffer, "");
-		return 0;
-	}
 
 	/* Default ouput on error */
 	strcpy(Buffer, "<NOT DECODED>");
@@ -820,7 +825,7 @@ out:
  *
  * 1 semioctet = 4 bits = half of byte
  */
-int GSM_PackSemiOctetNumber(unsigned char *Number, unsigned char *Output, gboolean semioctet)
+int GSM_PackSemiOctetNumber(const unsigned char *Number, unsigned char *Output, gboolean semioctet)
 {
 	unsigned char	format, buffer[GSM_MAX_NUMBER_LENGTH + 1];
 	int		length, i;
@@ -1335,11 +1340,11 @@ GSM_Error GSM_GetVCSLine(char **OutBuffer, char *Buffer, size_t *Pos, size_t Max
 	gboolean skip = FALSE;
 	gboolean quoted_printable = FALSE;
 	gboolean was_cr = FALSE, was_lf = FALSE;
-	size_t pos;
-	int tmp;
+	size_t pos=0;
+	int tmp=0;
 	size_t OutLen = 200;
 
-	*OutBuffer = malloc(OutLen);
+	*OutBuffer = (char *)malloc(OutLen);
 	if (*OutBuffer == NULL) return ERR_MOREMEMORY;
 	(*OutBuffer)[0] = 0;
 	pos = 0;
@@ -1395,7 +1400,7 @@ GSM_Error GSM_GetVCSLine(char **OutBuffer, char *Buffer, size_t *Pos, size_t Max
 			(*OutBuffer)[pos] = 0;
 			if (pos + 2 >= OutLen) {
 				OutLen += 100;
-				*OutBuffer = realloc(*OutBuffer, OutLen);
+				*OutBuffer = (char *)realloc(*OutBuffer, OutLen);
 				if (*OutBuffer == NULL) return ERR_MOREMEMORY;
 			}
 		}
@@ -1670,12 +1675,14 @@ void DecodeXMLUTF8(unsigned char *dest, const char *src, int len)
 			strncat(tmp, lastpos, pos_end - pos + 1);
 		}
 		free(entity);
+		entity=NULL;
 		lastpos = pos_end + 1;
 	}
 	/* Copy rest of string */
 	strcat(tmp, lastpos);
 	DecodeUTF8(dest, tmp, strlen(tmp));
 	free(tmp);
+	tmp=NULL;
 }
 
 void DecodeUTF7(unsigned char *dest, const unsigned char *src, int len)
