@@ -253,6 +253,10 @@ typedef struct {
 	 * First memory entry to be read
 	 */
 	int			FirstMemoryEntry;
+	/**
+	 * First memory entry to be read for Motorola
+	 */
+	int			MotorolaFirstMemoryEntry;
 	/**
 	 * Charset set in phone
 	 */
@@ -279,12 +283,15 @@ typedef struct {
 	size_t			NumberLength;
 	size_t			TextLength;
 	int			MemorySize;
+	int			MotorolaMemorySize;
 	int			MemoryUsed;
 
 	GSM_SMSMemoryStatus	LastSMSStatus;
 	int			LastSMSRead;
 	int			FirstCalendarPos;
 	int			FirstFreeCalendarPos;
+	GSM_CalendarStatus	CalendarStatus;
+	int			CalendarRead;
 	/**
 	 * Can we write messages to SIM memory?
 	 */
@@ -397,6 +404,14 @@ GSM_Error ATGEN_DispatchMessage	(GSM_StateMachine *s);
         if (error != ERR_NONE) return error; \
         error = GSM_WaitFor(s, cmd, len, type, time, request);
 
+/**
+ * Wrapper around \ref ATGEN_WaitFor which automatically sets
+ * length of request.
+ * It accepts same parameters as \ref GSM_WaitFor except length.
+ */
+#define ATGEN_WaitForAutoLen(s, cmd, type, time, request) \
+	ATGEN_WaitFor(s, cmd, strlen(cmd), type, time, request)
+
 /**
  * Parses AT formatted reply. This is a bit like sprintf parser, but
  * specially focused on AT replies and can automatically convert text
