@@ -25,56 +25,91 @@ static GSM_Error GetSiemensFrame(GSM_Protocol_Message msg, GSM_StateMachine *s,
 	int			i=2, pos=0, length=0;
 	unsigned char 		buf[512];
 
-	if (strstr(GetLineString(msg.Buffer,&Priv->Lines,2),"OK")) return ERR_EMPTY;
-        if (!strstr(GetLineString(msg.Buffer,&Priv->Lines,2),templ)) return ERR_UNKNOWN;
+	if (strstr(GetLineString(msg.Buffer,&Priv->Lines,2), "OK")) {
+		return ERR_EMPTY;
+	}
+	if (!strstr(GetLineString(msg.Buffer,&Priv->Lines,2), templ)) {
+		return ERR_UNKNOWN;
+	}
 
 	while (1) {
 		if (Priv->Lines.numbers[i*2+1]==0) break;
-		if ((!strstr(GetLineString(msg.Buffer,&Priv->Lines,i+1),templ)) &&
-	            (strstr(GetLineString(msg.Buffer,&Priv->Lines,i),templ))){
-			length = strlen(GetLineString(msg.Buffer,&Priv->Lines,i+1));
-			DecodeHexBin(buf, GetLineString(msg.Buffer,&Priv->Lines,i+1),length);
-			length = length/2;
+		if ((!strstr(GetLineString(msg.Buffer, &Priv->Lines, i + 1), templ)) &&
+				(strstr(GetLineString(msg.Buffer, &Priv->Lines, i), templ))){
+			length = strlen(GetLineString(msg.Buffer, &Priv->Lines, i + 1));
+			DecodeHexBin(buf, GetLineString(msg.Buffer, &Priv->Lines, i + 1),length);
+			length = length / 2;
 			memcpy (buffer+pos,buf,length);
 			pos+=length;
 		}
 		i++;
 	}
 	*len = pos;
-       return ERR_NONE;
+	return ERR_NONE;
 }
 
 static GSM_Error SetSiemensFrame (GSM_StateMachine *s, unsigned char *buff, const char *templ,
-			    int Location, GSM_Phone_RequestID RequestID, int len)
+			    int Location, GSM_Phone_RequestID RequestID, size_t len)
 {
 	GSM_Phone_Data		*Phone = &s->Phone.Data;
 	GSM_Error		error;
-	unsigned char 		req[20],req1[512],hexreq[2096];
+	unsigned char 		req[60],req1[512],hexreq[10000];
 	int			MaxFrame,CurrentFrame,size,sz,pos=0;
+	size_t reqlen;
 
-	EncodeHexBin(hexreq,buff,len);
+	if ((len * 2) > (sizeof(hexreq) - 1)) {
+		smprintf(s, "Too long request!\n");
+		return ERR_MOREMEMORY;
+	}
+
+	/* Encode request data */
+	EncodeHexBin(hexreq, buff, len);
+
+	/* Calculate number of frames */
 	size	 = len * 2;
 	MaxFrame = size / 352;
-	if (size % 352) MaxFrame++;
+	if (size % 352) {
+		MaxFrame++;
+	}
 
-	for (CurrentFrame=0;CurrentFrame<MaxFrame;CurrentFrame++) {
-		pos=CurrentFrame*352;
-	 	if (pos+352 < size) sz = 352; else sz = size - pos;
-		sprintf(req, "AT^SBNW=\"%s\",%i,%i,%i\r",templ,Location,CurrentFrame+1,MaxFrame);
+	for (CurrentFrame = 0; CurrentFrame < MaxFrame; CurrentFrame++) {
+		pos = CurrentFrame * 352;
+		if (pos + 352 < size) {
+			sz = 352;
+		} else {
+			sz = size - pos;
+		}
+
+		/* Write AT command */
+		reqlen = sprintf(req, "AT^SBNW=\"%s\",%i,%i,%i\r",templ,Location,CurrentFrame+1,MaxFrame);
 		s->Protocol.Data.AT.EditMode = TRUE;
-		error = GSM_WaitFor (s, req, strlen(req), 0x00, 3, RequestID);
-		s->Phone.Data.DispatchError=ERR_TIMEOUT;
-		s->Phone.Data.RequestID=RequestID;
-	     	if (error!=ERR_NONE) return error;
-	 	memcpy (req1,hexreq+pos,sz);
-	 	error = s->Protocol.Functions->WriteMessage(s, req1, sz, 0x00);
-	 	if (error!=ERR_NONE) return error;
+		error = GSM_WaitFor(s, req, reqlen, 0x00, 3, RequestID);
+		s->Phone.Data.DispatchError = ERR_TIMEOUT;
+		s->Phone.Data.RequestID = RequestID;
+		if (error != ERR_NONE) {
+			return error;
+		}
+
+		/* Write data */
+		memcpy(req1, hexreq + pos, sz);
+		error = s->Protocol.Functions->WriteMessage(s, req1, sz, 0x00);
+		if (error!=ERR_NONE) {
+			return error;
+		}
+
+		/* Write termination mark */
 		error = s->Protocol.Functions->WriteMessage(s,"\x1A", 1, 0x00);
-	 	if (error!=ERR_NONE) return error;
+		if (error != ERR_NONE) {
+			return error;
+		}
+
+		/* Wait for transaction completion */
 		error = GSM_WaitForOnce(s, NULL, 0x00, 0x00, 4);
-	 	if (error == ERR_TIMEOUT) return error;
-	 }
-	 return Phone->DispatchError;
+		if (error == ERR_TIMEOUT) {
+			return error;
+		}
+	}
+	return Phone->DispatchError;
 }
 
 GSM_Error SIEMENS_ReplyGetBitmap(GSM_Protocol_Message msg, GSM_StateMachine *s)
@@ -115,13 +150,14 @@ GSM_Error SIEMENS_ReplySetBitmap(GSM_Protocol_Message msg, GSM_StateMachine *s)
 GSM_Error SIEMENS_GetBitmap(GSM_StateMachine *s, GSM_Bitmap *Bitmap)
 {
 	unsigned char req[32];
+	size_t len;
 
 	if (Bitmap->Type!=GSM_OperatorLogo) return ERR_NOTSUPPORTED;
 	if (Bitmap->Location-1 < 0) Bitmap->Location++;
 	s->Phone.Data.Bitmap=Bitmap;
-	sprintf(req, "AT^SBNR=\"bmp\",%i\r", Bitmap->Location-1);
+	len = sprintf(req, "AT^SBNR=\"bmp\",%i\r", Bitmap->Location-1);
 	smprintf(s, "Getting Bitmap\n");
-	return GSM_WaitFor (s, req, strlen(req), 0x00, 4, ID_GetBitmap);
+	return GSM_WaitFor (s, req, len, 0x00, 4, ID_GetBitmap);
 }
 
 GSM_Error SIEMENS_SetBitmap(GSM_StateMachine *s, GSM_Bitmap *Bitmap)
@@ -161,11 +197,12 @@ GSM_Error SIEMENS_ReplyGetRingtone(GSM_Protocol_Message msg, GSM_StateMachine *s
 GSM_Error SIEMENS_GetRingtone(GSM_StateMachine *s, GSM_Ringtone *Ringtone, gboolean PhoneRingtone UNUSED)
 {
 	unsigned char req[32];
+	size_t len;
 
 	s->Phone.Data.Ringtone=Ringtone;
-	sprintf(req, "AT^SBNR=\"mid\",%i\r", Ringtone->Location-1);
+	len = sprintf(req, "AT^SBNR=\"mid\",%i\r", Ringtone->Location-1);
 	smprintf(s, "Getting RingTone\n");
-	return GSM_WaitFor (s, req, strlen(req), 0x00, 4, ID_GetRingtone);
+	return GSM_WaitFor (s, req, len, 0x00, 4, ID_GetRingtone);
 }
 
 GSM_Error SIEMENS_ReplySetRingtone(GSM_Protocol_Message msg, GSM_StateMachine *s)
@@ -226,6 +263,7 @@ GSM_Error SIEMENS_GetNextCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note,
 	GSM_Error		error;
 	unsigned char 		req[32];
 	int			Location;
+	size_t len;
 
 	if (Priv->Manufacturer!=AT_Siemens) return ERR_NOTSUPPORTED;
 
@@ -236,8 +274,8 @@ GSM_Error SIEMENS_GetNextCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note,
 	Location = Note->Location;
 	while (1){
 		Location++;
-		sprintf(req, "AT^SBNR=\"vcs\",%i\r",Location);
-		error = GSM_WaitFor (s, req, strlen(req), 0x00, 4, ID_GetCalendarNote);
+		len = sprintf(req, "AT^SBNR=\"vcs\",%i\r",Location);
+		error = GSM_WaitFor (s, req, len, 0x00, 4, ID_GetCalendarNote);
 		if ((error!=ERR_NONE) && (error!=ERR_EMPTY)) {
 			error = ERR_INVALIDLOCATION;
 			break;
@@ -257,14 +295,15 @@ GSM_Error SIEMENS_GetCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 {
 	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
 	unsigned char 		req[32];
+	size_t len;
 
 	if (Priv->Manufacturer!=AT_Siemens) return ERR_NOTSUPPORTED;
 
 	s->Phone.Data.Cal = Note;
-	sprintf(req, "AT^SBNR=\"vcs\",%i\r",Note->Location);
+	len = sprintf(req, "AT^SBNR=\"vcs\",%i\r",Note->Location);
 	smprintf(s, "Getting calendar note\n");
 
-	return GSM_WaitFor (s, req, strlen(req), 0x00, 4, ID_GetCalendarNote);
+	return GSM_WaitFor (s, req, len, 0x00, 4, ID_GetCalendarNote);
 }
 
 GSM_Error SIEMENS_ReplyAddCalendarNote(GSM_Protocol_Message msg, GSM_StateMachine *s)
@@ -272,6 +311,11 @@ GSM_Error SIEMENS_ReplyAddCalendarNote(GSM_Protocol_Message msg, GSM_StateMachin
     return SIEMENS_ReplySetFunction (msg, s, "Calendar Note");
 }
 
+GSM_Error SIEMENS_ReplySetMemory(GSM_Protocol_Message msg, GSM_StateMachine *s)
+{
+    return SIEMENS_ReplySetFunction (msg, s, "Memory entry");
+}
+
 GSM_Error SIEMENS_ReplyDelCalendarNote(GSM_Protocol_Message msg UNUSED, GSM_StateMachine *s)
 {
 	GSM_Phone_Data *Data = &s->Phone.Data;
@@ -291,13 +335,14 @@ GSM_Error SIEMENS_DelCalendarNote(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 {
 	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
 	unsigned char 		req[32];
+	size_t len;
 
 	if (s->Phone.Data.Priv.ATGEN.Manufacturer!=AT_Siemens) return ERR_NOTSUPPORTED;
 	s->Phone.Data.Cal = Note;
-	sprintf(req, "AT^SBNW=\"vcs\",%i,0\r",Note->Location);
+	len = sprintf(req, "AT^SBNW=\"vcs\",%i,0\r",Note->Location);
 	smprintf(s, "Deleting calendar note\n");
 	Priv->FirstFreeCalendarPos = 0;
-	return GSM_WaitFor (s, req, strlen(req), 0x00, 4, ID_DeleteCalendarNote);
+	return GSM_WaitFor(s, req, len, 0x00, 4, ID_DeleteCalendarNote);
 }
 
 GSM_Error SIEMENS_SetCalendarNote(GSM_StateMachine *s, GSM_CalendarEntry *Note)
@@ -323,6 +368,7 @@ GSM_Error SIEMENS_AddCalendarNote(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 	unsigned char 		req[500], req1[32];
 	size_t			size=0;
 	int Location;
+	size_t len;
 
 	if (Priv->Manufacturer!=AT_Siemens) return ERR_NOTSUPPORTED;
 
@@ -335,8 +381,8 @@ GSM_Error SIEMENS_AddCalendarNote(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 	Location = Note->Location;
 	while (1){
 		Location++;
-		sprintf(req1, "AT^SBNR=\"vcs\",%i\r",Location);
-		error = GSM_WaitFor (s, req1, strlen(req1), 0x00, 4, ID_GetCalendarNote);
+		len = sprintf(req1, "AT^SBNR=\"vcs\",%i\r",Location);
+		error = GSM_WaitFor (s, req1, len, 0x00, 4, ID_GetCalendarNote);
 		Note->Location			= Location;
 		Priv->FirstFreeCalendarPos	= Location;
 		if (error==ERR_EMPTY) break;
@@ -424,6 +470,30 @@ GSM_Error SIEMENS_ReplyGetMemoryInfo(GSM_Protocol_Message msg, GSM_StateMachine
 	}
 }
 
+GSM_Error SIEMENS_SetMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry)
+{
+	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
+	GSM_Error		error;
+	unsigned char 		req[5000];
+	size_t			size=0;
+
+	if (Priv->Manufacturer != AT_Siemens) {
+		return ERR_NOTSUPPORTED;
+	}
+	if (entry->MemoryType != MEM_ME) {
+		return ERR_NOTSUPPORTED;
+	}
+
+	/*
+	 * Phone does not seem to be able to handle full vCard 2.1,
+	 * it might be necessary to add some another vCard type specially
+	 * tailored for Siemens.
+	 */
+	error = GSM_EncodeVCARD(&(s->di), req, sizeof(req) ,&size, entry, TRUE, SonyEricsson_VCard10);
+	if (error != ERR_NONE) return error;
+
+	return SetSiemensFrame(s, req, "vcf", entry->Location, ID_SetMemory, size);
+}
 
 #endif
 
