@@ -24,4 +24,6 @@ GSM_Error SIEMENS_GetCalendar		(GSM_StateMachine *, GSM_CalendarEntry *);
 GSM_Error SIEMENS_ReplyGetMemory	(GSM_Protocol_Message, GSM_StateMachine *);
 GSM_Error SIEMENS_ReplyGetMemoryInfo(GSM_Protocol_Message msg, GSM_StateMachine *s);
 
+GSM_Error SIEMENS_SetMemory(GSM_StateMachine *s, GSM_MemoryEntry *entry);
+GSM_Error SIEMENS_ReplySetMemory(GSM_Protocol_Message msg, GSM_StateMachine *s);
 #endif
