@@ -65,7 +65,7 @@ static GSM_Error N6510_AllocFileCache(GSM_StateMachine *s, int requested)
 	newsize = requested + 10;
 
 	/* Reallocate memory */
-	Priv->FilesCache = realloc(Priv->FilesCache, newsize * sizeof(GSM_File));
+	Priv->FilesCache = (GSM_File *)realloc(Priv->FilesCache, newsize * sizeof(GSM_File));
 	if (Priv->FilesCache == NULL) return ERR_MOREMEMORY;
 
 	/* Store new cache size */
@@ -479,7 +479,7 @@ static GSM_Error N6510_SearchForFileName1(GSM_StateMachine *s, GSM_File *File)
 	File->Folder = FALSE;
 
 	/* making backup */
-	BackupCache = malloc(sizeof(GSM_File) * Priv->FilesLocationsUsed);
+	BackupCache = (GSM_File *)malloc(sizeof(GSM_File) * Priv->FilesLocationsUsed);
 	if (BackupCache == NULL) return ERR_MOREMEMORY;
 	memcpy(BackupCache, Priv->FilesCache, sizeof(GSM_File) * Priv->FilesLocationsUsed);
 	FilesLocationsUsed = Priv->FilesLocationsUsed;
@@ -493,9 +493,10 @@ static GSM_Error N6510_SearchForFileName1(GSM_StateMachine *s, GSM_File *File)
 	error = N6510_GetFileFolderInfo1(s, &Priv->FilesCache[0], TRUE);
 
 	/* backuping new data */
-	NewFiles = malloc(sizeof(GSM_File) * Priv->FilesLocationsUsed);
+	NewFiles = (GSM_File *)malloc(sizeof(GSM_File) * Priv->FilesLocationsUsed);
 	if (NewFiles == NULL) {
 		free(BackupCache);
+		BackupCache=NULL;
 		return ERR_MOREMEMORY;
 	}
 	memcpy(NewFiles, Priv->FilesCache, sizeof(GSM_File) * Priv->FilesLocationsUsed);
@@ -504,10 +505,12 @@ static GSM_Error N6510_SearchForFileName1(GSM_StateMachine *s, GSM_File *File)
 	/* restoring */
 	memcpy(Priv->FilesCache, BackupCache, sizeof(GSM_File) * FilesLocationsUsed);
 	free(BackupCache);
+	BackupCache=NULL;
 	Priv->FilesLocationsUsed = FilesLocationsUsed;
 
 	if (error != ERR_NONE) {
 		free(NewFiles);
+		NewFiles=NULL;
 		return error;
 	}
 
@@ -517,6 +520,7 @@ static GSM_Error N6510_SearchForFileName1(GSM_StateMachine *s, GSM_File *File)
 		if (error == ERR_EMPTY) continue;
 		if (error != ERR_NONE) {
 			free(NewFiles);
+			NewFiles=NULL;
 			return error;
 		}
 		smprintf(s, "%s",DecodeUnicodeString(File->Name));
@@ -525,10 +529,12 @@ static GSM_Error N6510_SearchForFileName1(GSM_StateMachine *s, GSM_File *File)
 			smprintf(s, "the same\n");
 			File->Folder = NewFiles[i].Folder;
 			free(NewFiles);
+			NewFiles=NULL;
 			return ERR_NONE;
 		}
 	}
 	free(NewFiles);
+	NewFiles=NULL;
 	return ERR_EMPTY;
 }
 
@@ -2350,14 +2356,18 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 
 	while (pos < FFF->Used) {
 		unknown = FALSE;
-		if (pos + 2 >= FFF->Used) {
-			smprintf(s, "ERROR: Reach end of file before end of block!\n");
+		if (pos + 1 >= FFF->Used) {
+			smprintf(s, "ERROR: Reach end of file before type of block!\n");
 			return ERR_BUG;
 		}
 		if (FFF->Buffer[pos] == 0x00) {
 			smprintf(s, "WARNING: 0x00 block, assuming rest is just junk!\n");
 			break;
 		}
+		if (pos + 2 >= FFF->Used) {
+			smprintf(s, "ERROR: Reach end of file before size of block!\n");
+			return ERR_BUG;
+		}
 		switch (FFF->Buffer[pos]) {
 			case 0x02: /* SMSC number, ASCII */
 				if (FFF->Buffer[pos + 2] <= 1) break;
@@ -2404,13 +2414,17 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 			case 0x0c:
 				/* This seems to be message ID (per number) */
 				break;
+			case 0x24:
+				/* 24$|00 |01 |01 */
+				if (FFF->Buffer[pos + 2] != 1 || FFF->Buffer[pos + 3] != 1) {
+					unknown = TRUE;
+				}
+				break;
 			case 0x07:
 			case 0x0b:
 			case 0x0e:
 			case 0x22:
 				/* 22"|00 |01 |84 */
-			case 0x24:
-				/* 24$|00 |01 |01 */
 			case 0x26:
 			case 0x27:
 			case 0x2a:
@@ -2447,7 +2461,7 @@ GSM_Error N6510_DecodeFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sm
 				break;
 		}
 		if (unknown) {
-			smprintf(s, "WARNING: Unknown block 0x%02x, see <http://cihar.com/gammu/report> how to report\n", FFF->Buffer[pos]);
+			smprintf(s, "WARNING: Unknown block 0x%02x, see <http://wammu.eu/support/bugs/> how to report\n", FFF->Buffer[pos]);
 			DumpMessage(&(s->di), FFF->Buffer + pos, 3 + (FFF->Buffer[pos + 1] << 8) + FFF->Buffer[pos + 2]);
 #ifdef DEBUG
 		} else {
@@ -2502,11 +2516,13 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 		while (Priv->SMSFileError == ERR_EMPTY) {
 			Priv->SMSFileFolder++;
 			/* Too high folder number */
-			if ((Priv->SMSFileFolder-1)>=Priv->LastSMSFolders.Number) return ERR_EMPTY;
+			if ((Priv->SMSFileFolder-1) >= Priv->LastSMSFolders.Number) {
+				return ERR_EMPTY;
+			}
 
-			EncodeUnicode(Priv->SMSFile.ID_FullName,"d:/predefmessages/",18);
-			CopyUnicodeString(Priv->SMSFile.ID_FullName+36,Priv->LastSMSFolders.Folder[Priv->SMSFileFolder-1].Name);
-			smprintf(s,"folder name is %s\n",DecodeUnicodeString(Priv->SMSFile.ID_FullName));
+			EncodeUnicode(Priv->SMSFile.ID_FullName, "d:/predefmessages/", 18);
+			CopyUnicodeString(Priv->SMSFile.ID_FullName + 36, Priv->LastSMSFolders.Folder[Priv->SMSFileFolder-1].Name);
+			smprintf(s,"folder name is %s\n", DecodeUnicodeString(Priv->SMSFile.ID_FullName));
 
 			Priv->SMSFileError = N6510_GetFolderListing(s,&Priv->SMSFile,TRUE);
 		}
