@@ -14,28 +14,34 @@
 static GSM_Error AT_WriteMessage (GSM_StateMachine *s, unsigned const char *buffer,
 				     int length, unsigned char type)
 {
-	int i,sent = 0;
+	int sent=0, write_data=0, i=0;
 
 	GSM_DumpMessageLevel2(s, buffer, length, type);
 	GSM_DumpMessageLevel3(s, buffer, length, type);
+
 	if (s->Protocol.Data.AT.FastWrite) {
 		while (sent != length) {
-			if ((i = s->Device.Functions->WriteDevice(s,buffer + sent, length - sent)) == 0) {
+			write_data = s->Device.Functions->WriteDevice(s,buffer + sent, length - sent);
+
+			if (write_data == 0 || write_data < 0) {
 				return ERR_DEVICEWRITEERROR;
 			}
-			sent += i;
+			sent += write_data;
 		}
 	} else {
-		for (i=0;i<length;i++) {
-			if (s->Device.Functions->WriteDevice(s,buffer+i,1)!=1) return ERR_DEVICEWRITEERROR;
+		for (i = 0; i < length; i++) {
 			/* For some phones like Siemens M20 we need to wait a little
 			 * after writing each char. Possible reason: these phones
 			 * can't receive so fast chars or there is bug here in Gammu */
+			write_data = s->Device.Functions->WriteDevice(s, buffer + i, 1);
+
+			if (write_data != 1) {
+				return ERR_DEVICEWRITEERROR;
+			}
 			usleep(1000);
 		}
 		usleep(400000);
 	}
-
 	return ERR_NONE;
 }
 
@@ -52,10 +58,23 @@ static GSM_Error AT_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 
 	/* These are lines with end of "normal" answers */
 	static const char 		*StartStrings[] = {
-		"OK"		, 	"ERROR"	 	,
-		"+CME ERROR:"	,	"+CMS ERROR:"	,
+		/* Standard AT */
+		"OK\r",
+		"ERROR\r",
 
-		"COMMAND NOT SUPPORT" /* HUAWEI */	,
+		/* AT with bad end of lines */
+		"OK\n",
+		"ERROR\n",
+
+		/* Standard GSM */
+		"+CME ERROR:",
+		"+CMS ERROR:",
+
+		/* Motorola A1200 */
+		"MODEM ERROR:",
+
+		/* Huawei */
+		"COMMAND NOT SUPPORT",
 
 		NULL};
 
@@ -63,22 +82,38 @@ static GSM_Error AT_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 	 * It starts with strings written here
 	 */
 	static const SpecialAnswersStruct SpecialAnswers[] = {
-		{"_OSIGQ:"	,1},	{"_OBS:"	,1},
-		{"^SCN:"	,1},	{"+CGREG:"	,1},
-		{"+CBM:"	,1},	{"+CMT:"	,2},
-		{"+CMTI:"	,1},	{"+CDS:"	,2},
-		{"+CREG:"	,1},	{"+CUSD"	,1},
-
-		{"RING"		,1},	{"NO CARRIER"	,1},
-		{"NO ANSWER"	,1},	{"+COLP"	,1},
-		{"+CLIP"	,1},	{"+CRING"	,1},
+		/* Standard GSM */
+		{"+CGREG:"	,1},
+		{"+CBM:"	,1},
+		{"+CMT:"	,2},
+		{"+CMTI:"	,1},
+		{"+CDS:"	,2},
+		{"+CREG:"	,1},
+		{"+CUSD"	,1},
+		{"+COLP"	,1},
+		{"+CLIP"	,1},
+		{"+CRING"	,1},
 		{"+CCWA"	,1},
 
+		/* Standard AT */
+		{"RING"		,1},
+		{"NO CARRIER"	,1},
+		{"NO ANSWER"	,1},
+
+		/* GlobeTrotter */
+		{"_OSIGQ:"	,1},
+		{"_OBS:"	,1},
+
+		{"^SCN:"	,1},
+
+		/* Sony-Ericsson */
 		{"*EBCA"	,1},
 
-		{"SDNDCRC ="	,1},	/* Samsung binary transfer end */
+		/* Samsung binary transfer end */
+		{"SDNDCRC ="	,1},
 
-		{"+MBAN:"	,1},	/* Motorola banner */
+		/* Motorola banner */
+		{"+MBAN:"	,1},
 
 		/* Huawei */
 		{"^RSSI:"	,1}, /* ^RSSI:18 */
@@ -86,6 +121,9 @@ static GSM_Error AT_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 		{"^BOOT:"	,1}, /* ^BOOT:27710117,0,0,0,75 */
 		{"^MODE:"	,1}, /* ^MODE:3,3 */
 
+		/* ONDA */
+		{"+ZUSIMR:"	,1}, /* +ZUSIMR:2 */
+
 		{NULL		,1}};
 
     	/* Ignore leading CR, LF and ESC */
@@ -106,7 +144,9 @@ static GSM_Error AT_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 		break;
 	case 10:
 	case 13:
-		if (!d->wascrlf) d->LineEnd = d->Msg.Length-1;
+		if (!d->wascrlf) {
+			d->LineEnd = d->Msg.Length - 1;
+		}
 		d->wascrlf = TRUE;
 		if (d->Msg.Length > 0 && rx_char == 10 && d->Msg.Buffer[d->Msg.Length-2]==13) {
 			i = 0;
@@ -131,7 +171,8 @@ static GSM_Error AT_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 					d->Msg.Length			= 0;
 				}
 			}
-			if (d->Msg.Length == 0) break;
+			if (d->Msg.Length == 0)
+				break;
 
 			i = 0;
 			while (SpecialAnswers[i].text != NULL) {
@@ -158,19 +199,22 @@ static GSM_Error AT_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 
 			if (d->SpecialAnswerLines == 1) {
 				/* This is end of special answer. We copy it and send to phone module */
-				Msg2.Buffer = malloc(d->LineEnd - d->SpecialAnswerStart + 3);
+				Msg2.Buffer = (unsigned char *)malloc(d->LineEnd - d->SpecialAnswerStart + 3);
 				memcpy(Msg2.Buffer,d->Msg.Buffer+d->SpecialAnswerStart,d->LineEnd - d->SpecialAnswerStart + 2);
 				Msg2.Length = d->LineEnd - d->SpecialAnswerStart + 2;
-				Msg2.Buffer[Msg2.Length] = 0;
+				Msg2.Buffer[Msg2.Length] = '\0';
 				Msg2.Type = 0;
 
 				s->Phone.Data.RequestMsg	= &Msg2;
 				s->Phone.Data.DispatchError	= s->Phone.Functions->DispatchMessage(s);
 				free(Msg2.Buffer);
+				Msg2.Buffer=NULL;
 
 				/* We cut special answer from main buffer */
 				d->Msg.Length			= d->SpecialAnswerStart;
-				if (d->Msg.Length != 0) d->Msg.Length = d->Msg.Length - 2;
+				if (d->Msg.Length != 0) {
+					d->Msg.Length = d->Msg.Length - 2;
+				}
 
 				/* We need to find earlier values of all variables */
 				d->wascrlf 			= FALSE;
@@ -181,12 +225,14 @@ static GSM_Error AT_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 						break;
 					case 10:
 					case 13:
-						if (!d->wascrlf) d->LineEnd = d->Msg.Length-1;
+						if (!d->wascrlf) {
+							d->LineEnd = d->Msg.Length - 1;
+						}
 						d->wascrlf = TRUE;
 						break;
 					default:
 						if (d->wascrlf) {
-							d->LineStart	= d->Msg.Length-1;
+							d->LineStart	= d->Msg.Length - 1;
 							d->wascrlf 	= FALSE;
 						}
 					}
@@ -214,7 +260,8 @@ static GSM_Error AT_StateMachine(GSM_StateMachine *s, unsigned char rx_char)
 			d->wascrlf 	= FALSE;
 		}
 		if (d->EditMode) {
-			if (strlen(d->Msg.Buffer+d->LineStart) == 2 && strncmp(d->Msg.Buffer+d->LineStart,"> ",2)==0) {
+			if (strlen(d->Msg.Buffer+d->LineStart) == 2 &&
+					strncmp(d->Msg. Buffer + d->LineStart, "> ", 2) == 0) {
 				s->Phone.Data.RequestMsg	= &d->Msg;
 				s->Phone.Data.DispatchError	= s->Phone.Functions->DispatchMessage(s);
 			}
@@ -244,15 +291,16 @@ static GSM_Error AT_Initialise(GSM_StateMachine *s)
 	error = s->Device.Functions->DeviceSetParity(s, FALSE);
 	if (error != ERR_NONE) return error;
 
-	error = s->Device.Functions->DeviceSetDtrRts(s,TRUE,TRUE);
+	error = s->Device.Functions->DeviceSetDtrRts(s, TRUE, TRUE);
 	if (error != ERR_NONE) return error;
 
-	return s->Device.Functions->DeviceSetSpeed(s,s->Speed);
+	return s->Device.Functions->DeviceSetSpeed(s, s->Speed);
 }
 
 static GSM_Error AT_Terminate(GSM_StateMachine *s)
 {
 	free(s->Protocol.Data.AT.Msg.Buffer);
+	s->Protocol.Data.AT.Msg.Buffer = NULL;
 	return ERR_NONE;
 }
 
