@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright © 2003 - 2009 Michal Čihař
+ * Copyright © 2003 - 2010 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -23,15 +23,12 @@
 #include "convertors.h"
 #include "misc.h"
 
-gboolean GetBoolFromDict(PyObject *dict, const char *key) {
-    PyObject        *o;
-    char            *s;
-    int             i;
+gboolean BoolFromPython(PyObject *o, const char *key) {
+    char *s;
+    int i;
 
-    o = PyDict_GetItemString(dict, key);
-    if (o == NULL) {
-        PyErr_Format(PyExc_ValueError, "Missing key in dictionary: %s", key);
-        return BOOL_INVALID;
+    if (o == Py_None) {
+        return FALSE;
     }
 
     if (!PyBool_Check(o)) {
@@ -46,23 +43,43 @@ gboolean GetBoolFromDict(PyObject *dict, const char *key) {
                 i = atoi(s);
                 if (i == 0) return FALSE;
                 else return TRUE;
+            } else if (strcasecmp(s, "yes") == 0) {
+                return TRUE;
+            } else if (strcasecmp(s, "true") == 0) {
+                return TRUE;
+            } else if (strcasecmp(s, "no") == 0) {
+                return FALSE;
+            } else if (strcasecmp(s, "false") == 0) {
+                return FALSE;
             } else {
-                PyErr_Format(PyExc_ValueError, "Value of '%s' doesn't seem to be gboolean", key);
+                PyErr_Format(PyExc_ValueError, "String value of '%s' doesn't seem to be boolean", key);
                 return BOOL_INVALID;
             }
         }
 
-        PyErr_Format(PyExc_ValueError, "Value of '%s' doesn't seem to be gboolean", key);
+        PyErr_Format(PyExc_ValueError, "Value of '%s' doesn't seem to be boolean", key);
         return BOOL_INVALID;
     }
 
     if (Py_False == o) return FALSE;
     else if (Py_True == o) return TRUE;
 
-    PyErr_Format(PyExc_ValueError, "Value of '%s' doesn't seem to be gboolean", key);
+    PyErr_Format(PyExc_ValueError, "Bool value of '%s' doesn't seem to be boolean", key);
     return BOOL_INVALID;
 }
 
+gboolean GetBoolFromDict(PyObject *dict, const char *key) {
+    PyObject        *o;
+
+    o = PyDict_GetItemString(dict, key);
+    if (o == NULL) {
+        PyErr_Format(PyExc_ValueError, "Missing key in dictionary: %s", key);
+        return BOOL_INVALID;
+    }
+
+    return BoolFromPython(o, key);
+}
+
 int GetIntFromDict(PyObject *dict, const char *key) {
     PyObject        *o;
     char            *s;
@@ -90,6 +107,7 @@ int GetIntFromDict(PyObject *dict, const char *key) {
             return i;
         } else {
             PyErr_Format(PyExc_ValueError, "Value of '%s' doesn't seem to be integer", key);
+            return INT_INVALID;
         }
     }
 
@@ -169,6 +187,11 @@ GSM_DateTime GetDateTimeFromDict(PyObject *dict, const char *key) {
 
     if (!BuildGSMDateTime(o, &dt)) {
         dt.Year = -1;
+    } else {
+        /* We use this as an error value */
+        if (dt.Year == -1) {
+            dt.Year = 0;
+        }
     }
     return dt;
 }
