@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright © 2003 - 2009 Michal Čihař
+ * Copyright © 2003 - 2010 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -72,6 +72,12 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
             case PBK_Number_Mobile:
                 convert_number("Mobile");
                 break;
+            case PBK_Number_Mobile_Work:
+                convert_number("Mobile_Work");
+                break;
+            case PBK_Number_Mobile_Home:
+                convert_number("Mobile_Home");
+                break;
             case PBK_Number_Work:
                 convert_number("Work");
                 break;
@@ -306,13 +312,21 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
 
     memset(entry, 0, sizeof(entry));
 
-    if (needs_location) {
-        entry->Location = GetIntFromDict(dict, "Location");
-        if (entry->Location == INT_INVALID) return 0;
+    entry->Location = GetIntFromDict(dict, "Location");
+    if (entry->Location == INT_INVALID) {
+        if (needs_location) {
+            return 0;
+        }
+        PyErr_Clear();
     }
 
     entry->MemoryType = GetMemoryTypeFromDict(dict, "MemoryType");
-    if (entry->MemoryType == ENUM_INVALID) return 0;
+    if (entry->MemoryType == ENUM_INVALID) {
+        if (needs_location) {
+            return 0;
+        }
+        PyErr_Clear();
+    }
 
     o = PyDict_GetItemString(dict, "Entries");
     if (o == NULL) {
@@ -365,6 +379,12 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         if (strcmp("Number_General", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Number_General;
+        } else if (strcmp("Number_Mobile_Work", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Number_Mobile_Work;
+        } else if (strcmp("Number_Mobile_Home", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Number_Mobile_Home;
         } else if (strcmp("Number_Mobile", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Number_Mobile;
@@ -411,7 +431,7 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
             valuetype = 'd';
             entry->Entries[i].EntryType = PBK_LastModified;
         } else if (strcmp("Caller_Group", type) == 0) {
-            valuetype = 't';
+            valuetype = 'n';
             entry->Entries[i].EntryType = PBK_Caller_Group;
         } else if (strcmp("Text_Name", type) == 0) {
             valuetype = 't';
