@@ -47,6 +47,6 @@ typedef int Py_ssize_t;
 /**
  * Initialisation of SMSD object.
  */
-bool gammu_smsd_init(PyObject *m);
+gboolean gammu_smsd_init(PyObject *m);
 
 #endif
