@@ -7,7 +7,7 @@ python-gammu - Phone communication libary
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -40,7 +40,7 @@ import datetime
 import string
 
 # some defines
-VERSION = '1.26.1'
+VERSION = '1.27.92'
 VERSION_TUPLE = tuple(map(int, VERSION.split('.')))
 GAMMU_REQUIRED = VERSION_TUPLE
 PYTHON_REQUIRED = (2,3)
@@ -290,14 +290,14 @@ setup (name = 'python-gammu',
     description = 'Gammu bindings',
     long_description = 'Bindings to libGammu, which allows access many phones.',
     author = "Michal Cihar",
-    author_email = 'gammu@cihar.com',
+    author_email = 'michal@cihar.com',
     maintainer = "Michal Cihar",
     maintainer_email = "michal@cihar.com",
     platforms = ['Linux','Mac OSX','Windows XP/2000/NT','Windows 95/98/ME'],
     keywords = ['mobile', 'phone', 'SMS', 'contact', 'gammu', 'calendar', 'todo'],
     license = 'GPL',
-    url = 'http://cihar.com/gammu/python',
-    download_url = 'http://cihar.com/gammu/python',
+    url = 'http://wammu.eu/python-gammu/',
+    download_url = 'http://wammu.eu/download/gammu/',
     classifiers = [
         'Development Status :: 5 - Production/Stable',
         'License :: OSI Approved :: GNU General Public License (GPL)',
