@@ -85,6 +85,7 @@ NORETURN void version(void)
 	printf("  - %s\n", "SYSLOG");
 #endif
 	printf("Backend services:\n");
+	printf("  - %s\n", "NULL");
 	printf("  - %s\n", "FILES");
 #ifdef HAVE_MYSQL_MYSQL_H
 	printf("  - %s\n", "MYSQL");
@@ -96,13 +97,13 @@ NORETURN void version(void)
 	printf("  - %s\n", "DBI");
 #endif
 	printf("\n");
-	printf("Copyright (C) 2003 - 2009 Michal Cihar <michal@cihar.com> and other authors.\n");
+	printf("Copyright (C) 2003 - 2010 Michal Cihar <michal@cihar.com> and other authors.\n");
 	printf("\n");
 	printf("License GPLv2: GNU GPL version 2 <http://creativecommons.org/licenses/GPL/2.0/>.\n");
 	printf("This is free software: you are free to change and redistribute it.\n");
 	printf("There is NO WARRANTY, to the extent permitted by law.\n");
 	printf("\n");
-	printf("Check <http://cihar.com/gammu/> for updates.\n");
+	printf("Check <http://wammu.eu/gammu/> for updates.\n");
 	printf("\n");
 	exit(0);
 }
@@ -178,6 +179,7 @@ void process_commandline(int argc, char **argv, SMSD_Parameters * params)
 		{"group", 1, 0, 'G'},
 		{"service-name", 1, 0, 'n'},
 		{"suicide", 1, 0, 'X'},
+		{"max-failures", 1, 0, 'f'},
 		{0, 0, 0, 0}
 	};
 	int option_index;
@@ -222,6 +224,9 @@ void process_commandline(int argc, char **argv, SMSD_Parameters * params)
 				}
 				break;
 #endif
+			case 'f':
+				params->max_failures = atoi(optarg);
+				break;
 #ifdef HAVE_ALARM
 			case 'X':
 				alarm(atoi(optarg));
@@ -347,9 +352,16 @@ int main(int argc, char **argv)
 		FALSE,
 		FALSE,
 		FALSE,
-		FALSE
+		FALSE,
+		0
 	};
 
+	/*
+	 * We don't need gettext, but need to set locales so that
+	 * charset conversion works.
+	 */
+	GSM_InitLocales(NULL);
+
 	process_commandline(argc, argv, &params);
 
 #ifdef HAVE_WINDOWS_SERVICE
@@ -430,7 +442,7 @@ read_config:
 		configure_daemon(&params);
 
 	reconfigure = FALSE;
-	error = SMSD_MainLoop(config, FALSE);
+	error = SMSD_MainLoop(config, FALSE, params.max_failures);
 	if (error != ERR_NONE) {
 		printf("Failed to run SMSD: %s\n", GSM_ErrorString(error));
 		SMSD_FreeConfig(config);
