@@ -23,17 +23,38 @@
 /* Disconnects from a database */
 static GSM_Error SMSDMySQL_Free(GSM_SMSDConfig *Config)
 {
-	SMSD_Log(1, Config, "Disconnecting from MySQL");
+	SMSD_Log(DEBUG_NOTICE, Config, "Disconnecting from MySQL");
 	mysql_close(&Config->DBConnMySQL);
 	return ERR_NONE;
 }
 
+static void SMSDMySQL_LogError(GSM_SMSDConfig *Config)
+{
+	SMSD_Log(DEBUG_ERROR, Config, "Error code: %d, Error: %s", mysql_errno(&Config->DBConnMySQL), mysql_error(&Config->DBConnMySQL));
+}
+
+
+struct _TableCheck
+{
+	const char *query;
+	const char *msg;
+} TableCheck;
+
+static struct _TableCheck	tc[] =
+{
+	{ "SELECT ID FROM `outbox` WHERE 1", "No table for outbox sms" },
+	{ "SELECT ID FROM `outbox_multipart` WHERE 1", "No table for outbox multipart sms" },
+	{ "SELECT ID FROM `sentitems` WHERE 1", "No table for sent sms" },
+	{ "SELECT ID FROM `inbox` WHERE 1", "No table for inbox sms" },
+	{ NULL, NULL },
+};
+
 /* Connects to database */
 static GSM_Error SMSDMySQL_Init(GSM_SMSDConfig *Config)
 {
-	unsigned char		buf[400];
 	MYSQL_RES 		*Res;
 	MYSQL_ROW 		Row;
+	struct _TableCheck *T;
 
 	unsigned int port = 0;
 	char * pport;
@@ -60,71 +81,43 @@ static GSM_Error SMSDMySQL_Init(GSM_SMSDConfig *Config)
 				port,
 				socketname,
 				0)) {
-	    	SMSD_Log(-1, Config, "Error connecting to database: %s", mysql_error(&Config->DBConnMySQL));
+	    	SMSD_Log(DEBUG_ERROR, Config, "Error connecting to database!");
+		SMSDMySQL_LogError(Config);
 	    	return ERR_UNKNOWN;
 	}
-	sprintf(buf, "SELECT ID FROM `outbox` WHERE 1");
-	if (mysql_real_query(&Config->DBConnMySQL,buf,strlen(buf))) {
-		SMSD_Log(-1, Config, "No table for outbox sms: %s", mysql_error(&Config->DBConnMySQL));
+
+	for (T = tc; T->query; T++) {
+		if (mysql_query(&Config->DBConnMySQL, T->query)) {
+			SMSD_Log(DEBUG_ERROR, Config, "%s", T->msg);
+			SMSDMySQL_LogError(Config);
+			mysql_close(&Config->DBConnMySQL);
+			return ERR_UNKNOWN;
+		}
+		if (!(Res = mysql_store_result(&Config->DBConnMySQL))) {
+			SMSD_Log(DEBUG_ERROR, Config, "%s", T->msg);
+			SMSDMySQL_LogError(Config);
+			mysql_close(&Config->DBConnMySQL);
+			return ERR_UNKNOWN;
+		}
+		mysql_free_result(Res);
+	}
+
+	if (mysql_query(&Config->DBConnMySQL, "SELECT Version FROM `gammu` WHERE 1")) {
+		SMSD_Log(DEBUG_ERROR, Config, "No Gammu table");
+		SMSDMySQL_LogError(Config);
 		mysql_close(&Config->DBConnMySQL);
 		return ERR_UNKNOWN;
 	}
 	if (!(Res = mysql_store_result(&Config->DBConnMySQL))) {
-		SMSD_Log(-1, Config, "No table for outbox sms: %s", mysql_error(&Config->DBConnMySQL));
-		mysql_close(&Config->DBConnMySQL);
-		return ERR_UNKNOWN;
-	}
-	mysql_free_result(Res);
-	sprintf(buf, "SELECT ID FROM `outbox_multipart` WHERE 1");
-	if (mysql_real_query(&Config->DBConnMySQL,buf,strlen(buf))) {
-		SMSD_Log(-1, Config, "No table for outbox sms: %s", mysql_error(&Config->DBConnMySQL));
-		mysql_close(&Config->DBConnMySQL);
-		return ERR_UNKNOWN;
-	}
-	if (!(Res = mysql_store_result(&Config->DBConnMySQL))) {
-		SMSD_Log(-1, Config, "No table for outbox sms: %s", mysql_error(&Config->DBConnMySQL));
-		mysql_close(&Config->DBConnMySQL);
-		return ERR_UNKNOWN;
-	}
-	mysql_free_result(Res);
-	sprintf(buf, "SELECT ID FROM `sentitems` WHERE 1");
-	if (mysql_real_query(&Config->DBConnMySQL,buf,strlen(buf))) {
-		SMSD_Log(-1, Config, "No table for sent sms: %s", mysql_error(&Config->DBConnMySQL));
-		mysql_close(&Config->DBConnMySQL);
-		return ERR_UNKNOWN;
-	}
-	if (!(Res = mysql_store_result(&Config->DBConnMySQL))) {
-		SMSD_Log(-1, Config, "No table for sent sms: %s", mysql_error(&Config->DBConnMySQL));
-		mysql_close(&Config->DBConnMySQL);
-		return ERR_UNKNOWN;
-	}
-	mysql_free_result(Res);
-	sprintf(buf, "SELECT ID FROM `inbox` WHERE 1");
-	if (mysql_real_query(&Config->DBConnMySQL,buf,strlen(buf))) {
-		SMSD_Log(-1, Config, "No table for inbox sms: %s", mysql_error(&Config->DBConnMySQL));
-		mysql_close(&Config->DBConnMySQL);
-		return ERR_UNKNOWN;
-	}
-	if (!(Res = mysql_store_result(&Config->DBConnMySQL))) {
-		SMSD_Log(-1, Config, "No table for inbox sms: %s", mysql_error(&Config->DBConnMySQL));
-		mysql_close(&Config->DBConnMySQL);
-		return ERR_UNKNOWN;
-	}
-	mysql_free_result(Res);
-	sprintf(buf, "SELECT Version FROM `gammu` WHERE 1");
-	if (mysql_real_query(&Config->DBConnMySQL,buf,strlen(buf))) {
-		SMSD_Log(-1, Config, "No Gammu table: %s", mysql_error(&Config->DBConnMySQL));
-		mysql_close(&Config->DBConnMySQL);
-		return ERR_UNKNOWN;
-	}
-	if (!(Res = mysql_store_result(&Config->DBConnMySQL))) {
-		SMSD_Log(-1, Config, "No Gammu table: %s", mysql_error(&Config->DBConnMySQL));
+		SMSD_Log(DEBUG_ERROR, Config, "No Gammu table");
+		SMSDMySQL_LogError(Config);
 		mysql_close(&Config->DBConnMySQL);
 		return ERR_UNKNOWN;
 	}
 	if (!(Row = mysql_fetch_row(Res))) {
 		mysql_free_result(Res);
-		SMSD_Log(-1, Config, "No version info in Gammu table: %s", mysql_error(&Config->DBConnMySQL));
+		SMSD_Log(DEBUG_ERROR, Config, "No version info in Gammu table");
+		SMSDMySQL_LogError(Config);
 		mysql_close(&Config->DBConnMySQL);
 		return ERR_UNKNOWN;
 	}
@@ -134,31 +127,26 @@ static GSM_Error SMSDMySQL_Init(GSM_SMSDConfig *Config)
 		return ERR_UNKNOWN;
 	}
 	mysql_free_result(Res);
-	mysql_query(&Config->DBConnMySQL,"SET NAMES utf8;");
-	SMSD_Log(0, Config, "Connected to Database: %s on %s", Config->database, Config->PC);
+	mysql_query(&Config->DBConnMySQL, "SET NAMES utf8;");
+	SMSD_Log(DEBUG_INFO, Config, "Connected to Database: %s on %s", Config->database, Config->PC);
 	return ERR_NONE;
 }
 
-static void SMSDMySQL_LogError(GSM_SMSDConfig *Config)
+static GSM_Error SMSDMySQL_Query_Real(GSM_SMSDConfig *Config, const char *query, gboolean retry)
 {
-	SMSD_Log(0, Config, "Error code: %d, Error: %s", mysql_errno(&Config->DBConnMySQL), mysql_error(&Config->DBConnMySQL));
-}
-
-static GSM_Error SMSDMySQL_Query_Real(GSM_SMSDConfig *Config, const char *query, bool retry)
-{
-	SMSD_Log(2, Config, "Execute SQL: %s", query);
+	SMSD_Log(DEBUG_SQL, Config, "Execute SQL: %s", query);
 
 	if (mysql_query(&Config->DBConnMySQL, query) != 0) {
-		SMSD_Log(0, Config, "SQL failed: %s", query);
+		SMSD_Log(DEBUG_INFO, Config, "SQL failed: %s", query);
 		SMSDMySQL_LogError(Config);
 		/* MySQL server has gone away */
 		if (retry && mysql_errno(&Config->DBConnMySQL) == 2006) {
-			SMSD_Log(0, Config, "Trying to reconnect to the Database...");
+			SMSD_Log(DEBUG_INFO, Config, "Trying to reconnect to the Database...");
 			SMSDMySQL_Free(Config);
 			sleep(30);
 			SMSDMySQL_Init(Config);
-			SMSD_Log(0, Config, "Retrying query...");
-			return SMSDMySQL_Query_Real(Config, query, false);
+			SMSD_Log(DEBUG_INFO, Config, "Retrying query...");
+			return SMSDMySQL_Query_Real(Config, query, FALSE);
 		}
 
 	}
@@ -167,29 +155,29 @@ static GSM_Error SMSDMySQL_Query_Real(GSM_SMSDConfig *Config, const char *query,
 
 static GSM_Error SMSDMySQL_Query(GSM_SMSDConfig *Config, const char *query)
 {
-	return SMSDMySQL_Query_Real(Config, query, true);
+	return SMSDMySQL_Query_Real(Config, query, TRUE);
 }
 
-static GSM_Error SMSDMySQL_Store_Real(GSM_SMSDConfig *Config, const char *query, MYSQL_RES **result, bool retry)
+static GSM_Error SMSDMySQL_Store_Real(GSM_SMSDConfig *Config, const char *query, MYSQL_RES **result, gboolean retry)
 {
 	GSM_Error error;
 
-	error = SMSDMySQL_Query_Real(Config, query, true);
+	error = SMSDMySQL_Query_Real(Config, query, TRUE);
 	if (error != ERR_NONE) return error;
 
 	*result = mysql_store_result(&Config->DBConnMySQL);
 
 	if (*result == NULL) {
-		SMSD_Log(0, Config, "Store result failed: %s", query);
+		SMSD_Log(DEBUG_INFO, Config, "Store result failed: %s", query);
 		SMSDMySQL_LogError(Config);
 		/* MySQL server has gone away */
 		if (retry && mysql_errno(&Config->DBConnMySQL) == 2006) {
-			SMSD_Log(0, Config, "Trying to reconnect to the Database...");
+			SMSD_Log(DEBUG_INFO, Config, "Trying to reconnect to the Database...");
 			SMSDMySQL_Free(Config);
 			sleep(30);
 			SMSDMySQL_Init(Config);
-			SMSD_Log(0, Config, "Retrying query...");
-			return SMSDMySQL_Store_Real(Config, query, result, false);
+			SMSD_Log(DEBUG_INFO, Config, "Retrying query...");
+			return SMSDMySQL_Store_Real(Config, query, result, FALSE);
 		}
 	}
 
@@ -198,34 +186,28 @@ static GSM_Error SMSDMySQL_Store_Real(GSM_SMSDConfig *Config, const char *query,
 
 static GSM_Error SMSDMySQL_Store(GSM_SMSDConfig *Config, const char *query, MYSQL_RES **result)
 {
-	return SMSDMySQL_Store_Real(Config, query, result, true);
+	return SMSDMySQL_Store_Real(Config, query, result, TRUE);
 }
 
 static GSM_Error SMSDMySQL_InitAfterConnect(GSM_SMSDConfig *Config)
 {
-	unsigned char buf[400],buf2[200];
+	char query[400];
+	char client_name[200];
 
-	sprintf(buf,"DELETE FROM `phones` WHERE `IMEI` = '%s'", Config->Status->IMEI);
-	if (SMSDMySQL_Query(Config, buf) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error deleting from database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+	snprintf(query, sizeof(query), "DELETE FROM `phones` WHERE `IMEI` = '%s'", Config->Status->IMEI);
+	if (SMSDMySQL_Query(Config, query) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error deleting phone info from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 
-	sprintf(buf2,"Gammu %s",VERSION);
-	if (strlen(GetOS()) != 0) {
-		strcat(buf2+strlen(buf2),", ");
-		strcat(buf2+strlen(buf2),GetOS());
-	}
-	if (strlen(GetCompiler()) != 0) {
-		strcat(buf2+strlen(buf2),", ");
-		strcat(buf2+strlen(buf2),GetCompiler());
-	}
+	snprintf(client_name, sizeof(client_name), "Gammu %s, %s, %s", VERSION, GetOS(), GetCompiler());
 
-	SMSD_Log(0, Config, "Communication established");
-	sprintf(buf,"INSERT INTO `phones` (`IMEI`,`ID`,`Send`,`Receive`,`InsertIntoDB`,`TimeOut`,`Client`, `Battery`, `Signal`) VALUES ('%s','%s','yes','yes',NOW(),(NOW() + INTERVAL 10 SECOND)+0,'%s', -1, -1)",
-		Config->Status->IMEI, Config->PhoneID, buf2);
-	if (SMSDMySQL_Query(Config, buf) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error inserting into database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+	SMSD_Log(DEBUG_INFO, Config, "Communication established");
+	snprintf(query, sizeof(query),
+		"INSERT INTO `phones` (`IMEI`,`ID`,`Send`,`Receive`,`InsertIntoDB`,`TimeOut`,`Client`, `Battery`, `Signal`) VALUES ('%s','%s','yes','yes',NOW(),(NOW() + INTERVAL 10 SECOND)+0,'%s', -1, -1)",
+		Config->Status->IMEI, Config->PhoneID, client_name);
+	if (SMSDMySQL_Query(Config, query) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error inserting phone info into database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 
@@ -240,7 +222,7 @@ static GSM_Error SMSDMySQL_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 	unsigned char		buffer[10000],buffer2[400],buffer3[50],buffer4[800];
 	int 			i;
 	time_t     		t_time1,t_time2;
-	bool			found;
+	gboolean			found;
 	long 			diff;
 	my_ulonglong		new_id;
 	size_t			locations_size = 0, locations_pos = 0;
@@ -252,19 +234,19 @@ static GSM_Error SMSDMySQL_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 		if (sms->SMS[i].PDU == SMS_Status_Report) {
 			strcpy(buffer2, DecodeUnicodeString(sms->SMS[i].Number));
 
-			SMSD_Log(0, Config, "Delivery report: %s to %s", DecodeUnicodeString(sms->SMS[i].Text), buffer2);
+			SMSD_Log(DEBUG_INFO, Config, "Delivery report: %s to %s", DecodeUnicodeString(sms->SMS[i].Text), buffer2);
 
 			sprintf(buffer, "SELECT ID,Status,UNIX_TIMESTAMP(SendingDateTime),DeliveryDateTime,SMSCNumber FROM `sentitems` WHERE "
 					"DeliveryDateTime IS NULL AND "
 					"SenderID='%s' AND TPMR='%i' AND DestinationNumber='%s'",
 					Config->PhoneID, sms->SMS[i].MessageReference, buffer2);
 			if (SMSDMySQL_Store(Config, buffer, &Res) != ERR_NONE) {
-				SMSD_Log(0, Config, "Error reading from database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+				SMSD_Log(DEBUG_INFO, Config, "Error reading sent items from database (%s)", __FUNCTION__);
 				return ERR_UNKNOWN;
 			}
-			found = false;
+			found = FALSE;
 			while ((Row = mysql_fetch_row(Res))) {
-				SMSD_Log(4, Config, "Checking for delivery report, SMSC=%s, state=%s", Row[4], Row[1]);
+				SMSD_Log(DEBUG_NOTICE, Config, "Checking for delivery report, SMSC=%s, state=%s", Row[4], Row[1]);
 				if (strcmp(Row[4],DecodeUnicodeString(sms->SMS[i].SMSC.Number))) {
 					if (Config->skipsmscnumber[0] == 0) continue;
 					if (strcmp(Config->skipsmscnumber,Row[4])) continue;
@@ -275,10 +257,10 @@ static GSM_Error SMSDMySQL_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 					diff = t_time2 - t_time1;
 
 					if (diff > -Config->deliveryreportdelay && diff < Config->deliveryreportdelay) {
-						found = true;
+						found = TRUE;
 						break;
 					} else {
-						SMSD_Log(1, Config, "Delivery report would match, but time delta is too big (%ld), consider increasing DeliveryReportDelay", diff);
+						SMSD_Log(DEBUG_NOTICE, Config, "Delivery report would match, but time delta is too big (%ld), consider increasing DeliveryReportDelay", diff);
 					}
 				}
 			}
@@ -299,7 +281,7 @@ static GSM_Error SMSDMySQL_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 				sprintf(buffer+strlen(buffer),"', `StatusError` = '%i'",sms->SMS[i].DeliveryStatus);
 				sprintf(buffer+strlen(buffer)," WHERE `ID` = '%s' AND `TPMR` = '%i'",Row[0],sms->SMS[i].MessageReference);
 				if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-					SMSD_Log(0, Config, "Error writing to database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+					SMSD_Log(DEBUG_INFO, Config, "Error updating sent item i ndatabase (%s)", __FUNCTION__);
 					return ERR_UNKNOWN;
 				}
 			}
@@ -364,15 +346,15 @@ static GSM_Error SMSDMySQL_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 		}
 		sprintf(buffer+strlen(buffer),"','%s')",Config->PhoneID);
 		if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error writing to database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+			SMSD_Log(DEBUG_INFO, Config, "Error writing inbox message to database (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
 		new_id = mysql_insert_id(&Config->DBConnMySQL);
 		if (new_id == 0) {
-			SMSD_Log(0, Config, "Error writing to database (%s): %s, new id is zero!", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+			SMSD_Log(DEBUG_INFO, Config, "Error writing inbox message to database (%s), new id is zero!", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
-		SMSD_Log(1, Config, "Inserted message id %llu", new_id);
+		SMSD_Log(DEBUG_NOTICE, Config, "Inserted message id %lu", (long)new_id);
 
 		if (locations_pos + 10 >= locations_size) {
 			locations_size += 40;
@@ -382,11 +364,11 @@ static GSM_Error SMSDMySQL_SaveInboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig
 				*Locations[0] = 0;
 			}
 		}
-		locations_pos += sprintf((*Locations) + locations_pos, "%llu ", new_id);
+		locations_pos += sprintf((*Locations) + locations_pos, "%lu ", (long)new_id);
 
 		sprintf(buf, "UPDATE phones SET Received = Received + 1 WHERE IMEI = '%s'", Config->Status->IMEI);
 		if (SMSDMySQL_Query(Config, buf) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error updating number of received messages (%s)", __FUNCTION__);
+			SMSD_Log(DEBUG_INFO, Config, "Error updating number of received messages (%s)", __FUNCTION__);
 	    		mysql_free_result(Res);
 			return ERR_UNKNOWN;
 		}
@@ -399,9 +381,9 @@ static GSM_Error SMSDMySQL_RefreshSendStatus(GSM_SMSDConfig *Config, char *ID)
 {
 	unsigned char buffer[10000];
 
-	sprintf(buffer,"UPDATE `outbox` SET `SendingTimeOut`=(now() + INTERVAL 15 SECOND)+0 WHERE `ID` = '%s' AND `SendingTimeOut` < now()",ID);
+	sprintf(buffer,"UPDATE `outbox` SET `SendingTimeOut`=(now() + INTERVAL 15 SECOND)+0 WHERE `ID` = '%s' AND (`SendingTimeOut` < now() OR SendingTimeOut IS NULL)",ID);
 	if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error writing to database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+		SMSD_Log(DEBUG_INFO, Config, "Error updating send timestamp in database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	if (mysql_affected_rows(&Config->DBConnMySQL) == 0) return ERR_UNKNOWN;
@@ -417,11 +399,10 @@ static GSM_Error SMSDMySQL_FindOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfi
 	MYSQL_RES 		*Res;
 	MYSQL_ROW 		Row;
 	int 			i;
-	bool			found = false;
+	gboolean			found = FALSE;
 
-	sprintf(buf, "SELECT ID,InsertIntoDB,SendingDateTime,SenderID FROM `outbox` WHERE SendingDateTime < NOW() AND SendingTimeOut < NOW()");
-	if (SMSDMySQL_Store(Config, buf, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error reading from database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+	if (SMSDMySQL_Store(Config, "SELECT ID,InsertIntoDB,SendingDateTime,SenderID FROM `outbox` WHERE SendingDateTime < NOW() AND SendingTimeOut < NOW()", &Res) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error reading message to send from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	while ((Row = mysql_fetch_row(Res))) {
@@ -429,7 +410,7 @@ static GSM_Error SMSDMySQL_FindOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfi
 		sprintf(Config->DT,"%s",Row[1]);
 		if (Row[3] == NULL || strlen(Row[3]) == 0 || !strcmp(Row[3],Config->PhoneID)) {
 			if (SMSDMySQL_RefreshSendStatus(Config, ID)==ERR_NONE) {
-				found = true;
+				found = TRUE;
 				break;
 			}
 		}
@@ -441,19 +422,19 @@ static GSM_Error SMSDMySQL_FindOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfi
 	}
 
 	sms->Number = 0;
-	for (i=0;i<GSM_MAX_MULTI_SMS;i++) {
+	for (i = 0; i < GSM_MAX_MULTI_SMS; i++) {
 		GSM_SetDefaultSMSData(&sms->SMS[i]);
 		sms->SMS[i].SMSC.Number[0] = 0;
 		sms->SMS[i].SMSC.Number[1] = 0;
 	}
-	for (i=1;i<GSM_MAX_MULTI_SMS+1;i++) {
-		if (i==1) {
+	for (i = 1; i < GSM_MAX_MULTI_SMS + 1; i++) {
+		if (i == 1) {
 			sprintf(buf, "SELECT Text,Coding,UDH,Class,TextDecoded,ID,DestinationNumber,MultiPart,RelativeValidity,DeliveryReport,CreatorID FROM `outbox` WHERE ID='%s'",ID);
 		} else {
 			sprintf(buf, "SELECT Text,Coding,UDH,Class,TextDecoded,ID,SequencePosition FROM `outbox_multipart` WHERE ID='%s' AND SequencePosition='%i'",ID,i);
 		}
 		if (SMSDMySQL_Store(Config, buf, &Res) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error reading from database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+			SMSD_Log(DEBUG_INFO, Config, "Error reading outbox message from database (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
 		if (!(Row = mysql_fetch_row(Res))) {
@@ -461,12 +442,16 @@ static GSM_Error SMSDMySQL_FindOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfi
 			return ERR_NONE;
 		}
 
-		sms->SMS[sms->Number].Coding=SMS_Coding_8bit;
-		if (!strcmp(Row[1],"Unicode_No_Compression")) sms->SMS[sms->Number].Coding=SMS_Coding_Unicode_No_Compression;
-		if (!strcmp(Row[1],"Default_No_Compression")) sms->SMS[sms->Number].Coding=SMS_Coding_Default_No_Compression;
+		sms->SMS[sms->Number].Coding = SMS_Coding_8bit;
+		if (!strcmp(Row[1], "Unicode_No_Compression")) {
+			sms->SMS[sms->Number].Coding = SMS_Coding_Unicode_No_Compression;
+		}
+		if (!strcmp(Row[1], "Default_No_Compression")) {
+			sms->SMS[sms->Number].Coding = SMS_Coding_Default_No_Compression;
+		}
 
 		if (Row[0] == NULL || strlen(Row[0])==0) {
-			SMSD_Log(1, Config, "Message: %s", Row[4]);
+			SMSD_Log(DEBUG_NOTICE, Config, "Message: %s", Row[4]);
 			DecodeUTF8(sms->SMS[sms->Number].Text,Row[4],strlen(Row[4]));
 		} else {
 			switch (sms->SMS[sms->Number].Coding) {
@@ -507,7 +492,7 @@ static GSM_Error SMSDMySQL_FindOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfi
 				Config->currdeliveryreport = 0;
 			}
 
-			if (!strcmp(Row[7],"false")) {
+			if (!strcmp(Row[7],"FALSE")) {
 				mysql_free_result(Res);
 				break;
 			}
@@ -521,25 +506,25 @@ static GSM_Error SMSDMySQL_FindOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfi
 /* After sending SMS is moved to Sent Items or Error Items. */
 static GSM_Error SMSDMySQL_MoveSMS(GSM_MultiSMSMessage *sms UNUSED,
 		GSM_SMSDConfig *Config, char *ID,
-		bool alwaysDelete UNUSED, bool sent UNUSED)
+		gboolean alwaysDelete UNUSED, gboolean sent UNUSED)
 {
-	unsigned char buffer[10000];
+	char buffer[100];
 
 	sprintf(buffer,"DELETE FROM `outbox` WHERE `ID` = '%s'",ID);
 	if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error deleting from database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+		SMSD_Log(DEBUG_INFO, Config, "Error deleting outbox message from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	sprintf(buffer,"DELETE FROM `outbox_multipart` WHERE `ID` = '%s'",ID);
 	if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error deleting from database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+		SMSD_Log(DEBUG_INFO, Config, "Error deleting multipart outbox message from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
   	return ERR_NONE;
 }
 
 /* Adds SMS to Outbox */
-static GSM_Error SMSDMySQL_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig *Config)
+static GSM_Error SMSDMySQL_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDConfig *Config, char *NewID)
 {
 	char			buffer[10000],buffer2[400],buffer5[400];
 	int 			i,ID = 0;
@@ -572,9 +557,9 @@ static GSM_Error SMSDMySQL_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDCon
 				sprintf(buffer+strlen(buffer),"default','");
 			}
 			if (sms->Number == 1) {
-				sprintf(buffer+strlen(buffer),"false");
+				sprintf(buffer+strlen(buffer),"FALSE");
 			} else {
-				sprintf(buffer+strlen(buffer),"true");
+				sprintf(buffer+strlen(buffer),"TRUE");
 			}
 			sprintf(buffer+strlen(buffer),"',NOW()");
 		} else {
@@ -640,106 +625,140 @@ static GSM_Error SMSDMySQL_CreateOutboxSMS(GSM_MultiSMSMessage *sms, GSM_SMSDCon
 		}
 		strcat(buffer, ")");
 		if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error writing to database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+			SMSD_Log(DEBUG_INFO, Config, "Error writing outbox record to database (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
 		if (i == 0) {
 			ID = mysql_insert_id(&Config->DBConnMySQL);
 			if (ID == 0) {
-				SMSD_Log(0, Config, "Failed to get inserted row ID (%s)", __FUNCTION__);
+				SMSD_Log(DEBUG_INFO, Config, "Failed to get inserted row ID (%s)", __FUNCTION__);
 				return ERR_UNKNOWN;
 			}
 		}
 	}
-	SMSD_Log(0, Config, "Written message with ID %i", ID);
+	SMSD_Log(DEBUG_INFO, Config, "Written message with ID %i", ID);
+	if (NewID != NULL) sprintf(NewID, "%d", ID);
   	return ERR_NONE;
 }
 
 
 static GSM_Error SMSDMySQL_AddSentSMSInfo(GSM_MultiSMSMessage *sms, GSM_SMSDConfig *Config, char *ID, int Part, GSM_SMSDSendingError err, int TPMR)
 {
-	unsigned char	buffer[10000],buffer2[400],buff[50],buffer5[400];
+	char send_state[100];
+	char query[10000];
+	char utf_text[2 * GSM_MAX_SMS_LENGTH], escaped_text[2 * GSM_MAX_SMS_LENGTH];
+	int query_pos;
 
 	if (err == SMSD_SEND_OK) {
-		SMSD_Log(1, Config, "Transmitted %s (%s: %i) to %s", Config->SMSID,
+		SMSD_Log(DEBUG_NOTICE, Config, "Transmitted %s (%s: %i) to %s", Config->SMSID,
 			     (Part == sms->Number ? "total" : "part"), Part,
 			     DecodeUnicodeString(sms->SMS[0].Number));
 	}
 
-	buff[0] = 0;
+	send_state[0] = 0;
 	if (err == SMSD_SEND_OK) {
 		if (sms->SMS[Part-1].PDU == SMS_Status_Report) {
-			sprintf(buff,"SendingOK");
+			strcpy(send_state, "SendingOK");
 		} else {
-			sprintf(buff,"SendingOKNoReport");
+			strcpy(send_state, "SendingOKNoReport");
 		}
 	}
 	if (err == SMSD_SEND_SENDING_ERROR)
-		sprintf(buff,"SendingError");
+		strcpy(send_state, "SendingError");
 	if (err == SMSD_SEND_ERROR)
-		sprintf(buff,"Error");
+		strcpy(send_state, "Error");
 
-	buffer[0] = 0;
-	sprintf(buffer+strlen(buffer),"INSERT INTO `sentitems` "
+	query[0] = 0;
+	query_pos = 0;
+	query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+		"INSERT INTO `sentitems` "
 		"(`CreatorID`,`ID`,`SequencePosition`,`Status`,`SendingDateTime`, `SMSCNumber`, `TPMR`, "
 		"`SenderID`,`Text`,`DestinationNumber`,`Coding`,`UDH`,`Class`,`TextDecoded`,`InsertIntoDB`,`RelativeValidity`) VALUES (");
-	sprintf(buffer+strlen(buffer),"'%s','%s','%i','%s',NOW(),'%s','%i','%s','",Config->CreatorID,ID,Part,buff,DecodeUnicodeString(sms->SMS[Part-1].SMSC.Number),TPMR,Config->PhoneID);
+	query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+		"'%s','%s','%i','%s',NOW(),'%s','%i','%s','",
+		Config->CreatorID, ID, Part, send_state, DecodeUnicodeString(sms->SMS[Part-1].SMSC.Number), TPMR, Config->PhoneID);
 	switch (sms->SMS[Part-1].Coding) {
-	case SMS_Coding_Unicode_No_Compression:
-    	case SMS_Coding_Default_No_Compression:
-		EncodeHexUnicode(buffer+strlen(buffer),sms->SMS[Part-1].Text,UnicodeLength(sms->SMS[Part-1].Text));
-		break;
-	case SMS_Coding_8bit:
-		EncodeHexBin(buffer+strlen(buffer),sms->SMS[Part-1].Text,sms->SMS[Part-1].Length);
-	default:
-		break;
+		case SMS_Coding_Unicode_No_Compression:
+		case SMS_Coding_Default_No_Compression:
+			EncodeHexUnicode(query + query_pos,
+				sms->SMS[Part-1].Text,
+				UnicodeLength(sms->SMS[Part-1].Text));
+			query_pos = strlen(query);
+			break;
+		case SMS_Coding_8bit:
+			EncodeHexBin(query + query_pos,
+				sms->SMS[Part-1].Text,
+				sms->SMS[Part-1].Length);
+			query_pos = strlen(query);
+		default:
+			break;
 	}
-	sprintf(buffer+strlen(buffer),"','%s','",DecodeUnicodeString(sms->SMS[Part-1].Number));
+	query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+		"','%s','",
+		DecodeUnicodeString(sms->SMS[Part-1].Number));
 	switch (sms->SMS[Part-1].Coding) {
-	case SMS_Coding_Unicode_No_Compression:
-		sprintf(buffer+strlen(buffer),"Unicode_No_Compression");
-		break;
-	case SMS_Coding_Unicode_Compression:
-		sprintf(buffer+strlen(buffer),"Unicode_Compression");
-		break;
-	case SMS_Coding_Default_No_Compression:
-		sprintf(buffer+strlen(buffer),"Default_No_Compression");
-		break;
-	case SMS_Coding_Default_Compression:
-		sprintf(buffer+strlen(buffer),"Default_Compression");
-		break;
-	case SMS_Coding_8bit:
-		sprintf(buffer+strlen(buffer),"8bit");
-		break;
+		case SMS_Coding_Unicode_No_Compression:
+			query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+				"Unicode_No_Compression");
+			break;
+		case SMS_Coding_Unicode_Compression:
+			query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+				"Unicode_Compression");
+			break;
+		case SMS_Coding_Default_No_Compression:
+			query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+				"Default_No_Compression");
+			break;
+		case SMS_Coding_Default_Compression:
+			query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+				"Default_Compression");
+			break;
+		case SMS_Coding_8bit:
+			query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+				"8bit");
+			break;
 	}
-	sprintf(buffer+strlen(buffer),"','");
+	query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+		"','");
 	if (sms->SMS[Part-1].UDH.Type != UDH_NoUDH) {
-		EncodeHexBin(buffer+strlen(buffer),sms->SMS[Part-1].UDH.Text,sms->SMS[Part-1].UDH.Length);
+		EncodeHexBin(query + query_pos,
+			sms->SMS[Part-1].UDH.Text,
+			sms->SMS[Part-1].UDH.Length);
+		query_pos = strlen(query);
 	}
-	sprintf(buffer+strlen(buffer),"','%i','",sms->SMS[Part-1].Class);
+	query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+		"','%i','",
+		sms->SMS[Part-1].Class);
 	switch (sms->SMS[Part-1].Coding) {
-	case SMS_Coding_Unicode_No_Compression:
-	case SMS_Coding_Default_No_Compression:
-		EncodeUTF8(buffer2, sms->SMS[Part-1].Text);
-		mysql_real_escape_string(&Config->DBConnMySQL,buffer5,buffer2,strlen(buffer2));
-		memcpy(buffer+strlen(buffer),buffer5,strlen(buffer5)+1);
-		break;
-	default:
-		break;
+		case SMS_Coding_Unicode_No_Compression:
+		case SMS_Coding_Default_No_Compression:
+			EncodeUTF8(utf_text, sms->SMS[Part-1].Text);
+			mysql_real_escape_string(&Config->DBConnMySQL, escaped_text, utf_text, strlen(utf_text));
+			query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+				"%s",
+				escaped_text);
+			break;
+		default:
+			break;
 	}
-	sprintf(buffer+strlen(buffer),"','%s','",Config->DT);
+	query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+		"','%s','",
+		Config->DT);
 	if (sms->SMS[Part-1].SMSC.Validity.Format == SMS_Validity_RelativeFormat) {
-		sprintf(buffer+strlen(buffer),"%i')",sms->SMS[Part-1].SMSC.Validity.Relative);
+		query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+			"%i')",
+			sms->SMS[Part-1].SMSC.Validity.Relative);
 	} else {
-		sprintf(buffer+strlen(buffer),"-1')");
+		query_pos += snprintf(query + query_pos, sizeof(query) - query_pos,
+			"-1')");
 	}
-	if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error writing to database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+	if (SMSDMySQL_Query(Config, query) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error writing sent item to database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
-	sprintf(buffer, "UPDATE `phones` SET `Sent`= `Sent` + 1 WHERE IMEI = '%s'", Config->Status->IMEI);
-	if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error updating number of sent messages (%s)", __FUNCTION__);
+	snprintf(query, sizeof(query), "UPDATE `phones` SET `Sent`= `Sent` + 1 WHERE IMEI = '%s'", Config->Status->IMEI);
+	if (SMSDMySQL_Query(Config, query) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error updating number of sent messages (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
   	return ERR_NONE;
@@ -753,7 +772,7 @@ static GSM_Error SMSDMySQL_RefreshPhoneStatus(GSM_SMSDConfig *Config)
 		"UPDATE `phones` SET `TimeOut`= (NOW() + INTERVAL 10 SECOND)+0, `Battery`= %d, `Signal`= %d WHERE `IMEI` = '%s'",
 		Config->Status->Charge.BatteryPercent, Config->Status->Network.SignalPercent, Config->Status->IMEI);
 	if (SMSDMySQL_Query(Config, buffer) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error writing to database (%s): %s", __FUNCTION__, mysql_error(&Config->DBConnMySQL));
+		SMSD_Log(DEBUG_INFO, Config, "Error writing phone information to database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	return ERR_NONE;
