@@ -8,13 +8,17 @@
 int main(int argc, char **argv)
 {
 	GSM_Error error;
-	bool numeric = false;
+	gboolean numeric = FALSE, manpage = FALSE;
 	int rc = 0;
 	const char *errorstring;
 	const char *errorname;
 
 	if (argc >= 2 && strcmp(argv[1], "-n") == 0) {
-		numeric = true;
+		numeric = TRUE;
+	}
+
+	if (argc >= 2 && strcmp(argv[1], "-m") == 0) {
+		manpage = TRUE;
 	}
 
 	for (error = ERR_NONE; error < ERR_LAST_VALUE; error++) {
@@ -30,6 +34,8 @@ int main(int argc, char **argv)
 		}
 		if (numeric) {
 			printf("%d. %s - %s\n", error, errorname, errorstring);
+		} else if (manpage) {
+			printf(".SS %d\n%s\n", 100 + error, errorstring);
 		} else {
 			printf("# %s - %s\n", errorname, errorstring);
 		}
