@@ -1033,7 +1033,7 @@ int main(int argc UNUSED, char **argv UNUSED)
 
 	InitLines(&lines);
 
-	SplitLines(input, sizeof(input), &lines, "\n", 1, FALSE);
+	SplitLines(input, sizeof(input), &lines, "\n", 1, "", 0 ,FALSE);
 
 #define COMPARE(num, text) \
 	if (strcmp(GetLineString(input, &lines, num), text) != 0) { \
@@ -1042,7 +1042,7 @@ int main(int argc UNUSED, char **argv UNUSED)
 		goto end; \
 	} \
 	if (strlen(GetLineString(input, &lines, num)) != (size_t)GetLineLength(input, &lines, num)) { \
-		printf("DIFFERENT LENGTH[%d]: %zd %d\n", num, strlen(GetLineString(input, &lines, num)), GetLineLength(input, &lines, num)); \
+		printf("DIFFERENT LENGTH[%d]: %ld %d\n", num, (long)strlen(GetLineString(input, &lines, num)), GetLineLength(input, &lines, num)); \
 		ret = 2; \
 		goto end; \
 	}
