@@ -30,8 +30,8 @@ int main(int argc, char **argv)
 	GSM_MultiSMSMessage sms;
 
 	/* Check parameters */
-	if (argc != 2) {
-		printf("Not enough parameters!\nUsage: sms-at-parse comm.dump\n");
+	if (argc != 2 && argc != 3) {
+		printf("Not enough parameters!\nUsage: sms-at-parse comm.dump [PDU|TXT]\n");
 		return 1;
 	}
 
@@ -46,6 +46,7 @@ int main(int argc, char **argv)
 	len = fread(buffer, 1, sizeof(buffer) - 1, f);
 	if (!feof(f)) {
 		printf("Could not read whole file %s\n", argv[1]);
+		fclose(f);
 		return 1;
 	}
 	/* Zero terminate data */
@@ -56,7 +57,7 @@ int main(int argc, char **argv)
 
 	/* Configure state machine */
 	debug_info = GSM_GetGlobalDebug();
-	GSM_SetDebugFileDescriptor(stderr, false, debug_info);
+	GSM_SetDebugFileDescriptor(stderr, FALSE, debug_info);
 	GSM_SetDebugLevel("textall", debug_info);
 
 	/* Allocates state machine */
@@ -64,20 +65,25 @@ int main(int argc, char **argv)
 	test_result (s != NULL);
 
 	debug_info = GSM_GetDebug(s);
-	GSM_SetDebugGlobal(true, debug_info);
+	GSM_SetDebugGlobal(TRUE, debug_info);
 
 	/* Initialize AT engine */
 	Data = &s->Phone.Data;
 	Data->ModelInfo = GetModelData(NULL, NULL, "unknown", NULL);
 	Priv = &s->Phone.Data.Priv.ATGEN;
 	Priv->ReplyState = AT_Reply_OK;
-	Priv->SMSMode = SMS_AT_PDU;
+	Priv->Charset = AT_CHARSET_GSM;
+	if (argc == 3 && strcmp(argv[2], "TXT") == 0) {
+		Priv->SMSMode = SMS_AT_TXT;
+	} else {
+		Priv->SMSMode = SMS_AT_PDU;
+	}
 
 	/* Init message */
 	msg.Type = 0;
 	msg.Length = len;
 	msg.Buffer = buffer;
-	SplitLines(msg.Buffer, msg.Length, &Priv->Lines, "\x0D\x0A", 2, true);
+	SplitLines(msg.Buffer, msg.Length, &Priv->Lines, "\x0D\x0A", 2, "\"", 1, TRUE);
 
 	/* Pointer to store message */
 	s->Phone.Data.GetSMSMessage = &sms;
@@ -88,8 +94,8 @@ int main(int argc, char **argv)
 
 	/* Display message */
 	if (error == ERR_NONE) {
-		DisplayMultiSMSInfo(&sms, false, true, NULL, NULL);
-		DisplayMultiSMSInfo(&sms, true, true, NULL, NULL);
+		DisplayMultiSMSInfo(&sms, FALSE, TRUE, NULL, NULL);
+		DisplayMultiSMSInfo(&sms, TRUE, TRUE, NULL, NULL);
 	}
 
 	/* This is normally done by ATGEN_Terminate */
