@@ -16,7 +16,7 @@ int main(int argc UNUSED, char **argv UNUSED)
 	GSM_Error error;
 	GSM_SMS_Backup Backup;
 	GSM_MultiSMSMessage SMS;
-        int i;
+        int i, step = 0;
 
 	/* Check parameters */
 	if (argc != 2) {
@@ -32,11 +32,20 @@ int main(int argc UNUSED, char **argv UNUSED)
 	error = GSM_ReadSMSBackupFile(argv[1], &Backup);
 	gammu_test_result(error, "GSM_ReadSMSBackupFile");
 
-        for (i = 0; Backup.SMS[i] != NULL; i++) {
-		SMS.Number = 1;
-		SMS.SMS[0] = *Backup.SMS[i];
-                DisplayMultiSMSInfo(&SMS, FALSE, TRUE, NULL, NULL);
-	}
+
+	do {
+		for (i = step; Backup.SMS[i] != NULL && i - step < GSM_MAX_MULTI_SMS; i++) {
+			SMS.Number = i + 1 - step;
+			SMS.SMS[i - step] = *Backup.SMS[i];
+		}
+		if (i - step == GSM_MAX_MULTI_SMS) {
+			step = i;
+		} else {
+			step = 0;
+		}
+
+		DisplayMultiSMSInfo(&SMS, TRUE, TRUE, NULL, NULL);
+	} while (step > 0);
 
 	/* We don't need this anymore */
 	GSM_FreeSMSBackup(&Backup);
